/**
 * Copyright 2024-2025, Optimizely
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { RequestHandler } from "../utils/http_request_handler/http";
import { Transformer } from "../utils/type";
import { ProjectConfigManager } from "./project_config_manager";
import { Store } from "../utils/cache/store";
export declare const INVALID_CONFIG_MANAGER = "Invalid config manager";
declare const configManagerSymbol: unique symbol;
export type OpaqueConfigManager = {
    [configManagerSymbol]: unknown;
};
export type StaticConfigManagerConfig = {
    datafile: string;
    jsonSchemaValidator?: Transformer<unknown, boolean>;
};
export declare const createStaticProjectConfigManager: (config: StaticConfigManagerConfig) => OpaqueConfigManager;
export type PollingConfigManagerConfig = {
    datafile?: string;
    sdkKey: string;
    jsonSchemaValidator?: Transformer<unknown, boolean>;
    autoUpdate?: boolean;
    updateInterval?: number;
    urlTemplate?: string;
    datafileAccessToken?: string;
    cache?: Store<string>;
};
export type PollingConfigManagerFactoryOptions = PollingConfigManagerConfig & {
    requestHandler: RequestHandler;
};
export declare const getPollingConfigManager: (opt: PollingConfigManagerFactoryOptions) => ProjectConfigManager;
export declare const getOpaquePollingConfigManager: (opt: PollingConfigManagerFactoryOptions) => OpaqueConfigManager;
export declare const wrapConfigManager: (configManager: ProjectConfigManager) => OpaqueConfigManager;
export declare const extractConfigManager: (opaqueConfigManager: OpaqueConfigManager) => ProjectConfigManager;
export {};
