/**
 * Copyright 2022-2025, Optimizely
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { LoggerFacade } from '../logging/logger';
import { Store } from '../utils/cache/store';
import { Maybe } from '../utils/type';
export interface VuidManager {
    getVuid(): Maybe<string>;
    isVuidEnabled(): boolean;
    initialize(): Promise<void>;
}
export declare class VuidCacheManager {
    private logger?;
    private vuidCacheKey;
    private cache?;
    private vuid?;
    private waitPromise;
    constructor(cache?: Store<string>, logger?: LoggerFacade);
    setCache(cache: Store<string>): void;
    setLogger(logger: LoggerFacade): void;
    private serialize;
    remove(): Promise<unknown>;
    load(): Promise<Maybe<string>>;
}
export type VuidManagerConfig = {
    enableVuid?: boolean;
    vuidCache: Store<string>;
    vuidCacheManager: VuidCacheManager;
};
export declare class DefaultVuidManager implements VuidManager {
    private vuidCacheManager;
    private vuid?;
    private vuidCache;
    private vuidEnabled;
    constructor(config: VuidManagerConfig);
    getVuid(): Maybe<string>;
    isVuidEnabled(): boolean;
    /**
     * initializes the VuidManager
     * @returns Promise that resolves when the VuidManager is initialized
     */
    initialize(): Promise<void>;
}
