(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.optimizelySdk = {}));
})(this, (function (exports) { 'use strict';

  /**
   * Convert array of 16 byte values to UUID string format of the form:
   * XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX
   */
  var byteToHex = [];
  for (var i = 0; i < 256; ++i) {
    byteToHex.push((i + 0x100).toString(16).slice(1));
  }
  function unsafeStringify(arr, offset = 0) {
    // Note: Be careful editing this code!  It's been tuned for performance
    // and works in ways you may not expect. See https://github.com/uuidjs/uuid/pull/434
    //
    // Note to future-self: No, you can't remove the `toLowerCase()` call.
    // REF: https://github.com/uuidjs/uuid/pull/677#issuecomment-1757351351
    return (byteToHex[arr[offset + 0]] + byteToHex[arr[offset + 1]] + byteToHex[arr[offset + 2]] + byteToHex[arr[offset + 3]] + '-' + byteToHex[arr[offset + 4]] + byteToHex[arr[offset + 5]] + '-' + byteToHex[arr[offset + 6]] + byteToHex[arr[offset + 7]] + '-' + byteToHex[arr[offset + 8]] + byteToHex[arr[offset + 9]] + '-' + byteToHex[arr[offset + 10]] + byteToHex[arr[offset + 11]] + byteToHex[arr[offset + 12]] + byteToHex[arr[offset + 13]] + byteToHex[arr[offset + 14]] + byteToHex[arr[offset + 15]]).toLowerCase();
  }

  // Unique ID creation requires a high quality random # generator. In the browser we therefore
  // require the crypto API and do not support built-in fallback to lower quality random number
  // generators (like Math.random()).

  var getRandomValues;
  var rnds8 = new Uint8Array(16);
  function rng() {
    // lazy load so that environments that need to polyfill have a chance to do so
    if (!getRandomValues) {
      // getRandomValues needs to be invoked in a context where "this" is a Crypto implementation.
      getRandomValues = typeof crypto !== 'undefined' && crypto.getRandomValues && crypto.getRandomValues.bind(crypto);
      if (!getRandomValues) {
        throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
      }
    }
    return getRandomValues(rnds8);
  }

  var randomUUID = typeof crypto !== 'undefined' && crypto.randomUUID && crypto.randomUUID.bind(crypto);
  var native = {
    randomUUID
  };

  function v4(options, buf, offset) {
    if (native.randomUUID && !buf && !options) {
      return native.randomUUID();
    }
    options = options || {};
    var rnds = options.random || (options.rng || rng)();

    // Per 4.4, set bits for version and `clock_seq_hi_and_reserved`
    rnds[6] = rnds[6] & 0x0f | 0x40;
    rnds[8] = rnds[8] & 0x3f | 0x80;

    // Copy bytes to buffer, if provided
    if (buf) {
      offset = offset || 0;
      for (var i = 0; i < 16; ++i) {
        buf[offset + i] = rnds[i];
      }
      return buf;
    }
    return unsafeStringify(rnds);
  }

  /**
   * Copyright 2017, 2019-2020, 2022-2023, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const MAX_SAFE_INTEGER_LIMIT = Math.pow(2, 53);
  function currentTimestamp() {
      return Math.round(new Date().getTime());
  }
  function isSafeInteger(number) {
      return typeof number == 'number' && Math.abs(number) <= MAX_SAFE_INTEGER_LIMIT;
  }
  function keyBy(arr, key) {
      if (!arr)
          return {};
      return keyByUtil(arr, function (item) {
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          return item[key];
      });
  }
  function isNumber$1(value) {
      return typeof value === 'number';
  }
  function uuid() {
      return v4();
  }
  function getTimestamp() {
      return new Date().getTime();
  }
  function groupBy(arr, grouperFn) {
      const grouper = {};
      arr.forEach(item => {
          const key = grouperFn(item);
          grouper[key] = grouper[key] || [];
          grouper[key].push(item);
      });
      return objectValues(grouper);
  }
  function objectValues(obj) {
      return Object.keys(obj).map(key => obj[key]);
  }
  function objectEntries(obj) {
      return Object.keys(obj).map(key => [key, obj[key]]);
  }
  function find(arr, cond) {
      let found;
      for (const item of arr) {
          if (cond(item)) {
              found = item;
              break;
          }
      }
      return found;
  }
  function keyByUtil(arr, keyByFn) {
      const map = {};
      arr.forEach(item => {
          const key = keyByFn(item);
          map[key] = item;
      });
      return map;
  }
  // TODO[OASIS-6649]: Don't use any type
  // eslint-disable-next-line  @typescript-eslint/no-explicit-any
  function sprintf(format, ...args) {
      let i = 0;
      return format.replace(/%s/g, function () {
          const arg = args[i++];
          const type = typeof arg;
          if (type === 'function') {
              return arg();
          }
          else if (type === 'string') {
              return arg;
          }
          else {
              return String(arg);
          }
      });
  }
  /**
   * Checks two string arrays for equality.
   * @param arrayA First Array to be compared against.
   * @param arrayB Second Array to be compared against.
   * @returns {boolean} True if both arrays are equal, otherwise returns false.
   */
  function checkArrayEquality(arrayA, arrayB) {
      return arrayA.length === arrayB.length && arrayA.every((item, index) => item === arrayB[index]);
  }
  var fns = {
      checkArrayEquality,
      currentTimestamp,
      isSafeInteger,
      keyBy,
      uuid,
      isNumber: isNumber$1,
      getTimestamp,
      groupBy,
      objectValues,
      objectEntries,
      find,
      keyByUtil,
      sprintf,
  };

  class OptimizelyError extends Error {
      constructor(baseMessage, ...params) {
          super();
          this.resolved = false;
          this.name = 'OptimizelyError';
          this.baseMessage = baseMessage;
          this.params = params;
          // this is needed cause instanceof doesn't work for
          // custom Errors when TS is compiled to es5
          Object.setPrototypeOf(this, OptimizelyError.prototype);
      }
      setMessage(resolver) {
          if (!this.resolved) {
              this.message = sprintf(resolver.resolve(this.baseMessage), ...this.params);
              this.resolved = true;
          }
      }
  }

  const BUCKETING_ID_NOT_STRING = '0';
  const CONDITION_EVALUATOR_ERROR = '2';
  const DATAFILE_FETCH_REQUEST_FAILED = '3';
  const ERROR_FETCHING_DATAFILE = '4';
  const EVENT_ACTION_INVALID = '5';
  const EVENT_DATA_INVALID = '6';
  const EVENT_KEY_NOT_FOUND = '7';
  const EXPERIMENT_KEY_NOT_IN_DATAFILE = '8';
  const FAILED_TO_DISPATCH_EVENTS = '9';
  const FAILED_TO_SEND_ODP_EVENTS = '10';
  const FEATURE_NOT_IN_DATAFILE = '11';
  const INVALID_ATTRIBUTES$1 = '12';
  const INVALID_BUCKETING_ID = '13';
  const INVALID_DATAFILE = '16';
  const INVALID_DATAFILE_MALFORMED = '17';
  const INVALID_DATAFILE_VERSION = '18';
  const INVALID_EVENT_TAGS = '19';
  const INVALID_EXPERIMENT_ID = '20';
  const INVALID_EXPERIMENT_KEY = '21';
  const INVALID_GROUP_ID = '22';
  const INVALID_INPUT_FORMAT = '23';
  const INVALID_JSON = '24';
  const INVALID_USER_ID = '25';
  const INVALID_USER_PROFILE_SERVICE = '26';
  const INVALID_VARIATION_KEY = '27';
  const MISSING_INTEGRATION_KEY = '28';
  const NOTIFICATION_LISTENER_EXCEPTION = '29';
  const NOT_TRACKING_USER = '30';
  const NO_DATAFILE_SPECIFIED = '31';
  const NO_EVENT_PROCESSOR = '32';
  const NO_JSON_PROVIDED = '33';
  const NO_PROJECT_CONFIG_FAILURE = '34';
  const NO_VARIATION_FOR_EXPERIMENT_KEY = '36';
  const ODP_CONFIG_NOT_AVAILABLE = '37';
  const ODP_EVENTS_SHOULD_HAVE_ATLEAST_ONE_KEY_VALUE = '38';
  const ODP_EVENT_FAILED = '39';
  const ODP_EVENT_FAILED_ODP_MANAGER_MISSING = '40';
  const ODP_NOT_INTEGRATED = '42';
  const ONLY_POST_REQUESTS_ARE_SUPPORTED = '43';
  const OUT_OF_BOUNDS = '44';
  const REQUEST_ERROR = '46';
  const REQUEST_TIMEOUT = '47';
  const RETRY_CANCELLED = '48';
  const SEND_BEACON_FAILED = '49';
  const SERVICE_NOT_RUNNING = '50';
  const UNABLE_TO_CAST_VALUE = '52';
  const UNABLE_TO_GET_VUID_VUID_MANAGER_NOT_AVAILABLE = '53';
  const UNABLE_TO_PARSE_AND_SKIPPED_HEADER = '54';
  const UNDEFINED_ATTRIBUTE = '55';
  const UNEXPECTED_CONDITION_VALUE = '56';
  const UNEXPECTED_RESERVED_ATTRIBUTE_PREFIX = '57';
  const UNEXPECTED_TYPE = '58';
  const UNKNOWN_CONDITION_TYPE = '59';
  const UNKNOWN_MATCH_TYPE = '60';
  const UNRECOGNIZED_ATTRIBUTE = '61';
  const UNRECOGNIZED_DECIDE_OPTION = '62';
  const USER_NOT_IN_FORCED_VARIATION = '64';
  const USER_PROFILE_LOOKUP_ERROR = '65';
  const USER_PROFILE_SAVE_ERROR = '66';
  const VARIABLE_KEY_NOT_IN_DATAFILE = '67';
  const VARIABLE_REQUESTED_WITH_WRONG_TYPE = '68';
  const VARIATION_ID_NOT_IN_DATAFILE = '69';
  const messages$1 = [
      "BucketingID attribute is not a string. Defaulted to userId",
      "CMAB decision fetch failed with status: %s",
      "Error evaluating audience condition of type %s: %s",
      "Datafile fetch request failed with status: %s",
      "Error fetching datafile: %s",
      "Event action invalid.",
      "Event data invalid.",
      "Event key %s is not in datafile.",
      "Experiment key %s is not in datafile.",
      "Failed to dispatch events, status: %s",
      "failed to send odp events",
      "Feature key %s is not in datafile.",
      "Provided attributes are in an invalid format.",
      "Unable to generate hash for bucketing ID %s: %s",
      "Invalid CMAB fetch response",
      "Provided Optimizely config is in an invalid format.",
      "Datafile is invalid - property %s: %s",
      "Datafile is invalid because it is malformed.",
      "This version of the JavaScript SDK does not support the given datafile version: %s",
      "Provided event tags are in an invalid format.",
      "Experiment ID %s is not in datafile.",
      "Experiment key %s is not in datafile. It is either invalid, paused, or archived.",
      "Group ID %s is not in datafile.",
      "Provided %s is in an invalid format.",
      "JSON object is not valid.",
      "Provided user ID is in an invalid format.",
      "Provided user profile service instance is in an invalid format: %s.",
      "Provided variation key is in an invalid format.",
      "Integration key missing from datafile. All integrations should include a key.",
      "Notification listener for (%s) threw exception: %s",
      "Not tracking user %s.",
      "No datafile specified. Cannot start optimizely.",
      "No event processor is provided",
      "No JSON object to validate against schema.",
      "No project config available. Failing %s.",
      "No status code in response",
      "No variation key %s defined in datafile for experiment %s.",
      "ODP config is not available.",
      "ODP events should have at least one key-value pair in identifiers.",
      "ODP event send failed.",
      "ODP Event failed to send. (ODP Manager not available).",
      "ODP event manager stopped before it could start",
      "ODP is not integrated",
      "Only POST requests are supported",
      "Audience condition %s evaluated to UNKNOWN because the number value for user attribute \"%s\" is not in the range [-2^53, +2^53].",
      "Promise value is not allowed in sync operation",
      "Request error",
      "Request timeout",
      "Retry cancelled",
      "sendBeacon failed",
      "%s not running",
      "unable to bind optimizely.close() to page unload event: \"%s\"",
      "Unable to cast value %s to type %s, returning null.",
      "Unable to get VUID - VuidManager is not available",
      "Unable to parse & skipped header item",
      "Provided attribute: %s has an undefined value.",
      "Audience condition %s evaluated to UNKNOWN because the condition value is not supported.",
      "Attribute %s unexpectedly has reserved prefix %s; using attribute ID instead of reserved attribute name.",
      "Audience condition %s evaluated to UNKNOWN because a value of type \"%s\" was passed for user attribute \"%s\".",
      "Audience condition %s has an unknown condition type. You may need to upgrade to a newer release of the Optimizely SDK.",
      "Audience condition %s uses an unknown match type. You may need to upgrade to a newer release of the Optimizely SDK.",
      "Unrecognized attribute %s provided. Pruning before sending event to Optimizely.",
      "Unrecognized decide option %s provided.",
      "Unsupported protocol: %s",
      "User %s is not in the forced variation map. Cannot remove their forced variation.",
      "Error while looking up user profile for user ID \"%s\": %s.",
      "Error while saving user profile for user ID \"%s\": %s.",
      "Variable with key \"%s\" associated with feature with key \"%s\" is not in datafile.",
      "Requested variable type \"%s\", but variable is of type \"%s\". Use correct API to retrieve value. Returning None.",
      "Variation ID %s is not in the datafile."
  ];

  /**
   * Copyright 2023-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Sample event dispatcher implementation for tracking impression and conversions
   * Users of the SDK can provide their own implementation
   * @param  {Event}    eventObj
   * @param  {Function} callback
   */
  const dispatchEvent = function (eventObj) {
      const { params, url } = eventObj;
      const blob = new Blob([JSON.stringify(params)], {
          type: "application/json",
      });
      const success = navigator.sendBeacon(url, blob);
      if (success) {
          return Promise.resolve({});
      }
      return Promise.reject(new OptimizelyError(SEND_BEACON_FAILED));
  };
  const eventDispatcher$1 = {
      dispatchEvent,
  };

  /**
   * Copyright 2019, 2024, 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  exports.LogLevel = void 0;
  (function (LogLevel) {
      LogLevel[LogLevel["Debug"] = 0] = "Debug";
      LogLevel[LogLevel["Info"] = 1] = "Info";
      LogLevel[LogLevel["Warn"] = 2] = "Warn";
      LogLevel[LogLevel["Error"] = 3] = "Error";
  })(exports.LogLevel || (exports.LogLevel = {}));
  const LogLevelToUpper = {
      [exports.LogLevel.Debug]: 'DEBUG',
      [exports.LogLevel.Info]: 'INFO',
      [exports.LogLevel.Warn]: 'WARN',
      [exports.LogLevel.Error]: 'ERROR',
  };
  const LogLevelToLower = {
      [exports.LogLevel.Debug]: 'debug',
      [exports.LogLevel.Info]: 'info',
      [exports.LogLevel.Warn]: 'warn',
      [exports.LogLevel.Error]: 'error',
  };
  class ConsoleLogHandler {
      constructor(prefix) {
          this.prefix = prefix || '[OPTIMIZELY]';
      }
      log(level, message) {
          const log = `${this.prefix} - ${LogLevelToUpper[level]} ${this.getTime()} ${message}`;
          this.consoleLog(level, log);
      }
      getTime() {
          return new Date().toISOString();
      }
      consoleLog(logLevel, log) {
          const methodName = LogLevelToLower[logLevel];
          const method = console[methodName] || console.log;
          method.call(console, log);
      }
  }
  class OptimizelyLogger {
      constructor(config) {
          this.prefix = '';
          this.logHandler = config.logHandler;
          this.infoResolver = config.infoMsgResolver;
          this.errorResolver = config.errorMsgResolver;
          this.level = config.level;
          if (config.name) {
              this.setName(config.name);
          }
      }
      child(name) {
          return new OptimizelyLogger({
              logHandler: this.logHandler,
              infoMsgResolver: this.infoResolver,
              errorMsgResolver: this.errorResolver,
              level: this.level,
              name,
          });
      }
      setName(name) {
          this.name = name;
          this.prefix = `${name}: `;
      }
      info(message, ...args) {
          this.log(exports.LogLevel.Info, message, args);
      }
      debug(message, ...args) {
          this.log(exports.LogLevel.Debug, message, args);
      }
      warn(message, ...args) {
          this.log(exports.LogLevel.Warn, message, args);
      }
      error(message, ...args) {
          this.log(exports.LogLevel.Error, message, args);
      }
      handleLog(level, message, args) {
          const log = args.length > 0 ? `${this.prefix}${sprintf(message, ...args)}`
              : `${this.prefix}${message}`;
          this.logHandler.log(level, log);
      }
      log(level, message, args) {
          if (level < this.level) {
              return;
          }
          if (message instanceof Error) {
              if (message instanceof OptimizelyError) {
                  message.setMessage(this.errorResolver);
              }
              this.handleLog(level, message.message, []);
              return;
          }
          let resolver = this.errorResolver;
          if (level < exports.LogLevel.Warn) {
              if (!this.infoResolver) {
                  return;
              }
              resolver = this.infoResolver;
          }
          const resolvedMessage = resolver.resolve(message);
          this.handleLog(level, resolvedMessage, args);
      }
  }

  const ADDING_AUTHORIZATION_HEADER_WITH_BEARER_TOKEN = '0';
  const AUDIENCE_EVALUATION_RESULT = '1';
  const EVALUATING_AUDIENCE = '2';
  const FAILED_TO_PARSE_REVENUE = '4';
  const FAILED_TO_PARSE_VALUE = '5';
  const FEATURE_ENABLED_FOR_USER = '6';
  const FEATURE_NOT_ENABLED_FOR_USER = '7';
  const FEATURE_NOT_ENABLED_RETURN_DEFAULT_VARIABLE_VALUE = '8';
  const INVALID_CLIENT_ENGINE = '9';
  const INVALID_DECIDE_OPTIONS = '10';
  const INVALID_DEFAULT_DECIDE_OPTIONS = '11';
  const INVALID_EXPERIMENT_KEY_INFO = '12';
  const MAKING_DATAFILE_REQ_TO_URL_WITH_HEADERS = '13';
  const MISSING_ATTRIBUTE_VALUE = '14';
  const NOT_ACTIVATING_USER = '15';
  const PARSED_NUMERIC_VALUE = '16';
  const PARSED_REVENUE_VALUE = '17';
  const RESPONSE_STATUS_CODE = '18';
  const SAVED_LAST_MODIFIED_HEADER_VALUE_FROM_RESPONSE = '19';
  const SAVED_USER_VARIATION = '20';
  const SAVED_VARIATION_NOT_FOUND = '21';
  const SHOULD_NOT_DISPATCH_ACTIVATE = '22';
  const SKIPPING_JSON_VALIDATION = '23';
  const TRACK_EVENT = '24';
  const UNEXPECTED_TYPE_NULL = '25';
  const UPDATED_OPTIMIZELY_CONFIG = '26';
  const USER_HAS_NO_FORCED_VARIATION = '27';
  const USER_HAS_NO_FORCED_VARIATION_FOR_EXPERIMENT = '28';
  const USER_MAPPED_TO_FORCED_VARIATION = '29';
  const USER_RECEIVED_DEFAULT_VARIABLE_VALUE = '30';
  const USER_RECEIVED_VARIABLE_VALUE = '31';
  const VALID_BUCKETING_ID = '32';
  const VALID_DATAFILE = '33';
  const VALID_USER_PROFILE_SERVICE = '34';
  const VARIABLE_NOT_USED_RETURN_DEFAULT_VARIABLE_VALUE = '35';
  const VARIATION_REMOVED_FOR_USER = '36';
  const messages = [
      "Adding Authorization header with Bearer Token",
      "Audience \"%s\" evaluated to %s.",
      "Starting to evaluate audience \"%s\" with conditions: %s.",
      "Event store is full. Not saving event with id %d.",
      "Failed to parse revenue value \"%s\" from event tags.",
      "Failed to parse event value \"%s\" from event tags.",
      "Feature %s is enabled for user %s.",
      "Feature %s is not enabled for user %s.",
      "Feature \"%s\" is not enabled for user %s. Returning the default variable value \"%s\".",
      "Invalid client engine passed: %s. Defaulting to node-sdk.",
      "Provided decide options is not an array. Using default decide options.",
      "Provided default decide options is not an array.",
      "Experiment key %s is not in datafile. It is either invalid, paused, or archived.",
      "Making datafile request to url %s with headers: %s",
      "Audience condition %s evaluated to UNKNOWN because no value was passed for user attribute \"%s\".",
      "Not activating user %s for experiment %s.",
      "Parsed event value \"%s\" from event tags.",
      "Parsed revenue value \"%s\" from event tags.",
      "Response status code: %s",
      "Saved last modified header value from response: %s",
      "Saved user profile for user \"%s\".",
      "User %s was previously bucketed into variation with ID %s for experiment %s, but no matching variation was found.",
      "Experiment %s is not in \"Running\" state. Not activating user.",
      "Skipping JSON schema validation.",
      "Tracking event %s for user %s.",
      "Audience condition %s evaluated to UNKNOWN because a null value was passed for user attribute \"%s\".",
      "Updated Optimizely config to revision %s (project id %s)",
      "User %s is not in the forced variation map.",
      "No experiment %s mapped to user %s in the forced variation map.",
      "Set variation %s for experiment %s and user %s in the forced variation map.",
      "User \"%s\" is not in any variation or rollout rule. Returning default value for variable \"%s\" of feature flag \"%s\".",
      "Got variable value \"%s\" for variable \"%s\" of feature flag \"%s\"",
      "BucketingId is valid: \"%s\"",
      "Datafile is valid.",
      "Valid user profile service provided.",
      "Variable \"%s\" is not used in variation \"%s\". Returning default value.",
      "Variation mapped to experiment %s has been removed for user %s."
  ];

  const infoResolver = {
      resolve(baseMessage) {
          const messageNum = parseInt(baseMessage);
          return messages[messageNum] || baseMessage;
      }
  };
  const errorResolver = {
      resolve(baseMessage) {
          const messageNum = parseInt(baseMessage);
          return messages$1[messageNum] || baseMessage;
      }
  };

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const INVALID_LOG_HANDLER = 'Invalid log handler';
  const INVALID_LEVEL_PRESET = 'Invalid level preset';
  const debugPreset = {
      level: exports.LogLevel.Debug,
      infoResolver,
      errorResolver,
  };
  const infoPreset = {
      level: exports.LogLevel.Info,
      infoResolver,
      errorResolver,
  };
  const warnPreset = {
      level: exports.LogLevel.Warn,
      errorResolver,
  };
  const errorPreset = {
      level: exports.LogLevel.Error,
      errorResolver,
  };
  const levelPresetSymbol = Symbol();
  const DEBUG = {
      [levelPresetSymbol]: debugPreset,
  };
  const INFO = {
      [levelPresetSymbol]: infoPreset,
  };
  const WARN = {
      [levelPresetSymbol]: warnPreset,
  };
  const ERROR = {
      [levelPresetSymbol]: errorPreset,
  };
  const extractLevelPreset = (preset) => {
      if (!preset || typeof preset !== 'object' || !preset[levelPresetSymbol]) {
          throw new Error(INVALID_LEVEL_PRESET);
      }
      return preset[levelPresetSymbol];
  };
  const loggerSymbol = Symbol();
  const validateLogHandler = (logHandler) => {
      if (typeof logHandler !== 'object' || typeof logHandler.log !== 'function') {
          throw new Error(INVALID_LOG_HANDLER);
      }
  };
  const createLogger = (config) => {
      const { level, infoResolver, errorResolver } = extractLevelPreset(config.level);
      if (config.logHandler) {
          validateLogHandler(config.logHandler);
      }
      const loggerName = 'Optimizely';
      return {
          [loggerSymbol]: new OptimizelyLogger({
              name: loggerName,
              level,
              infoMsgResolver: infoResolver,
              errorMsgResolver: errorResolver,
              logHandler: config.logHandler || new ConsoleLogHandler(),
          }),
      };
  };
  const extractLogger = (logger) => {
      if (!logger || typeof logger !== 'object') {
          return undefined;
      }
      return logger[loggerSymbol];
  };

  class DefaultErrorNotifier {
      constructor(errorHandler, messageResolver, name) {
          this.errorHandler = errorHandler;
          this.messageResolver = messageResolver;
          this.name = name || '';
      }
      notify(error) {
          if (error instanceof OptimizelyError) {
              error.setMessage(this.messageResolver);
          }
          this.errorHandler.handleError(error);
      }
      child(name) {
          return new DefaultErrorNotifier(this.errorHandler, this.messageResolver, name);
      }
  }

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const INVALID_ERROR_HANDLER = 'Invalid error handler';
  const errorNotifierSymbol = Symbol();
  const validateErrorHandler = (errorHandler) => {
      if (!errorHandler || typeof errorHandler !== 'object' || typeof errorHandler.handleError !== 'function') {
          throw new Error(INVALID_ERROR_HANDLER);
      }
  };
  const createErrorNotifier = (errorHandler) => {
      validateErrorHandler(errorHandler);
      return {
          [errorNotifierSymbol]: new DefaultErrorNotifier(errorHandler, errorResolver),
      };
  };
  const extractErrorNotifier = (errorNotifier) => {
      if (!errorNotifier || typeof errorNotifier !== 'object') {
          return undefined;
      }
      return errorNotifier[errorNotifierSymbol];
  };

  /****************************************************************************
   * Copyright 2018, 2021, Optimizely, Inc. and contributors                  *
   *                                                                          *
   * Licensed under the Apache License, Version 2.0 (the "License");          *
   * you may not use this file except in compliance with the License.         *
   * You may obtain a copy of the License at                                  *
   *                                                                          *
   *    http://www.apache.org/licenses/LICENSE-2.0                            *
   *                                                                          *
   * Unless required by applicable law or agreed to in writing, software      *
   * distributed under the License is distributed on an "AS IS" BASIS,        *
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
   * See the License for the specific language governing permissions and      *
   * limitations under the License.                                           *
   ***************************************************************************/
  const AND_CONDITION = 'and';
  const OR_CONDITION = 'or';
  const NOT_CONDITION = 'not';
  const DEFAULT_OPERATOR_TYPES = [AND_CONDITION, OR_CONDITION, NOT_CONDITION];
  /**
   * Top level method to evaluate conditions
   * @param  {ConditionTree<Leaf>}    conditions      Nested array of and/or conditions, or a single leaf
   *                                                  condition value of any type
   *                                                  Example: ['and', '0', ['or', '1', '2']]
   * @param  {LeafEvaluator<Leaf>}    leafEvaluator   Function which will be called to evaluate leaf condition
   *                                                  values
   * @return {?boolean}                               Result of evaluating the conditions using the operator
   *                                                  rules and the leaf evaluator. A return value of null
   *                                                  indicates that the conditions are invalid or unable to be
   *                                                  evaluated.
   */
  function evaluate$2(conditions, leafEvaluator) {
      if (Array.isArray(conditions)) {
          let firstOperator = conditions[0];
          let restOfConditions = conditions.slice(1);
          if (typeof firstOperator === 'string' && DEFAULT_OPERATOR_TYPES.indexOf(firstOperator) === -1) {
              // Operator to apply is not explicit - assume 'or'
              firstOperator = OR_CONDITION;
              restOfConditions = conditions;
          }
          switch (firstOperator) {
              case AND_CONDITION:
                  return andEvaluator(restOfConditions, leafEvaluator);
              case NOT_CONDITION:
                  return notEvaluator(restOfConditions, leafEvaluator);
              default:
                  // firstOperator is OR_CONDITION
                  return orEvaluator(restOfConditions, leafEvaluator);
          }
      }
      const leafCondition = conditions;
      return leafEvaluator(leafCondition);
  }
  /**
   * Evaluates an array of conditions as if the evaluator had been applied
   * to each entry and the results AND-ed together.
   * @param  {unknown[]}             conditions      Array of conditions ex: [operand_1, operand_2]
   * @param  {LeafEvaluator<Leaf>}   leafEvaluator   Function which will be called to evaluate leaf condition values
   * @return {?boolean}                              Result of evaluating the conditions. A return value of null
   *                                                 indicates that the conditions are invalid or unable to be
   *                                                 evaluated.
   */
  function andEvaluator(conditions, leafEvaluator) {
      let sawNullResult = false;
      if (Array.isArray(conditions)) {
          for (let i = 0; i < conditions.length; i++) {
              const conditionResult = evaluate$2(conditions[i], leafEvaluator);
              if (conditionResult === false) {
                  return false;
              }
              if (conditionResult === null) {
                  sawNullResult = true;
              }
          }
          return sawNullResult ? null : true;
      }
      return null;
  }
  /**
   * Evaluates an array of conditions as if the evaluator had been applied
   * to a single entry and NOT was applied to the result.
   * @param  {unknown[]}             conditions      Array of conditions ex: [operand_1]
   * @param  {LeafEvaluator<Leaf>}   leafEvaluator   Function which will be called to evaluate leaf condition values
   * @return {?boolean}                              Result of evaluating the conditions. A return value of null
   *                                                 indicates that the conditions are invalid or unable to be
   *                                                 evaluated.
   */
  function notEvaluator(conditions, leafEvaluator) {
      if (Array.isArray(conditions) && conditions.length > 0) {
          const result = evaluate$2(conditions[0], leafEvaluator);
          return result === null ? null : !result;
      }
      return null;
  }
  /**
   * Evaluates an array of conditions as if the evaluator had been applied
   * to each entry and the results OR-ed together.
   * @param  {unknown[]}             conditions      Array of conditions ex: [operand_1, operand_2]
   * @param  {LeafEvaluator<Leaf>}   leafEvaluator   Function which will be called to evaluate leaf condition values
   * @return {?boolean}                              Result of evaluating the conditions. A return value of null
   *                                                 indicates that the conditions are invalid or unable to be
   *                                                 evaluated.
   */
  function orEvaluator(conditions, leafEvaluator) {
      let sawNullResult = false;
      if (Array.isArray(conditions)) {
          for (let i = 0; i < conditions.length; i++) {
              const conditionResult = evaluate$2(conditions[i], leafEvaluator);
              if (conditionResult === true) {
                  return true;
              }
              if (conditionResult === null) {
                  sawNullResult = true;
              }
          }
          return sawNullResult ? null : false;
      }
      return null;
  }

  /**
   * The OptimizelyConfig class
   * @param {ProjectConfig} configObj
   * @param {string}        datafile
   */
  class OptimizelyConfig {
      constructor(configObj, datafile, logger) {
          var _a, _b;
          this.sdkKey = (_a = configObj.sdkKey) !== null && _a !== void 0 ? _a : '';
          this.environmentKey = (_b = configObj.environmentKey) !== null && _b !== void 0 ? _b : '';
          this.attributes = configObj.attributes;
          this.audiences = OptimizelyConfig.getAudiences(configObj);
          this.events = configObj.events;
          this.revision = configObj.revision;
          const featureIdVariablesMap = (configObj.featureFlags || []).reduce((resultMap, feature) => {
              resultMap[feature.id] = feature.variables;
              return resultMap;
          }, {});
          const variableIdMap = OptimizelyConfig.getVariableIdMap(configObj);
          const { experimentsMapById, experimentsMapByKey } = OptimizelyConfig.getExperimentsMap(configObj, featureIdVariablesMap, variableIdMap, logger);
          this.experimentsMap = experimentsMapByKey;
          this.featuresMap = OptimizelyConfig.getFeaturesMap(configObj, featureIdVariablesMap, experimentsMapById, variableIdMap);
          this.datafile = datafile;
      }
      /**
       * Get the datafile
       * @returns {string} JSON string representation of the datafile that was used to create the current config object
       */
      getDatafile() {
          return this.datafile;
      }
      /**
       * Get Unique audiences list with typedAudiences as priority
       * @param       {ProjectConfig}              configObj
       * @returns     {OptimizelyAudience[]}       Array of unique audiences
       */
      static getAudiences(configObj) {
          const audiences = [];
          const typedAudienceIds = [];
          (configObj.typedAudiences || []).forEach((typedAudience) => {
              audiences.push({
                  id: typedAudience.id,
                  conditions: JSON.stringify(typedAudience.conditions),
                  name: typedAudience.name,
              });
              typedAudienceIds.push(typedAudience.id);
          });
          (configObj.audiences || []).forEach((audience) => {
              if (typedAudienceIds.indexOf(audience.id) === -1 && audience.id != '$opt_dummy_audience') {
                  audiences.push({
                      id: audience.id,
                      conditions: JSON.stringify(audience.conditions),
                      name: audience.name,
                  });
              }
          });
          return audiences;
      }
      /**
       * Converts list of audience conditions to serialized audiences used in experiment
       * for examples:
       * 1. Input: ["or", "1", "2"]
       * Output: "\"us\" OR \"female\""
       * 2. Input: ["not", "1"]
       * Output: "NOT \"us\""
       * 3. Input: ["or", "1"]
       * Output: "\"us\""
       * 4. Input: ["and", ["or", "1", ["and", "2", "3"]], ["and", "11", ["or", "12", "13"]]]
       * Output: "(\"us\" OR (\"female\" AND \"adult\")) AND (\"fr\" AND (\"male\" OR \"kid\"))"
       * @param       {Array<string | string[]>}                 conditions
       * @param       {[id: string]: Audience}                   audiencesById
       * @returns     {string}                                   Serialized audiences condition string
       */
      static getSerializedAudiences(conditions, audiencesById) {
          let serializedAudience = '';
          if (conditions) {
              let cond = '';
              conditions.forEach((item) => {
                  let subAudience = '';
                  // Checks if item is list of conditions means it is sub audience
                  if (item instanceof Array) {
                      subAudience = OptimizelyConfig.getSerializedAudiences(item, audiencesById);
                      subAudience = `(${subAudience})`;
                  }
                  else if (DEFAULT_OPERATOR_TYPES.indexOf(item) > -1) {
                      cond = item.toUpperCase();
                  }
                  else {
                      // Checks if item is audience id
                      const audienceName = audiencesById[item] ? audiencesById[item].name : item;
                      // if audience condition is "NOT" then add "NOT" at start. Otherwise check if there is already audience id in serializedAudience then append condition between serializedAudience and item
                      if (serializedAudience || cond === 'NOT') {
                          cond = cond === '' ? 'OR' : cond;
                          if (serializedAudience === '') {
                              serializedAudience = `${cond} "${audiencesById[item].name}"`;
                          }
                          else {
                              serializedAudience = serializedAudience.concat(` ${cond} "${audienceName}"`);
                          }
                      }
                      else {
                          serializedAudience = `"${audienceName}"`;
                      }
                  }
                  // Checks if sub audience is empty or not
                  if (subAudience !== '') {
                      if (serializedAudience !== '' || cond === 'NOT') {
                          cond = cond === '' ? 'OR' : cond;
                          if (serializedAudience === '') {
                              serializedAudience = `${cond} ${subAudience}`;
                          }
                          else {
                              serializedAudience = serializedAudience.concat(` ${cond} ${subAudience}`);
                          }
                      }
                      else {
                          serializedAudience = serializedAudience.concat(subAudience);
                      }
                  }
              });
          }
          return serializedAudience;
      }
      /**
       * Get serialized audience condition string for experiment
       * @param       {Experiment}                 experiment
       * @param       {ProjectConfig}              configObj
       * @returns     {string}                     Serialized audiences condition string
       */
      static getExperimentAudiences(experiment, configObj) {
          if (!experiment.audienceConditions) {
              return '';
          }
          return OptimizelyConfig.getSerializedAudiences(experiment.audienceConditions, configObj.audiencesById);
      }
      /**
       * Make map of featureVariable which are associated with given feature experiment
       * @param       {FeatureVariablesMap}                 featureIdVariableMap
       * @param       {[id: string]: FeatureVariable}       variableIdMap
       * @param       {string}                              featureId
       * @param       {VariationVariable[] | undefined}     featureVariableUsages
       * @param       {boolean | undefined}                 isFeatureEnabled
       * @returns     {OptimizelyVariablesMap}              FeatureVariables mapped by key
       */
      static mergeFeatureVariables(featureIdVariableMap, variableIdMap, featureId, featureVariableUsages, isFeatureEnabled) {
          const variablesMap = (featureIdVariableMap[featureId] || []).reduce((optlyVariablesMap, featureVariable) => {
              optlyVariablesMap[featureVariable.key] = {
                  id: featureVariable.id,
                  key: featureVariable.key,
                  type: featureVariable.type,
                  value: featureVariable.defaultValue,
              };
              return optlyVariablesMap;
          }, {});
          (featureVariableUsages || []).forEach((featureVariableUsage) => {
              const defaultVariable = variableIdMap[featureVariableUsage.id];
              const optimizelyVariable = {
                  id: featureVariableUsage.id,
                  key: defaultVariable.key,
                  type: defaultVariable.type,
                  value: isFeatureEnabled ? featureVariableUsage.value : defaultVariable.defaultValue,
              };
              variablesMap[defaultVariable.key] = optimizelyVariable;
          });
          return variablesMap;
      }
      /**
       * Gets Map of all experiment variations and variables including rollouts
       * @param       {Variation[]}                           variations
       * @param       {FeatureVariablesMap}                   featureIdVariableMap
       * @param       {{[id: string]: FeatureVariable}}       variableIdMap
       * @param       {string}                                featureId
       * @returns     {[key: string]: Variation}              Variations mapped by key
       */
      static getVariationsMap(variations, featureIdVariableMap, variableIdMap, featureId) {
          let variationsMap = {};
          variationsMap = variations.reduce((optlyVariationsMap, variation) => {
              const variablesMap = OptimizelyConfig.mergeFeatureVariables(featureIdVariableMap, variableIdMap, featureId, variation.variables, variation.featureEnabled);
              optlyVariationsMap[variation.key] = {
                  id: variation.id,
                  key: variation.key,
                  featureEnabled: variation.featureEnabled,
                  variablesMap: variablesMap,
              };
              return optlyVariationsMap;
          }, {});
          return variationsMap;
      }
      /**
       * Gets Map of FeatureVariable with respect to featureVariableId
       * @param       {ProjectConfig}                        configObj
       * @returns     {[id: string]: FeatureVariable}        FeatureVariables mapped by id
       */
      static getVariableIdMap(configObj) {
          let variablesIdMap = {};
          variablesIdMap = (configObj.featureFlags || []).reduce((resultMap, feature) => {
              feature.variables.forEach((variable) => {
                  resultMap[variable.id] = variable;
              });
              return resultMap;
          }, {});
          return variablesIdMap;
      }
      /**
       * Gets list of rollout experiments
       * @param       {ProjectConfig}                     configObj
       * @param       {FeatureVariablesMap}               featureVariableIdMap
       * @param       {string}                            featureId
       * @param       {Experiment[]}                      experiments
       * @param       {{[id: string]: FeatureVariable}}   variableIdMap
       * @returns     {OptimizelyExperiment[]}            List of Optimizely rollout experiments
       */
      static getDeliveryRules(configObj, featureVariableIdMap, featureId, experiments, variableIdMap) {
          return experiments.map((experiment) => {
              return {
                  id: experiment.id,
                  key: experiment.key,
                  audiences: OptimizelyConfig.getExperimentAudiences(experiment, configObj),
                  variationsMap: OptimizelyConfig.getVariationsMap(experiment.variations, featureVariableIdMap, variableIdMap, featureId),
              };
          });
      }
      /**
       * Get Experiment Ids which are part of rollout
       * @param       {Rollout[]}     rollouts
       * @returns     {string[]}      Array of experiment Ids
       */
      static getRolloutExperimentIds(rollouts) {
          const experimentIds = [];
          (rollouts || []).forEach((rollout) => {
              rollout.experiments.forEach((e) => {
                  experimentIds.push(e.id);
              });
          });
          return experimentIds;
      }
      /**
       * Get experiments mapped by their id's which are not part of a rollout
       * @param       {ProjectConfig}                           configObj
       * @param       {FeatureVariablesMap}                     featureIdVariableMap
       * @param       {{[id: string]: FeatureVariable}}         variableIdMap
       * @returns     { experimentsMapById: { [id: string]: OptimizelyExperiment }, experimentsMapByKey: OptimizelyExperimentsMap }      Experiments mapped by id and key
       */
      static getExperimentsMap(configObj, featureIdVariableMap, variableIdMap, logger) {
          const rolloutExperimentIds = this.getRolloutExperimentIds(configObj.rollouts);
          const experimentsMapById = {};
          const experimentsMapByKey = {};
          const experiments = configObj.experiments || [];
          experiments.forEach((experiment) => {
              if (rolloutExperimentIds.indexOf(experiment.id) !== -1) {
                  return;
              }
              const featureIds = configObj.experimentFeatureMap[experiment.id];
              let featureId = '';
              if (featureIds && featureIds.length > 0) {
                  featureId = featureIds[0];
              }
              const variationsMap = OptimizelyConfig.getVariationsMap(experiment.variations, featureIdVariableMap, variableIdMap, featureId.toString());
              const optimizelyExperiment = {
                  id: experiment.id,
                  key: experiment.key,
                  audiences: OptimizelyConfig.getExperimentAudiences(experiment, configObj),
                  variationsMap: variationsMap,
              };
              experimentsMapById[experiment.id] = optimizelyExperiment;
              if (experimentsMapByKey[experiment.key] && logger) {
                  logger.warn(`Duplicate experiment keys found in datafile: ${experiment.key}`);
              }
              experimentsMapByKey[experiment.key] = optimizelyExperiment;
          });
          return { experimentsMapById, experimentsMapByKey };
      }
      /**
       * Get experiments mapped by their keys
       * @param       {OptimizelyExperimentsMap}     experimentsMapById
       * @returns     {OptimizelyExperimentsMap}     Experiments mapped by key
       */
      static getExperimentsKeyMap(experimentsMapById) {
          const experimentKeysMap = {};
          for (const id in experimentsMapById) {
              const experiment = experimentsMapById[id];
              experimentKeysMap[experiment.key] = experiment;
          }
          return experimentKeysMap;
      }
      /**
       * Gets Map of all FeatureFlags and associated experiment map inside it
       * @param       {ProjectConfig}                     configObj
       * @param       {FeatureVariablesMap}               featureVariableIdMap
       * @param       {OptimizelyExperimentsMap}          experimentsMapById
       * @param       {{[id: string]: FeatureVariable}}   variableIdMap
       * @returns     {OptimizelyFeaturesMap}             OptimizelyFeature mapped by key
       */
      static getFeaturesMap(configObj, featureVariableIdMap, experimentsMapById, variableIdMap) {
          const featuresMap = {};
          configObj.featureFlags.forEach((featureFlag) => {
              const featureExperimentMap = {};
              const experimentRules = [];
              featureFlag.experimentIds.forEach(experimentId => {
                  const experiment = experimentsMapById[experimentId];
                  if (experiment) {
                      featureExperimentMap[experiment.key] = experiment;
                  }
                  experimentRules.push(experimentsMapById[experimentId]);
              });
              const featureVariableMap = (featureFlag.variables || []).reduce((variables, variable) => {
                  variables[variable.key] = {
                      id: variable.id,
                      key: variable.key,
                      type: variable.type,
                      value: variable.defaultValue,
                  };
                  return variables;
              }, {});
              let deliveryRules = [];
              const rollout = configObj.rolloutIdMap[featureFlag.rolloutId];
              if (rollout) {
                  deliveryRules = OptimizelyConfig.getDeliveryRules(configObj, featureVariableIdMap, featureFlag.id, rollout.experiments, variableIdMap);
              }
              featuresMap[featureFlag.key] = {
                  id: featureFlag.id,
                  key: featureFlag.key,
                  experimentRules: experimentRules,
                  deliveryRules: deliveryRules,
                  experimentsMap: featureExperimentMap,
                  variablesMap: featureVariableMap,
              };
          });
          return featuresMap;
      }
  }
  /**
   * Create an instance of OptimizelyConfig
   * @param   {ProjectConfig}             configObj
   * @param   {string}                    datafile
   * @returns {OptimizelyConfig}          An instance of OptimizelyConfig
   */
  function createOptimizelyConfig(configObj, datafile, logger) {
      return new OptimizelyConfig(configObj, datafile, logger);
  }

  /**
   * Copyright 2016-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const CONTROL_ATTRIBUTES = {
      BOT_FILTERING: '$opt_bot_filtering',
      BUCKETING_ID: '$opt_bucketing_id',
      STICKY_BUCKETING_KEY: '$opt_experiment_bucket_map',
      USER_AGENT: '$opt_user_agent',
  };
  const JAVASCRIPT_CLIENT_ENGINE = 'javascript-sdk';
  const NODE_CLIENT_ENGINE = 'node-sdk';
  const CLIENT_VERSION = '6.0.0';
  /*
   * Represents the source of a decision for feature management. When a feature
   * is accessed through isFeatureEnabled or getVariableValue APIs, the decision
   * source is used to decide whether to dispatch an impression event to
   * Optimizely.
   */
  const DECISION_SOURCES = {
      FEATURE_TEST: 'feature-test',
      ROLLOUT: 'rollout',
      EXPERIMENT: 'experiment',
  };
  const AUDIENCE_EVALUATION_TYPES = {
      RULE: 'rule',
      EXPERIMENT: 'experiment',
  };
  /*
   * Possible types of variables attached to features
   */
  const FEATURE_VARIABLE_TYPES = {
      BOOLEAN: 'boolean',
      DOUBLE: 'double',
      INTEGER: 'integer',
      STRING: 'string',
      JSON: 'json',
  };
  /*
   * Supported datafile versions
   */
  const DATAFILE_VERSIONS = {
      V2: '2',
      V3: '3',
      V4: '4',
  };
  const DECISION_MESSAGES = {
      SDK_NOT_READY: 'Optimizely SDK not configured properly yet.',
      FLAG_KEY_INVALID: 'No flag was found for key "%s".',
      VARIABLE_VALUE_INVALID: 'Variable value for key "%s" is invalid or wrong type.',
  };
  /**
   * Default milliseconds before request timeout
   */
  const REQUEST_TIMEOUT_MS = 60 * 1000; // 1 minute
  const DEFAULT_CMAB_CACHE_TIMEOUT = 30 * 60 * 1000; // 30 minutes
  const DEFAULT_CMAB_CACHE_SIZE = 1000;

  /**
   * Copyright 2016, 2018-2020, 2022, 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const SUPPORTED_VERSIONS = [DATAFILE_VERSIONS.V2, DATAFILE_VERSIONS.V3, DATAFILE_VERSIONS.V4];
  /**
   * Validates the datafile
   * @param {Object|string}  datafile
   * @return {Object} The datafile object if the datafile is valid
   * @throws If the datafile is not valid for any of the following reasons:
   - The datafile string is undefined
   - The datafile string cannot be parsed as a JSON object
   - The datafile version is not supported
   */
  // eslint-disable-next-line
  const validateDatafile = function (datafile) {
      if (!datafile) {
          throw new OptimizelyError(NO_DATAFILE_SPECIFIED);
      }
      if (typeof datafile === 'string') {
          // Attempt to parse the datafile string
          try {
              datafile = JSON.parse(datafile);
          }
          catch (ex) {
              throw new OptimizelyError(INVALID_DATAFILE_MALFORMED);
          }
      }
      if (typeof datafile === 'object' && !Array.isArray(datafile) && datafile !== null) {
          if (SUPPORTED_VERSIONS.indexOf(datafile['version']) === -1) {
              throw new OptimizelyError(INVALID_DATAFILE_VERSION, datafile['version']);
          }
      }
      else {
          throw new OptimizelyError(INVALID_DATAFILE_MALFORMED);
      }
      return datafile;
  };
  var configValidator = {
      validateDatafile: validateDatafile,
  };

  /**
   * Copyright 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class OdpConfig {
      constructor(apiKey, apiHost, pixelUrl, segmentsToCheck) {
          this.apiKey = apiKey;
          this.apiHost = apiHost;
          this.pixelUrl = pixelUrl;
          this.segmentsToCheck = segmentsToCheck;
      }
      /**
       * Detects if there are any changes between the current and incoming ODP Configs
       * @param configToCompare ODP Configuration to check self against for equality
       * @returns Boolean based on if the current ODP Config is equivalent to the incoming ODP Config
       */
      equals(configToCompare) {
          return (this.apiHost === configToCompare.apiHost &&
              this.apiKey === configToCompare.apiKey &&
              this.pixelUrl === configToCompare.pixelUrl &&
              checkArrayEquality(this.segmentsToCheck, configToCompare.segmentsToCheck));
      }
  }
  const odpIntegrationsAreEqual = (config1, config2) => {
      if (config1.integrated !== config2.integrated) {
          return false;
      }
      if (config1.integrated && config2.integrated) {
          return config1.odpConfig.equals(config2.odpConfig);
      }
      return true;
  };

  /**
   * Copyright 2016-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const EXPERIMENT_RUNNING_STATUS = 'Running';
  const RESERVED_ATTRIBUTE_PREFIX = '$opt_';
  // eslint-disable-next-line  @typescript-eslint/no-explicit-any
  function createMutationSafeDatafileCopy(datafile) {
      var _a, _b;
      const datafileCopy = Object.assign({}, datafile);
      datafileCopy.audiences = (datafile.audiences || []).map((audience) => {
          return Object.assign({}, audience);
      });
      datafileCopy.experiments = (datafile.experiments || []).map((experiment) => {
          return Object.assign({}, experiment);
      });
      datafileCopy.featureFlags = (datafile.featureFlags || []).map((featureFlag) => {
          return Object.assign({}, featureFlag);
      });
      datafileCopy.groups = (datafile.groups || []).map((group) => {
          const groupCopy = Object.assign({}, group);
          groupCopy.experiments = (group.experiments || []).map(experiment => {
              return Object.assign({}, experiment);
          });
          return groupCopy;
      });
      datafileCopy.rollouts = (datafile.rollouts || []).map((rollout) => {
          const rolloutCopy = Object.assign({}, rollout);
          rolloutCopy.experiments = (rollout.experiments || []).map(experiment => {
              return Object.assign({}, experiment);
          });
          return rolloutCopy;
      });
      datafileCopy.environmentKey = (_a = datafile.environmentKey) !== null && _a !== void 0 ? _a : '';
      datafileCopy.sdkKey = (_b = datafile.sdkKey) !== null && _b !== void 0 ? _b : '';
      return datafileCopy;
  }
  /**
   * Creates projectConfig object to be used for quick project property lookup
   * @param  {Object}        datafileObj   JSON datafile representing the project
   * @param  {string|null}   datafileStr   JSON string representation of the datafile
   * @return {ProjectConfig} Object representing project configuration
   */
  const createProjectConfig = function (datafileObj, datafileStr = null) {
      const projectConfig = createMutationSafeDatafileCopy(datafileObj);
      projectConfig.__datafileStr = datafileStr === null ? JSON.stringify(datafileObj) : datafileStr;
      /*
       * Conditions of audiences in projectConfig.typedAudiences are not
       * expected to be string-encoded as they are here in projectConfig.audiences.
       */
      (projectConfig.audiences || []).forEach(audience => {
          audience.conditions = JSON.parse(audience.conditions);
      });
      projectConfig.audiencesById = Object.assign(Object.assign({}, keyBy(projectConfig.audiences, 'id')), keyBy(projectConfig.typedAudiences, 'id'));
      projectConfig.attributes = projectConfig.attributes || [];
      projectConfig.attributeKeyMap = {};
      projectConfig.attributeIdMap = {};
      projectConfig.attributes.forEach(attribute => {
          projectConfig.attributeKeyMap[attribute.key] = attribute;
          projectConfig.attributeIdMap[attribute.id] = attribute;
      });
      projectConfig.eventKeyMap = keyBy(projectConfig.events, 'key');
      projectConfig.groupIdMap = keyBy(projectConfig.groups, 'id');
      let experiments;
      Object.keys(projectConfig.groupIdMap || {}).forEach(Id => {
          experiments = projectConfig.groupIdMap[Id].experiments;
          (experiments || []).forEach(experiment => {
              experiment.groupId = Id;
              projectConfig.experiments.push(experiment);
          });
      });
      projectConfig.rolloutIdMap = keyBy(projectConfig.rollouts || [], 'id');
      objectValues(projectConfig.rolloutIdMap || {}).forEach(rollout => {
          (rollout.experiments || []).forEach(experiment => {
              experiment.isRollout = true;
              projectConfig.experiments.push(experiment);
              // Creates { <variationKey>: <variation> } map inside of the experiment
              experiment.variationKeyMap = keyBy(experiment.variations, 'key');
          });
      });
      const allSegmentsSet = new Set();
      Object.keys(projectConfig.audiencesById)
          .map(audience => getAudienceSegments(projectConfig.audiencesById[audience]))
          .forEach(audienceSegments => {
          audienceSegments.forEach(segment => {
              allSegmentsSet.add(segment);
          });
      });
      const allSegments = Array.from(allSegmentsSet);
      let odpIntegrated = false;
      let odpApiHost = '';
      let odpApiKey = '';
      let odpPixelUrl = '';
      if (projectConfig.integrations) {
          projectConfig.integrationKeyMap = keyBy(projectConfig.integrations, 'key');
          projectConfig.integrations.forEach(integration => {
              if (!('key' in integration)) {
                  throw new OptimizelyError(MISSING_INTEGRATION_KEY);
              }
              if (integration.key === 'odp') {
                  odpIntegrated = true;
                  odpApiKey = odpApiKey || integration.publicKey || '';
                  odpApiHost = odpApiHost || integration.host || '';
                  odpPixelUrl = odpPixelUrl || integration.pixelUrl || '';
              }
          });
      }
      if (odpIntegrated) {
          projectConfig.odpIntegrationConfig = {
              integrated: true,
              odpConfig: new OdpConfig(odpApiKey, odpApiHost, odpPixelUrl, allSegments),
          };
      }
      else {
          projectConfig.odpIntegrationConfig = { integrated: false };
      }
      projectConfig.experimentKeyMap = keyBy(projectConfig.experiments, 'key');
      projectConfig.experimentIdMap = keyBy(projectConfig.experiments, 'id');
      projectConfig.variationIdMap = {};
      projectConfig.variationVariableUsageMap = {};
      (projectConfig.experiments || []).forEach(experiment => {
          // Creates { <variationKey>: <variation> } map inside of the experiment
          experiment.variationKeyMap = keyBy(experiment.variations, 'key');
          // Creates { <variationId>: { key: <variationKey>, id: <variationId> } } mapping for quick lookup
          projectConfig.variationIdMap = Object.assign(Object.assign({}, projectConfig.variationIdMap), keyBy(experiment.variations, 'id'));
          objectValues(experiment.variationKeyMap || {}).forEach(variation => {
              if (variation.variables) {
                  projectConfig.variationVariableUsageMap[variation.id] = keyBy(variation.variables, 'id');
              }
          });
      });
      // Object containing experiment Ids that exist in any feature
      // for checking that experiment is a feature experiment or not.
      projectConfig.experimentFeatureMap = {};
      projectConfig.featureKeyMap = keyBy(projectConfig.featureFlags || [], 'key');
      objectValues(projectConfig.featureKeyMap || {}).forEach(feature => {
          // Json type is represented in datafile as a subtype of string for the sake of backwards compatibility.
          // Converting it to a first-class json type while creating Project Config
          feature.variables.forEach(variable => {
              if (variable.type === FEATURE_VARIABLE_TYPES.STRING && variable.subType === FEATURE_VARIABLE_TYPES.JSON) {
                  variable.type = FEATURE_VARIABLE_TYPES.JSON;
                  delete variable.subType;
              }
          });
          feature.variableKeyMap = keyBy(feature.variables, 'key');
          (feature.experimentIds || []).forEach(experimentId => {
              // Add this experiment in experiment-feature map.
              if (projectConfig.experimentFeatureMap[experimentId]) {
                  projectConfig.experimentFeatureMap[experimentId].push(feature.id);
              }
              else {
                  projectConfig.experimentFeatureMap[experimentId] = [feature.id];
              }
          });
      });
      // all rules (experiment rules and delivery rules) for each flag
      projectConfig.flagRulesMap = {};
      (projectConfig.featureFlags || []).forEach(featureFlag => {
          const flagRuleExperiments = [];
          featureFlag.experimentIds.forEach(experimentId => {
              const experiment = projectConfig.experimentIdMap[experimentId];
              if (experiment) {
                  flagRuleExperiments.push(experiment);
              }
          });
          const rollout = projectConfig.rolloutIdMap[featureFlag.rolloutId];
          if (rollout) {
              flagRuleExperiments.push(...rollout.experiments);
          }
          projectConfig.flagRulesMap[featureFlag.key] = flagRuleExperiments;
      });
      // all variations for each flag
      // - datafile does not contain a separate entity for this.
      // - we collect variations used in each rule (experiment rules and delivery rules)
      projectConfig.flagVariationsMap = {};
      objectEntries(projectConfig.flagRulesMap || {}).forEach(([flagKey, rules]) => {
          const variations = [];
          rules.forEach(rule => {
              rule.variations.forEach(variation => {
                  if (!find(variations, item => item.id === variation.id)) {
                      variations.push(variation);
                  }
              });
          });
          projectConfig.flagVariationsMap[flagKey] = variations;
      });
      return projectConfig;
  };
  /**
   * Extract all audience segments used in this audience's conditions
   * @param  {Audience}     audience  Object representing the audience being parsed
   * @return {string[]}               List of all audience segments
   */
  const getAudienceSegments = function (audience) {
      if (!audience.conditions)
          return [];
      return getSegmentsFromConditions(audience.conditions);
  };
  // eslint-disable-next-line  @typescript-eslint/no-explicit-any
  const getSegmentsFromConditions = (condition) => {
      const segments = [];
      if (isLogicalOperator(condition)) {
          return [];
      }
      else if (Array.isArray(condition)) {
          condition.forEach(nextCondition => segments.push(...getSegmentsFromConditions(nextCondition)));
      }
      else if (condition['match'] === 'qualified') {
          segments.push(condition['value']);
      }
      return segments;
  };
  function isLogicalOperator(condition) {
      return ['and', 'or', 'not'].includes(condition);
  }
  /**
   * Get layer ID for the provided experiment key
   * @param  {ProjectConfig}    projectConfig   Object representing project configuration
   * @param  {string}           experimentId    Experiment ID for which layer ID is to be determined
   * @return {string}                           Layer ID corresponding to the provided experiment key
   * @throws If experiment key is not in datafile
   */
  const getLayerId = function (projectConfig, experimentId) {
      const experiment = projectConfig.experimentIdMap[experimentId];
      if (!experiment) {
          throw new OptimizelyError(INVALID_EXPERIMENT_ID, experimentId);
      }
      return experiment.layerId;
  };
  /**
   * Get attribute ID for the provided attribute key
   * @param  {ProjectConfig}   projectConfig    Object representing project configuration
   * @param  {string}          attributeKey     Attribute key for which ID is to be determined
   * @param  {LogHandler}      logger
   * @return {string|null}     Attribute ID corresponding to the provided attribute key. Attribute key if it is a reserved attribute.
   */
  const getAttributeId = function (projectConfig, attributeKey, logger) {
      const attribute = projectConfig.attributeKeyMap[attributeKey];
      const hasReservedPrefix = attributeKey.indexOf(RESERVED_ATTRIBUTE_PREFIX) === 0;
      if (attribute) {
          if (hasReservedPrefix) {
              logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_RESERVED_ATTRIBUTE_PREFIX, attributeKey, RESERVED_ATTRIBUTE_PREFIX);
          }
          return attribute.id;
      }
      else if (hasReservedPrefix) {
          return attributeKey;
      }
      logger === null || logger === void 0 ? void 0 : logger.warn(UNRECOGNIZED_ATTRIBUTE, attributeKey);
      return null;
  };
  /**
   * Get event ID for the provided
   * @param  {ProjectConfig}   projectConfig  Object representing project configuration
   * @param  {string}          eventKey       Event key for which ID is to be determined
   * @return {string|null}     Event ID corresponding to the provided event key
   */
  const getEventId = function (projectConfig, eventKey) {
      const event = projectConfig.eventKeyMap[eventKey];
      if (event) {
          return event.id;
      }
      return null;
  };
  /**
   * Get experiment status for the provided experiment key
   * @param  {ProjectConfig}  projectConfig   Object representing project configuration
   * @param  {string}         experimentKey   Experiment key for which status is to be determined
   * @return {string}         Experiment status corresponding to the provided experiment key
   * @throws If experiment key is not in datafile
   */
  const getExperimentStatus = function (projectConfig, experimentKey) {
      const experiment = projectConfig.experimentKeyMap[experimentKey];
      if (!experiment) {
          throw new OptimizelyError(INVALID_EXPERIMENT_KEY, experimentKey);
      }
      return experiment.status;
  };
  /**
   * Returns whether experiment has a status of 'Running'
   * @param  {ProjectConfig}  projectConfig   Object representing project configuration
   * @param  {string}         experimentKey   Experiment key for which status is to be compared with 'Running'
   * @return {boolean}                        True if experiment status is set to 'Running', false otherwise
   */
  const isActive = function (projectConfig, experimentKey) {
      return getExperimentStatus(projectConfig, experimentKey) === EXPERIMENT_RUNNING_STATUS;
  };
  /**
   * Determine for given experiment if event is running, which determines whether should be dispatched or not
   * @param  {ProjectConfig}  configObj       Object representing project configuration
   * @param  {string}         experimentKey   Experiment key for which the status is to be determined
   * @return {boolean}                        True if the experiment is running
   *                                          False if the experiment is not running
   *
   */
  const isRunning = function (projectConfig, experimentKey) {
      return getExperimentStatus(projectConfig, experimentKey) === EXPERIMENT_RUNNING_STATUS;
  };
  /**
   * Get audience conditions for the experiment
   * @param  {ProjectConfig}  projectConfig   Object representing project configuration
   * @param  {string}         experimentId    Experiment id for which audience conditions are to be determined
   * @return {Array<string|string[]>}         Audience conditions for the experiment - can be an array of audience IDs, or a
   *                                          nested array of conditions
   *                                          Examples: ["5", "6"], ["and", ["or", "1", "2"], "3"]
   * @throws If experiment key is not in datafile
   */
  const getExperimentAudienceConditions = function (projectConfig, experimentId) {
      const experiment = projectConfig.experimentIdMap[experimentId];
      if (!experiment) {
          throw new OptimizelyError(INVALID_EXPERIMENT_ID, experimentId);
      }
      return experiment.audienceConditions || experiment.audienceIds;
  };
  /**
   * Get variation key given experiment key and variation ID
   * @param  {ProjectConfig}  projectConfig   Object representing project configuration
   * @param  {string}         variationId     ID of the variation
   * @return {string|null}    Variation key or null if the variation ID is not found
   */
  const getVariationKeyFromId = function (projectConfig, variationId) {
      if (projectConfig.variationIdMap.hasOwnProperty(variationId)) {
          return projectConfig.variationIdMap[variationId].key;
      }
      return null;
  };
  /**
   * Get variation given variation ID
   * @param  {ProjectConfig}  projectConfig   Object representing project configuration
   * @param  {string}         variationId     ID of the variation
   * @return {Variation|null}    Variation or null if the variation ID is not found
   */
  const getVariationFromId = function (projectConfig, variationId) {
      if (projectConfig.variationIdMap.hasOwnProperty(variationId)) {
          return projectConfig.variationIdMap[variationId];
      }
      return null;
  };
  /**
   * Get the variation ID given the experiment key and variation key
   * @param  {ProjectConfig}  projectConfig   Object representing project configuration
   * @param  {string}         experimentKey   Key of the experiment the variation belongs to
   * @param  {string}         variationKey    The variation key
   * @return {string|null}    Variation ID or null
   */
  const getVariationIdFromExperimentAndVariationKey = function (projectConfig, experimentKey, variationKey) {
      const experiment = projectConfig.experimentKeyMap[experimentKey];
      if (experiment.variationKeyMap.hasOwnProperty(variationKey)) {
          return experiment.variationKeyMap[variationKey].id;
      }
      return null;
  };
  /**
   * Get experiment from provided experiment key
   * @param  {ProjectConfig}  projectConfig  Object representing project configuration
   * @param  {string}         experimentKey  Event key for which experiment IDs are to be retrieved
   * @return {Experiment}     Experiment
   * @throws If experiment key is not in datafile
   */
  const getExperimentFromKey = function (projectConfig, experimentKey) {
      if (projectConfig.experimentKeyMap.hasOwnProperty(experimentKey)) {
          const experiment = projectConfig.experimentKeyMap[experimentKey];
          if (experiment) {
              return experiment;
          }
      }
      throw new OptimizelyError(EXPERIMENT_KEY_NOT_IN_DATAFILE, experimentKey);
  };
  /**
   * Given an experiment id, returns the traffic allocation within that experiment
   * @param  {ProjectConfig}  projectConfig  Object representing project configuration
   * @param  {string}         experimentId   Id representing the experiment
   * @return {TrafficAllocation[]}           Traffic allocation for the experiment
   * @throws If experiment key is not in datafile
   */
  const getTrafficAllocation = function (projectConfig, experimentId) {
      const experiment = projectConfig.experimentIdMap[experimentId];
      if (!experiment) {
          throw new OptimizelyError(INVALID_EXPERIMENT_ID, experimentId);
      }
      return experiment.trafficAllocation;
  };
  /**
   * Get experiment from provided experiment id. Log an error if no experiment
   * exists in the project config with the given ID.
   * @param  {ProjectConfig}  projectConfig  Object representing project configuration
   * @param  {string}         experimentId   ID of desired experiment object
   * @param  {LogHandler}     logger
   * @return {Experiment|null}               Experiment object or null
   */
  const getExperimentFromId = function (projectConfig, experimentId, logger) {
      if (projectConfig.experimentIdMap.hasOwnProperty(experimentId)) {
          const experiment = projectConfig.experimentIdMap[experimentId];
          if (experiment) {
              return experiment;
          }
      }
      logger === null || logger === void 0 ? void 0 : logger.error(INVALID_EXPERIMENT_ID, experimentId);
      return null;
  };
  /**
   * Returns flag variation for specified flagKey and variationKey
   * @param  {flagKey}        string
   * @param  {variationKey}   string
   * @return {Variation|null}
   */
  const getFlagVariationByKey = function (projectConfig, flagKey, variationKey) {
      if (!projectConfig) {
          return null;
      }
      const variations = projectConfig.flagVariationsMap[flagKey];
      const result = find(variations, item => item.key === variationKey);
      if (result) {
          return result;
      }
      return null;
  };
  /**
   * Get feature from provided feature key. Log an error if no feature exists in
   * the project config with the given key.
   * @param  {ProjectConfig}    projectConfig
   * @param  {string}           featureKey
   * @param  {LogHandler}       logger
   * @return {FeatureFlag|null} Feature object, or null if no feature with the given
   *                            key exists
   */
  const getFeatureFromKey = function (projectConfig, featureKey, logger) {
      if (projectConfig.featureKeyMap.hasOwnProperty(featureKey)) {
          const feature = projectConfig.featureKeyMap[featureKey];
          if (feature) {
              return feature;
          }
      }
      logger === null || logger === void 0 ? void 0 : logger.error(FEATURE_NOT_IN_DATAFILE, featureKey);
      return null;
  };
  /**
   * Get the variable with the given key associated with the feature with the
   * given key. If the feature key or the variable key are invalid, log an error
   * message.
   * @param  {ProjectConfig}        projectConfig
   * @param  {string}               featureKey
   * @param  {string}               variableKey
   * @param  {LogHandler}           logger
   * @return {FeatureVariable|null} Variable object, or null one or both of the given
   * feature and variable keys are invalid
   */
  const getVariableForFeature = function (projectConfig, featureKey, variableKey, logger) {
      const feature = projectConfig.featureKeyMap[featureKey];
      if (!feature) {
          logger === null || logger === void 0 ? void 0 : logger.error(FEATURE_NOT_IN_DATAFILE, featureKey);
          return null;
      }
      const variable = feature.variableKeyMap[variableKey];
      if (!variable) {
          logger === null || logger === void 0 ? void 0 : logger.error(VARIABLE_KEY_NOT_IN_DATAFILE, variableKey, featureKey);
          return null;
      }
      return variable;
  };
  /**
   * Get the value of the given variable for the given variation. If the given
   * variable has no value for the given variation, return null. Log an error message if the variation is invalid. If the
   * variable or variation are invalid, return null.
   * @param  {ProjectConfig}     projectConfig
   * @param  {FeatureVariable}   variable
   * @param  {Variation}         variation
   * @param  {LogHandler}        logger
   * @return {string|null}       The value of the given variable for the given
   * variation, or null if the given variable has no value
   * for the given variation or if the variation or variable are invalid
   */
  const getVariableValueForVariation = function (projectConfig, variable, variation, logger) {
      if (!variable || !variation) {
          return null;
      }
      if (!projectConfig.variationVariableUsageMap.hasOwnProperty(variation.id)) {
          logger === null || logger === void 0 ? void 0 : logger.error(VARIATION_ID_NOT_IN_DATAFILE, variation.id);
          return null;
      }
      const variableUsages = projectConfig.variationVariableUsageMap[variation.id];
      const variableUsage = variableUsages[variable.id];
      return variableUsage ? variableUsage.value : null;
  };
  /**
   * Given a variable value in string form, try to cast it to the argument type.
   * If the type cast succeeds, return the type casted value, otherwise log an
   * error and return null.
   * @param {string}     variableValue  Variable value in string form
   * @param {string}     variableType   Type of the variable whose value was passed
   *                                    in the first argument. Must be one of
   *                                    FEATURE_VARIABLE_TYPES in
   *                                    lib/utils/enums/index.js. The return value's
   *                                    type is determined by this argument (boolean
   *                                    for BOOLEAN, number for INTEGER or DOUBLE,
   *                                    and string for STRING).
   * @param {LogHandler} logger         Logger instance
   * @returns {*}                       Variable value of the appropriate type, or
   *                                    null if the type cast failed
   */
  const getTypeCastValue = function (variableValue, variableType, logger) {
      let castValue;
      switch (variableType) {
          case FEATURE_VARIABLE_TYPES.BOOLEAN:
              if (variableValue !== 'true' && variableValue !== 'false') {
                  logger === null || logger === void 0 ? void 0 : logger.error(UNABLE_TO_CAST_VALUE, variableValue, variableType);
                  castValue = null;
              }
              else {
                  castValue = variableValue === 'true';
              }
              break;
          case FEATURE_VARIABLE_TYPES.INTEGER:
              castValue = parseInt(variableValue, 10);
              if (isNaN(castValue)) {
                  logger === null || logger === void 0 ? void 0 : logger.error(UNABLE_TO_CAST_VALUE, variableValue, variableType);
                  castValue = null;
              }
              break;
          case FEATURE_VARIABLE_TYPES.DOUBLE:
              castValue = parseFloat(variableValue);
              if (isNaN(castValue)) {
                  logger === null || logger === void 0 ? void 0 : logger.error(UNABLE_TO_CAST_VALUE, variableValue, variableType);
                  castValue = null;
              }
              break;
          case FEATURE_VARIABLE_TYPES.JSON:
              try {
                  castValue = JSON.parse(variableValue);
              }
              catch (e) {
                  logger === null || logger === void 0 ? void 0 : logger.error(UNABLE_TO_CAST_VALUE, variableValue, variableType);
                  castValue = null;
              }
              break;
          default:
              // type is STRING
              castValue = variableValue;
              break;
      }
      return castValue;
  };
  /**
   * Returns an object containing all audiences in the project config. Keys are audience IDs
   * and values are audience objects.
   * @param   {ProjectConfig}     projectConfig
   * @returns {{ [id: string]: Audience }}
   */
  const getAudiencesById = function (projectConfig) {
      return projectConfig.audiencesById;
  };
  /**
   * Returns true if an event with the given key exists in the datafile, and false otherwise
   * @param   {ProjectConfig}     projectConfig
   * @param   {string}            eventKey
   * @returns {boolean}
   */
  const eventWithKeyExists = function (projectConfig, eventKey) {
      return projectConfig.eventKeyMap.hasOwnProperty(eventKey);
  };
  /**
   * Returns true if experiment belongs to any feature, false otherwise.
   * @param   {ProjectConfig}       projectConfig
   * @param   {string}              experimentId
   * @returns {boolean}
   */
  const isFeatureExperiment = function (projectConfig, experimentId) {
      return projectConfig.experimentFeatureMap.hasOwnProperty(experimentId);
  };
  /**
   * Returns the JSON string representation of the datafile
   * @param   {ProjectConfig}       projectConfig
   * @returns {string}
   */
  const toDatafile = function (projectConfig) {
      return projectConfig.__datafileStr;
  };
  /**
   * @typedef   {Object}
   * @property  {Object|null} configObj
   * @property  {Error|null}  error
   */
  /**
   * Try to create a project config object from the given datafile and
   * configuration properties.
   * Returns a ProjectConfig if successful.
   * Otherwise, throws an error.
   * @param   {Object}         config
   * @param   {Object|string}  config.datafile
   * @param   {Object}         config.jsonSchemaValidator
   * @param   {Object}         config.logger
   * @returns {Object}         ProjectConfig
   * @throws {Error}
   */
  const tryCreatingProjectConfig = function (config) {
      var _a, _b;
      const newDatafileObj = configValidator.validateDatafile(config.datafile);
      if (config.jsonSchemaValidator) {
          config.jsonSchemaValidator(newDatafileObj);
          (_a = config.logger) === null || _a === void 0 ? void 0 : _a.info(VALID_DATAFILE);
      }
      else {
          (_b = config.logger) === null || _b === void 0 ? void 0 : _b.info(SKIPPING_JSON_VALIDATION);
      }
      const createProjectConfigArgs = [newDatafileObj];
      if (typeof config.datafile === 'string') {
          // Since config.datafile was validated above, we know that it is a valid JSON string
          createProjectConfigArgs.push(config.datafile);
      }
      const newConfigObj = createProjectConfig(...createProjectConfigArgs);
      return newConfigObj;
  };
  /**
   * Get the send flag decisions value
   * @param  {ProjectConfig}   projectConfig
   * @return {boolean}         A boolean value that indicates if we should send flag decisions
   */
  const getSendFlagDecisionsValue = function (projectConfig) {
      return !!projectConfig.sendFlagDecisions;
  };

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const noop = () => { };
  function resolvablePromise() {
      let resolve = noop;
      let reject = noop;
      const promise = new Promise((res, rej) => {
          resolve = res;
          reject = rej;
      });
      return { promise, resolve, reject, then: promise.then.bind(promise) };
  }

  /**
   * Copyright 2024-2025 Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const SERVICE_FAILED_TO_START = '%s failed to start, reason: %s';
  const SERVICE_STOPPED_BEFORE_RUNNING = '%s stopped before running';
  /**
   * The service interface represents an object with an operational state,
   * with methods to start and stop. The design of this interface in modelled
   * after Guava Service interface (https://github.com/google/guava/wiki/ServiceExplained).
   */
  var ServiceState;
  (function (ServiceState) {
      ServiceState[ServiceState["New"] = 0] = "New";
      ServiceState[ServiceState["Starting"] = 1] = "Starting";
      ServiceState[ServiceState["Running"] = 2] = "Running";
      ServiceState[ServiceState["Stopping"] = 3] = "Stopping";
      ServiceState[ServiceState["Terminated"] = 4] = "Terminated";
      ServiceState[ServiceState["Failed"] = 5] = "Failed";
  })(ServiceState || (ServiceState = {}));
  class BaseService {
      constructor(startupLogs = []) {
          this.disposable = false;
          this.state = ServiceState.New;
          this.startPromise = resolvablePromise();
          this.stopPromise = resolvablePromise();
          this.startupLogs = startupLogs;
          // avoid unhandled promise rejection
          this.startPromise.promise.catch(() => { });
          this.stopPromise.promise.catch(() => { });
      }
      makeDisposable() {
          this.disposable = true;
      }
      setLogger(logger) {
          this.logger = logger;
      }
      printStartupLogs() {
          if (!this.logger) {
              return;
          }
          for (const { level, message, params } of this.startupLogs) {
              const methodName = LogLevelToLower[level];
              const method = this.logger[methodName];
              method.call(this.logger, message, ...params);
          }
      }
      onRunning() {
          return this.startPromise.promise;
      }
      onTerminated() {
          return this.stopPromise.promise;
      }
      getState() {
          return this.state;
      }
      isStarting() {
          return this.state === ServiceState.Starting;
      }
      isRunning() {
          return this.state === ServiceState.Running;
      }
      isNew() {
          return this.state === ServiceState.New;
      }
      isDone() {
          return [
              ServiceState.Stopping,
              ServiceState.Terminated,
              ServiceState.Failed
          ].includes(this.state);
      }
      start() {
          this.printStartupLogs();
      }
  }

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class EventEmitter {
      constructor() {
          this.id = 0;
          this.listeners = {};
      }
      on(eventName, listener) {
          var _a;
          if (!this.listeners[eventName]) {
              this.listeners[eventName] = new Map();
          }
          const curId = this.id++;
          (_a = this.listeners[eventName]) === null || _a === void 0 ? void 0 : _a.set(curId, listener);
          return () => {
              var _a;
              (_a = this.listeners[eventName]) === null || _a === void 0 ? void 0 : _a.delete(curId);
          };
      }
      emit(eventName, data) {
          const listeners = this.listeners[eventName];
          if (listeners) {
              listeners.forEach(listener => {
                  listener(data);
              });
          }
      }
      removeListeners(eventName) {
          var _a;
          (_a = this.listeners[eventName]) === null || _a === void 0 ? void 0 : _a.clear();
      }
      removeAllListeners() {
          this.listeners = {};
      }
  }

  const NO_SDKKEY_OR_DATAFILE = 'sdkKey or datafile must be provided';
  const GOT_INVALID_DATAFILE = 'got invalid datafile';
  /**
   * ProjectConfigManager provides project config objects via its methods
   * getConfig and onUpdate. It uses a DatafileManager to fetch datafile if provided.
   * It is responsible for parsing and validating datafiles, and converting datafile
   * string into project config objects.
   * @param {ProjectConfigManagerConfig}    config
   */
  const LOGGER_NAME$7 = 'ProjectConfigManager';
  class ProjectConfigManagerImpl extends BaseService {
      constructor(config) {
          super();
          this.eventEmitter = new EventEmitter();
          this.jsonSchemaValidator = config.jsonSchemaValidator;
          this.datafile = config.datafile;
          this.datafileManager = config.datafileManager;
          if (config.logger) {
              this.setLogger(config.logger);
          }
      }
      setLogger(logger) {
          var _a;
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$7);
          (_a = this.datafileManager) === null || _a === void 0 ? void 0 : _a.setLogger(logger.child());
      }
      start() {
          var _a, _b, _c;
          if (!this.isNew()) {
              return;
          }
          this.state = ServiceState.Starting;
          if (!this.datafile && !this.datafileManager) {
              this.handleInitError(new Error(NO_SDKKEY_OR_DATAFILE));
              return;
          }
          if (this.datafile) {
              this.handleNewDatafile(this.datafile, true);
          }
          (_a = this.datafileManager) === null || _a === void 0 ? void 0 : _a.start();
          // This handles the case where the datafile manager starts successfully. The 
          // datafile manager will only start successfully when it has downloaded a datafile,
          // an will fire an onUpdate event.
          (_b = this.datafileManager) === null || _b === void 0 ? void 0 : _b.onUpdate(this.handleNewDatafile.bind(this));
          // If the datafile manager runs successfully, it will emit a onUpdate event. We can
          // handle the success case in the onUpdate handler. Hanlding the error case in the
          // catch callback
          (_c = this.datafileManager) === null || _c === void 0 ? void 0 : _c.onRunning().catch((err) => {
              this.handleDatafileManagerError(err);
          });
      }
      makeDisposable() {
          var _a;
          super.makeDisposable();
          (_a = this.datafileManager) === null || _a === void 0 ? void 0 : _a.makeDisposable();
      }
      handleInitError(error) {
          var _a, _b;
          (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(error);
          this.state = ServiceState.Failed;
          (_b = this.datafileManager) === null || _b === void 0 ? void 0 : _b.stop();
          this.startPromise.reject(error);
          this.stopPromise.reject(error);
      }
      handleDatafileManagerError(err) {
          var _a;
          (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(SERVICE_FAILED_TO_START, 'DatafileManager', err.message);
          // If datafile manager onRunning() promise is rejected, and the project config manager 
          // is still in starting state, that means a datafile was not provided in cofig or was invalid, 
          // otherwise the state would have already been set to running synchronously.
          // In this case, we cannot recover.
          if (this.isStarting()) {
              this.handleInitError(new Error(sprintf(SERVICE_FAILED_TO_START, 'DatafileManager', err.message)));
          }
      }
      /**
       * Handle new datafile by attemping to create a new Project Config object. If successful and
       * the new config object's revision is newer than the current one, sets/updates the project config
       * and emits onUpdate event. If unsuccessful,
       * the project config and optimizely config objects will not be updated. If the error
       * is fatal, handleInitError will be called.
       */
      handleNewDatafile(newDatafile, fromConfig = false) {
          var _a, _b;
          if (this.isDone()) {
              return;
          }
          try {
              const config = tryCreatingProjectConfig({
                  datafile: newDatafile,
                  jsonSchemaValidator: this.jsonSchemaValidator,
                  logger: this.logger,
              });
              if (this.isStarting()) {
                  this.state = ServiceState.Running;
                  this.startPromise.resolve();
              }
              if (((_a = this.projectConfig) === null || _a === void 0 ? void 0 : _a.revision) !== config.revision) {
                  this.projectConfig = config;
                  this.optimizelyConfig = undefined;
                  this.eventEmitter.emit('update', config);
              }
          }
          catch (err) {
              (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(err);
              // if the state is starting and no datafileManager is provided, we cannot recover.
              // If the state is starting and the datafileManager has emitted a datafile,
              // that means a datafile was not provided in config or an invalid datafile was provided,
              // otherwise the state would have already been set to running synchronously.
              // If the first datafile emitted by the datafileManager is invalid, 
              // we consider this to be an initialization error as well.
              const fatalError = (this.isStarting() && !this.datafileManager) ||
                  (this.isStarting() && !fromConfig);
              if (fatalError) {
                  this.handleInitError(new Error(GOT_INVALID_DATAFILE));
              }
          }
      }
      getConfig() {
          return this.projectConfig;
      }
      getOptimizelyConfig() {
          if (!this.optimizelyConfig && this.projectConfig) {
              this.optimizelyConfig = createOptimizelyConfig(this.projectConfig, toDatafile(this.projectConfig), this.logger);
          }
          return this.optimizelyConfig;
      }
      /**
       * Add a listener for project config updates. The listener will be called
       * whenever this instance has a new project config object available.
       * Returns a dispose function that removes the subscription
       * @param  {Function} listener
       * @return {Function}
       */
      onUpdate(listener) {
          return this.eventEmitter.on('update', listener);
      }
      stop() {
          if (this.isDone()) {
              return;
          }
          if (this.isNew() || this.isStarting()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'ProjectConfigManager')));
          }
          this.state = ServiceState.Stopping;
          this.eventEmitter.removeAllListeners();
          if (!this.datafileManager) {
              this.state = ServiceState.Terminated;
              this.stopPromise.resolve();
              return;
          }
          this.datafileManager.stop();
          this.datafileManager.onTerminated().then(() => {
              this.state = ServiceState.Terminated;
              this.stopPromise.resolve();
          }).catch((err) => {
              this.state = ServiceState.Failed;
              this.stopPromise.reject(err);
          });
      }
  }

  /******************************************************************************
  Copyright (c) Microsoft Corporation.

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
  REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
  INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
  LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
  OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  PERFORMANCE OF THIS SOFTWARE.
  ***************************************************************************** */

  function __awaiter(thisArg, _arguments, P, generator) {
      function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
      return new (P || (P = Promise))(function (resolve, reject) {
          function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
          function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
          function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
          step((generator = generator.apply(thisArg, _arguments || [])).next());
      });
  }

  typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
      var e = new Error(message);
      return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
  };

  /**
   * Copyright 2022-2023, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const DEFAULT_UPDATE_INTERVAL_MINUTES = 5;
  /** Standard interval (5 minutes in milliseconds) for polling datafile updates.; */
  const DEFAULT_UPDATE_INTERVAL = DEFAULT_UPDATE_INTERVAL_MINUTES * 60 * 1000;
  const MIN_UPDATE_INTERVAL_SECONDS = 30;
  /** Minimum allowed interval (30 seconds in milliseconds) for polling datafile updates. */
  const MIN_UPDATE_INTERVAL = MIN_UPDATE_INTERVAL_SECONDS * 1000;
  const UPDATE_INTERVAL_BELOW_MINIMUM_MESSAGE = `Polling intervals below ${MIN_UPDATE_INTERVAL_SECONDS} seconds are not recommended.`;
  const DEFAULT_URL_TEMPLATE = `https://cdn.optimizely.com/datafiles/%s.json`;
  const DEFAULT_AUTHENTICATED_URL_TEMPLATE = `https://config.optimizely.com/datafiles/auth/%s.json`;

  const isSuccessStatusCode = (statusCode) => {
      return statusCode >= 200 && statusCode < 400;
  };

  const LOGGER_NAME$6 = 'PollingDatafileManager';
  const FAILED_TO_FETCH_DATAFILE = 'Failed to fetch datafile';
  class PollingDatafileManager extends BaseService {
      constructor(config) {
          super(config.startupLogs);
          const { autoUpdate = false, sdkKey, datafileAccessToken, urlTemplate, cache, initRetry, repeater, requestHandler, logger, } = config;
          this.cache = cache;
          this.cacheKey = 'opt-datafile-' + sdkKey;
          this.sdkKey = sdkKey;
          this.datafileAccessToken = datafileAccessToken;
          this.requestHandler = requestHandler;
          this.emitter = new EventEmitter();
          this.autoUpdate = autoUpdate;
          this.initRetryRemaining = initRetry;
          this.repeater = repeater;
          if (logger) {
              this.setLogger(logger);
          }
          const urlTemplateToUse = urlTemplate ||
              (datafileAccessToken ? DEFAULT_AUTHENTICATED_URL_TEMPLATE : DEFAULT_URL_TEMPLATE);
          this.datafileUrl = sprintf(urlTemplateToUse, this.sdkKey);
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$6);
      }
      onUpdate(listener) {
          return this.emitter.on('update', listener);
      }
      get() {
          return this.currentDatafile;
      }
      start() {
          if (!this.isNew()) {
              return;
          }
          super.start();
          this.state = ServiceState.Starting;
          this.setDatafileFromCacheIfAvailable();
          this.repeater.setTask(this.syncDatafile.bind(this));
          this.repeater.start(true);
      }
      makeDisposable() {
          var _a;
          super.makeDisposable();
          this.initRetryRemaining = Math.min((_a = this.initRetryRemaining) !== null && _a !== void 0 ? _a : 5, 5);
      }
      stop() {
          var _a;
          if (this.isDone()) {
              return;
          }
          if (this.isNew() || this.isStarting()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'PollingDatafileManager')));
          }
          this.state = ServiceState.Terminated;
          this.repeater.stop();
          (_a = this.currentRequest) === null || _a === void 0 ? void 0 : _a.abort();
          this.emitter.removeAllListeners();
          this.stopPromise.resolve();
      }
      handleInitFailure() {
          this.state = ServiceState.Failed;
          this.repeater.stop();
          const error = new Error(FAILED_TO_FETCH_DATAFILE);
          this.startPromise.reject(error);
          this.stopPromise.reject(error);
      }
      handleError(errorOrStatus) {
          var _a, _b;
          if (this.isDone()) {
              return;
          }
          if (errorOrStatus instanceof Error) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(ERROR_FETCHING_DATAFILE, errorOrStatus.message, errorOrStatus);
          }
          else {
              (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(DATAFILE_FETCH_REQUEST_FAILED, errorOrStatus);
          }
          if (this.isStarting() && this.initRetryRemaining !== undefined) {
              if (this.initRetryRemaining === 0) {
                  this.handleInitFailure();
              }
              else {
                  this.initRetryRemaining--;
              }
          }
      }
      onRequestRejected(err) {
          return __awaiter(this, void 0, void 0, function* () {
              this.handleError(err);
              return Promise.reject(err);
          });
      }
      onRequestResolved(response) {
          return __awaiter(this, void 0, void 0, function* () {
              if (this.isDone()) {
                  return;
              }
              this.saveLastModified(response.headers);
              if (!isSuccessStatusCode(response.statusCode)) {
                  this.handleError(response.statusCode);
                  return Promise.reject(new Error());
              }
              const datafile = this.getDatafileFromResponse(response);
              if (datafile) {
                  this.handleDatafile(datafile);
                  // if autoUpdate is off, don't need to sync datafile any more
                  // if disposable, stop the repeater after the first successful fetch
                  if (!this.autoUpdate || this.disposable) {
                      this.repeater.stop();
                  }
              }
          });
      }
      makeDatafileRequest() {
          var _a, _b;
          const headers = {};
          if (this.lastResponseLastModified) {
              headers['if-modified-since'] = this.lastResponseLastModified;
          }
          if (this.datafileAccessToken) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(ADDING_AUTHORIZATION_HEADER_WITH_BEARER_TOKEN);
              headers['Authorization'] = `Bearer ${this.datafileAccessToken}`;
          }
          (_b = this.logger) === null || _b === void 0 ? void 0 : _b.debug(MAKING_DATAFILE_REQ_TO_URL_WITH_HEADERS, this.datafileUrl, () => JSON.stringify(headers));
          return this.requestHandler.makeRequest(this.datafileUrl, headers, 'GET');
      }
      syncDatafile() {
          return __awaiter(this, void 0, void 0, function* () {
              this.currentRequest = this.makeDatafileRequest();
              return this.currentRequest.responsePromise
                  .then(this.onRequestResolved.bind(this), this.onRequestRejected.bind(this))
                  .finally(() => this.currentRequest = undefined);
          });
      }
      handleDatafile(datafile) {
          var _a;
          if (this.isDone()) {
              return;
          }
          this.currentDatafile = datafile;
          (_a = this.cache) === null || _a === void 0 ? void 0 : _a.set(this.cacheKey, datafile);
          if (this.isStarting()) {
              this.startPromise.resolve();
              this.state = ServiceState.Running;
          }
          this.emitter.emit('update', datafile);
      }
      getDatafileFromResponse(response) {
          var _a;
          (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(RESPONSE_STATUS_CODE, response.statusCode);
          if (response.statusCode === 304) {
              return undefined;
          }
          return response.body;
      }
      saveLastModified(headers) {
          var _a;
          const lastModifiedHeader = headers['last-modified'] || headers['Last-Modified'];
          if (lastModifiedHeader !== undefined) {
              this.lastResponseLastModified = lastModifiedHeader;
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(SAVED_LAST_MODIFIED_HEADER_VALUE_FROM_RESPONSE, this.lastResponseLastModified);
          }
      }
      setDatafileFromCacheIfAvailable() {
          return __awaiter(this, void 0, void 0, function* () {
              if (!this.cache) {
                  return;
              }
              try {
                  const datafile = yield this.cache.get(this.cacheKey);
                  if (datafile && this.isStarting()) {
                      this.handleDatafile(datafile);
                  }
              }
              catch (_a) {
                  // ignore error
              }
          });
      }
  }

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const scheduleMicrotask = (callback) => {
      if (typeof queueMicrotask === 'function') {
          queueMicrotask(callback);
      }
      else {
          Promise.resolve().then(callback);
      }
  };

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class ExponentialBackoff {
      constructor(base, max, maxJitter) {
          this.base = base;
          this.max = max;
          this.maxJitter = maxJitter;
          this.current = base;
      }
      backoff() {
          const ret = this.current + this.maxJitter * Math.random();
          this.current = Math.min(this.current * 2, this.max);
          return ret;
      }
      reset() {
          this.current = this.base;
      }
  }
  // IntervalRepeater is a Repeater that invokes the task at a fixed interval 
  // after the completion of the previous task invocation. If a backoff controller
  // is provided, the repeater will use the backoff controller to determine the
  // time between invocations after a failure instead. It will reset the backoffController
  // on success.
  class IntervalRepeater {
      constructor(interval, backoffController) {
          this.failureCount = 0;
          this.running = false;
          this.interval = interval;
          this.backoffController = backoffController;
      }
      isRunning() {
          return this.running;
      }
      handleSuccess() {
          var _a;
          this.failureCount = 0;
          (_a = this.backoffController) === null || _a === void 0 ? void 0 : _a.reset();
          this.setTimer(this.interval);
      }
      handleFailure() {
          var _a, _b;
          this.failureCount++;
          const time = (_b = (_a = this.backoffController) === null || _a === void 0 ? void 0 : _a.backoff()) !== null && _b !== void 0 ? _b : this.interval;
          this.setTimer(time);
      }
      setTimer(timeout) {
          if (!this.running) {
              return;
          }
          this.timeoutId = setTimeout(this.executeTask.bind(this), timeout);
      }
      executeTask() {
          if (!this.task) {
              return;
          }
          this.task(this.failureCount).then(this.handleSuccess.bind(this), this.handleFailure.bind(this));
      }
      start(immediateExecution) {
          this.running = true;
          if (immediateExecution) {
              scheduleMicrotask(this.executeTask.bind(this));
          }
          else {
              this.setTimer(this.interval);
          }
      }
      stop() {
          this.running = false;
          clearInterval(this.timeoutId);
      }
      reset() {
          var _a;
          this.failureCount = 0;
          (_a = this.backoffController) === null || _a === void 0 ? void 0 : _a.reset();
          this.stop();
      }
      setTask(task) {
          this.task = task;
      }
  }

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const INVALID_STORE = 'Invalid store';
  const INVALID_STORE_METHOD = 'Invalid store method %s';
  // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
  const validateStore = (store) => {
      const errors = [];
      if (!store || typeof store !== 'object') {
          throw new Error(INVALID_STORE);
      }
      for (const method of ['set', 'get', 'remove', 'getKeys']) {
          if (typeof store[method] !== 'function') {
              errors.push(INVALID_STORE_METHOD.replace('%s', method));
          }
      }
      if (errors.length > 0) {
          throw new Error(errors.join(', '));
      }
  };

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const INVALID_CONFIG_MANAGER = "Invalid config manager";
  const configManagerSymbol = Symbol();
  const createStaticProjectConfigManager = (config) => {
      return {
          [configManagerSymbol]: new ProjectConfigManagerImpl(config),
      };
  };
  const getPollingConfigManager = (opt) => {
      var _a;
      if (opt.cache) {
          validateStore(opt.cache);
      }
      const updateInterval = (_a = opt.updateInterval) !== null && _a !== void 0 ? _a : DEFAULT_UPDATE_INTERVAL;
      const backoff = new ExponentialBackoff(1000, updateInterval, 500);
      const repeater = new IntervalRepeater(updateInterval, backoff);
      const startupLogs = [];
      if (updateInterval < MIN_UPDATE_INTERVAL) {
          startupLogs.push({
              level: exports.LogLevel.Warn,
              message: UPDATE_INTERVAL_BELOW_MINIMUM_MESSAGE,
              params: [],
          });
      }
      const datafileManagerConfig = {
          sdkKey: opt.sdkKey,
          autoUpdate: opt.autoUpdate,
          urlTemplate: opt.urlTemplate,
          datafileAccessToken: opt.datafileAccessToken,
          requestHandler: opt.requestHandler,
          cache: opt.cache,
          repeater,
          startupLogs,
      };
      const datafileManager = new PollingDatafileManager(datafileManagerConfig);
      return new ProjectConfigManagerImpl({
          datafile: opt.datafile,
          datafileManager,
          jsonSchemaValidator: opt.jsonSchemaValidator,
      });
  };
  const getOpaquePollingConfigManager = (opt) => {
      return {
          [configManagerSymbol]: getPollingConfigManager(opt),
      };
  };
  const extractConfigManager = (opaqueConfigManager) => {
      if (!opaqueConfigManager || typeof opaqueConfigManager !== 'object') {
          throw new Error(INVALID_CONFIG_MANAGER);
      }
      const configManager = opaqueConfigManager[configManagerSymbol];
      if (!configManager) {
          throw new Error(INVALID_CONFIG_MANAGER);
      }
      return opaqueConfigManager[configManagerSymbol];
  };

  const ACTIVATE_EVENT_KEY = 'campaign_activated';
  const CUSTOM_ATTRIBUTE_FEATURE_TYPE = 'custom';
  /**
   * Given an array of batchable Decision or ConversionEvent events it returns
   * a single EventV1 with proper batching
   *
   * @param {UserEvent[]} events
   * @returns {EventBatch}
   */
  function makeEventBatch(events) {
      const visitors = [];
      const data = events[0];
      events.forEach(event => {
          if (event.type === 'conversion' || event.type === 'impression') {
              const visitor = makeVisitor(event);
              if (event.type === 'impression') {
                  visitor.snapshots.push(makeDecisionSnapshot(event));
              }
              else if (event.type === 'conversion') {
                  visitor.snapshots.push(makeConversionSnapshot(event));
              }
              visitors.push(visitor);
          }
      });
      return {
          client_name: data.context.clientName,
          client_version: data.context.clientVersion,
          account_id: data.context.accountId,
          project_id: data.context.projectId,
          revision: data.context.revision,
          anonymize_ip: data.context.anonymizeIP,
          enrich_decisions: true,
          visitors,
      };
  }
  function makeConversionSnapshot(conversion) {
      const tags = Object.assign({}, conversion.tags);
      delete tags['revenue'];
      delete tags['value'];
      const event = {
          entity_id: conversion.event.id,
          key: conversion.event.key,
          timestamp: conversion.timestamp,
          uuid: conversion.uuid,
      };
      if (conversion.tags) {
          event.tags = conversion.tags;
      }
      if (conversion.value != null) {
          event.value = conversion.value;
      }
      if (conversion.revenue != null) {
          event.revenue = conversion.revenue;
      }
      return {
          events: [event],
      };
  }
  function makeDecisionSnapshot(event) {
      var _a, _b;
      const { layer, experiment, variation, ruleKey, flagKey, ruleType, enabled, cmabUuid } = event;
      const layerId = layer ? layer.id : null;
      const experimentId = (_a = experiment === null || experiment === void 0 ? void 0 : experiment.id) !== null && _a !== void 0 ? _a : '';
      const variationId = (_b = variation === null || variation === void 0 ? void 0 : variation.id) !== null && _b !== void 0 ? _b : '';
      const variationKey = variation ? variation.key : '';
      return {
          decisions: [
              {
                  campaign_id: layerId,
                  experiment_id: experimentId,
                  variation_id: variationId,
                  metadata: {
                      flag_key: flagKey,
                      rule_key: ruleKey,
                      rule_type: ruleType,
                      variation_key: variationKey,
                      enabled: enabled,
                      cmab_uuid: cmabUuid,
                  },
              },
          ],
          events: [
              {
                  entity_id: layerId,
                  timestamp: event.timestamp,
                  key: ACTIVATE_EVENT_KEY,
                  uuid: event.uuid,
              },
          ],
      };
  }
  function makeVisitor(data) {
      const visitor = {
          snapshots: [],
          visitor_id: data.user.id,
          attributes: [],
      };
      data.user.attributes.forEach(attr => {
          visitor.attributes.push({
              entity_id: attr.entityId,
              key: attr.key,
              type: 'custom',
              value: attr.value,
          });
      });
      if (typeof data.context.botFiltering === 'boolean') {
          visitor.attributes.push({
              entity_id: CONTROL_ATTRIBUTES.BOT_FILTERING,
              key: CONTROL_ATTRIBUTES.BOT_FILTERING,
              type: CUSTOM_ATTRIBUTE_FEATURE_TYPE,
              value: data.context.botFiltering,
          });
      }
      return visitor;
  }
  function buildLogEvent(events) {
      return {
          url: 'https://logx.optimizely.com/v1/events',
          httpVerb: 'POST',
          params: makeEventBatch(events),
      };
  }

  /**
   * Copyright 2021-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class ForwardingEventProcessor extends BaseService {
      constructor(dispatcher) {
          super();
          this.dispatcher = dispatcher;
          this.eventEmitter = new EventEmitter();
      }
      process(event) {
          const formattedEvent = buildLogEvent([event]);
          const res = this.dispatcher.dispatchEvent(formattedEvent);
          this.eventEmitter.emit('dispatch', formattedEvent);
          return res;
      }
      start() {
          if (!this.isNew()) {
              return;
          }
          this.state = ServiceState.Running;
          this.startPromise.resolve();
      }
      stop() {
          if (this.isDone()) {
              return;
          }
          if (this.isNew()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'ForwardingEventProcessor')));
          }
          this.state = ServiceState.Terminated;
          this.stopPromise.resolve();
      }
      onDispatch(handler) {
          return this.eventEmitter.on('dispatch', handler);
      }
  }

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class SyncStoreWithBatchedGet {
      constructor() {
          this.operation = 'sync';
      }
  }
  class AsyncStoreWithBatchedGet {
      constructor() {
          this.operation = 'async';
      }
  }
  const getBatchedSync = (store, keys) => {
      if (store instanceof SyncStoreWithBatchedGet) {
          return store.getBatched(keys);
      }
      return keys.map((key) => store.get(key));
  };
  const getBatchedAsync = (store, keys) => {
      if (store instanceof AsyncStoreWithBatchedGet) {
          return store.getBatched(keys);
      }
      return Promise.all(keys.map((key) => store.get(key)));
  };
  class SyncPrefixStore extends SyncStoreWithBatchedGet {
      constructor(store, prefix, transformGet, transformSet) {
          super();
          this.operation = 'sync';
          this.store = store;
          this.prefix = prefix;
          this.transformGet = transformGet;
          this.transformSet = transformSet;
      }
      addPrefix(key) {
          return `${this.prefix}${key}`;
      }
      removePrefix(key) {
          return key.substring(this.prefix.length);
      }
      set(key, value) {
          return this.store.set(this.addPrefix(key), this.transformSet(value));
      }
      get(key) {
          const value = this.store.get(this.addPrefix(key));
          return value ? this.transformGet(value) : undefined;
      }
      remove(key) {
          return this.store.remove(this.addPrefix(key));
      }
      getInternalKeys() {
          return this.store.getKeys().filter((key) => key.startsWith(this.prefix));
      }
      getKeys() {
          return this.getInternalKeys().map((key) => this.removePrefix(key));
      }
      getBatched(keys) {
          return getBatchedSync(this.store, keys.map((key) => this.addPrefix(key)))
              .map((value) => value ? this.transformGet(value) : undefined);
      }
  }

  const runTask = (task, returnPromise, cancelSignal, backoff, retryRemaining) => {
      task().then((res) => {
          returnPromise.resolve(res);
      }).catch((e) => {
          var _a;
          if (retryRemaining === 0) {
              returnPromise.reject(e);
              return;
          }
          if (cancelSignal.cancelled) {
              returnPromise.reject(new OptimizelyError(RETRY_CANCELLED));
              return;
          }
          const delay = (_a = backoff === null || backoff === void 0 ? void 0 : backoff.backoff()) !== null && _a !== void 0 ? _a : 0;
          setTimeout(() => {
              retryRemaining = retryRemaining === undefined ? undefined : retryRemaining - 1;
              runTask(task, returnPromise, cancelSignal, backoff, retryRemaining);
          }, delay);
      });
  };
  const runWithRetry = (task, backoff, maxRetries) => {
      const returnPromise = resolvablePromise();
      const cancelSignal = { cancelled: false };
      const cancelRetry = () => {
          cancelSignal.cancelled = true;
      };
      runTask(task, returnPromise, cancelSignal, backoff, maxRetries);
      return { cancelRetry, result: returnPromise.promise };
  };

  /**
   * Copyright 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const idSuffixBase = 10000;
  class IdGenerator {
      constructor() {
          this.idSuffixOffset = 0;
      }
      // getId returns an Id that generally increases with each call.
      // only exceptions are when idSuffix rotates back to 0 within the same millisecond
      // or when the clock goes back
      getId() {
          const idSuffix = idSuffixBase + this.idSuffixOffset;
          this.idSuffixOffset = (this.idSuffixOffset + 1) % idSuffixBase;
          const timestamp = Date.now();
          return `${timestamp}${idSuffix}`;
      }
  }

  /**
   * Copyright 2020, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Get experiment key from the provided decision object
   * @param   {DecisionObj} decisionObj       Object representing decision
   * @returns {string}                        Experiment key or empty string if experiment is null
   */
  function getExperimentKey(decisionObj) {
      var _a, _b;
      return (_b = (_a = decisionObj.experiment) === null || _a === void 0 ? void 0 : _a.key) !== null && _b !== void 0 ? _b : '';
  }
  /**
   * Get variation key from the provided decision object
   * @param   {DecisionObj} decisionObj       Object representing decision
   * @returns {string}                        Variation key or empty string if variation is null
   */
  function getVariationKey(decisionObj) {
      var _a, _b;
      return (_b = (_a = decisionObj.variation) === null || _a === void 0 ? void 0 : _a.key) !== null && _b !== void 0 ? _b : '';
  }
  /**
   * Get featureEnabled from variation in the provided decision object
   * @param   {DecisionObj} decisionObj       Object representing decision
   * @returns {boolean}                       featureEnabled boolean or false if variation is null
   */
  function getFeatureEnabledFromVariation(decisionObj) {
      var _a, _b;
      return (_b = (_a = decisionObj.variation) === null || _a === void 0 ? void 0 : _a.featureEnabled) !== null && _b !== void 0 ? _b : false;
  }
  /**
   * Get experiment id from the provided decision object
   * @param   {DecisionObj} decisionObj       Object representing decision
   * @returns {string}                        Experiment id or null if experiment is null
   */
  function getExperimentId(decisionObj) {
      var _a, _b;
      return (_b = (_a = decisionObj.experiment) === null || _a === void 0 ? void 0 : _a.id) !== null && _b !== void 0 ? _b : null;
  }
  /**
   * Get variation id from the provided decision object
   * @param   {DecisionObj} decisionObj       Object representing decision
   * @returns {string}                        Variation id or null if variation is null
   */
  function getVariationId(decisionObj) {
      var _a, _b;
      return (_b = (_a = decisionObj.variation) === null || _a === void 0 ? void 0 : _a.id) !== null && _b !== void 0 ? _b : null;
  }

  /**
   * Validates user's provided attributes
   * @param  {unknown}  attributes
   * @return {boolean}  true if the attributes are valid
   * @throws If the attributes are not valid
   */
  function validate$5(attributes) {
      if (typeof attributes === 'object' && !Array.isArray(attributes) && attributes !== null) {
          Object.keys(attributes).forEach(function (key) {
              if (typeof attributes[key] === 'undefined') {
                  throw new OptimizelyError(UNDEFINED_ATTRIBUTE, key);
              }
          });
          return true;
      }
      else {
          throw new OptimizelyError(INVALID_ATTRIBUTES$1);
      }
  }
  /**
   * Validates user's provided attribute
   * @param  {unknown}  attributeKey
   * @param  {unknown}  attributeValue
   * @return {boolean}  true if the attribute is valid
   */
  function isAttributeValid(attributeKey, attributeValue) {
      return (typeof attributeKey === 'string' &&
          (typeof attributeValue === 'string' ||
              typeof attributeValue === 'boolean' ||
              (fns.isNumber(attributeValue) && fns.isSafeInteger(attributeValue))));
  }

  /**
   * Copyright 2017, 2019-2020, 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Provides utility method for parsing event tag values
   */
  const REVENUE_EVENT_METRIC_NAME = "revenue" /* RESERVED_EVENT_KEYWORDS.REVENUE */;
  const VALUE_EVENT_METRIC_NAME = "value" /* RESERVED_EVENT_KEYWORDS.VALUE */;
  /**
   * Grab the revenue value from the event tags. "revenue" is a reserved keyword.
   * @param {EventTags} eventTags
   * @param {LoggerFacade} logger
   * @return {number|null}
   */
  function getRevenueValue(eventTags, logger) {
      const rawValue = eventTags[REVENUE_EVENT_METRIC_NAME];
      if (rawValue == null) {
          // null or undefined event values
          return null;
      }
      const parsedRevenueValue = typeof rawValue === 'string' ? parseInt(rawValue) : Math.trunc(rawValue);
      if (isFinite(parsedRevenueValue)) {
          logger === null || logger === void 0 ? void 0 : logger.info(PARSED_REVENUE_VALUE, parsedRevenueValue);
          return parsedRevenueValue;
      }
      else {
          // NaN, +/- infinity values
          logger === null || logger === void 0 ? void 0 : logger.info(FAILED_TO_PARSE_REVENUE, rawValue);
          return null;
      }
  }
  /**
   * Grab the event value from the event tags. "value" is a reserved keyword.
   * @param {EventTags} eventTags
   * @param {LoggerFacade} logger
   * @return {number|null}
   */
  function getEventValue(eventTags, logger) {
      const rawValue = eventTags[VALUE_EVENT_METRIC_NAME];
      if (rawValue == null) {
          // null or undefined event values
          return null;
      }
      const parsedEventValue = typeof rawValue === 'string' ? parseFloat(rawValue) : rawValue;
      if (isFinite(parsedEventValue)) {
          logger === null || logger === void 0 ? void 0 : logger.info(PARSED_NUMERIC_VALUE, parsedEventValue);
          return parsedEventValue;
      }
      else {
          // NaN, +/- infinity values
          logger === null || logger === void 0 ? void 0 : logger.info(FAILED_TO_PARSE_VALUE, rawValue);
          return null;
      }
  }

  const areEventContextsEqual = (eventA, eventB) => {
      const contextA = eventA.context;
      const contextB = eventB.context;
      return (contextA.accountId === contextB.accountId &&
          contextA.projectId === contextB.projectId &&
          contextA.clientName === contextB.clientName &&
          contextA.clientVersion === contextB.clientVersion &&
          contextA.revision === contextB.revision &&
          contextA.anonymizeIP === contextB.anonymizeIP &&
          contextA.botFiltering === contextB.botFiltering);
  };
  /**
   * Creates an ImpressionEvent object from decision data
   * @param  {ImpressionConfig}  config
   * @return {ImpressionEvent}   an ImpressionEvent object
   */
  const buildImpressionEvent = function ({ configObj, decisionObj, userId, flagKey, enabled, userAttributes, clientEngine, clientVersion, }) {
      const ruleType = decisionObj.decisionSource;
      const experimentKey = getExperimentKey(decisionObj);
      const experimentId = getExperimentId(decisionObj);
      const variationKey = getVariationKey(decisionObj);
      const variationId = getVariationId(decisionObj);
      const cmabUuid = decisionObj.cmabUuid;
      const layerId = experimentId !== null ? getLayerId(configObj, experimentId) : null;
      return {
          type: 'impression',
          timestamp: fns.currentTimestamp(),
          uuid: fns.uuid(),
          user: {
              id: userId,
              attributes: buildVisitorAttributes(configObj, userAttributes),
          },
          context: {
              accountId: configObj.accountId,
              projectId: configObj.projectId,
              revision: configObj.revision,
              clientName: clientEngine,
              clientVersion: clientVersion,
              anonymizeIP: configObj.anonymizeIP || false,
              botFiltering: configObj.botFiltering,
          },
          layer: {
              id: layerId,
          },
          experiment: {
              id: experimentId,
              key: experimentKey,
          },
          variation: {
              id: variationId,
              key: variationKey,
          },
          ruleKey: experimentKey,
          flagKey: flagKey,
          ruleType: ruleType,
          enabled: enabled,
          cmabUuid,
      };
  };
  /**
   * Creates a ConversionEvent object from track
   * @param  {ConversionConfig} config
   * @return {ConversionEvent}  a ConversionEvent object
   */
  const buildConversionEvent = function ({ configObj, userId, userAttributes, clientEngine, clientVersion, eventKey, eventTags, }, logger) {
      const eventId = getEventId(configObj, eventKey);
      const revenue = eventTags ? getRevenueValue(eventTags, logger) : null;
      const eventValue = eventTags ? getEventValue(eventTags, logger) : null;
      return {
          type: 'conversion',
          timestamp: fns.currentTimestamp(),
          uuid: fns.uuid(),
          user: {
              id: userId,
              attributes: buildVisitorAttributes(configObj, userAttributes),
          },
          context: {
              accountId: configObj.accountId,
              projectId: configObj.projectId,
              revision: configObj.revision,
              clientName: clientEngine,
              clientVersion: clientVersion,
              anonymizeIP: configObj.anonymizeIP || false,
              botFiltering: configObj.botFiltering,
          },
          event: {
              id: eventId,
              key: eventKey,
          },
          revenue: revenue,
          value: eventValue,
          tags: eventTags,
      };
  };
  const buildVisitorAttributes = (configObj, attributes, logger) => {
      if (!attributes) {
          return [];
      }
      // Omit attribute values that are not supported by the log endpoint.
      const builtAttributes = [];
      Object.keys(attributes).forEach(function (attributeKey) {
          const attributeValue = attributes[attributeKey];
          if (typeof attributeValue === 'object' || typeof attributeValue === 'undefined') {
              return;
          }
          if (isAttributeValid(attributeKey, attributeValue)) {
              const attributeId = getAttributeId(configObj, attributeKey, logger);
              if (attributeId) {
                  builtAttributes.push({
                      entityId: attributeId,
                      key: attributeKey,
                      value: attributeValue,
                  });
              }
          }
      });
      return builtAttributes;
  };

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const EVENT_STORE_FULL = 'Event store is full. Not saving event with id %d.';

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const DEFAULT_MIN_BACKOFF = 1000;
  const DEFAULT_MAX_BACKOFF = 32000;
  const MAX_EVENTS_IN_STORE = 500;
  const LOGGER_NAME$5 = 'BatchEventProcessor';
  class BatchEventProcessor extends BaseService {
      constructor(config) {
          var _a;
          super(config.startupLogs);
          this.eventQueue = [];
          this.eventCountInStore = undefined;
          this.eventCountWaitPromise = Promise.resolve();
          this.maxEventsInStore = MAX_EVENTS_IN_STORE;
          this.idGenerator = new IdGenerator();
          this.runningTask = new Map();
          this.dispatchingEvents = new Map();
          this.eventEmitter = new EventEmitter();
          this.eventDispatcher = config.eventDispatcher;
          this.closingEventDispatcher = config.closingEventDispatcher;
          this.batchSize = config.batchSize;
          this.eventStore = config.eventStore;
          this.retryConfig = config.retryConfig;
          this.dispatchRepeater = config.dispatchRepeater;
          this.dispatchRepeater.setTask(() => this.flush());
          this.maxEventsInStore = Math.max(2 * config.batchSize, MAX_EVENTS_IN_STORE);
          this.failedEventRepeater = config.failedEventRepeater;
          (_a = this.failedEventRepeater) === null || _a === void 0 ? void 0 : _a.setTask(() => this.retryFailedEvents());
          if (config.logger) {
              this.setLogger(config.logger);
          }
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$5);
      }
      onDispatch(handler) {
          return this.eventEmitter.on('dispatch', handler);
      }
      retryFailedEvents() {
          return __awaiter(this, void 0, void 0, function* () {
              if (!this.eventStore) {
                  return;
              }
              const keys = (yield this.eventStore.getKeys()).filter((k) => !this.dispatchingEvents.has(k) && !this.eventQueue.find((e) => e.id === k));
              const events = yield (this.eventStore.operation === 'sync' ?
                  getBatchedSync(this.eventStore, keys) : getBatchedAsync(this.eventStore, keys));
              const failedEvents = [];
              events.forEach((e) => {
                  if (e) {
                      failedEvents.push(e);
                  }
              });
              if (failedEvents.length == 0) {
                  return;
              }
              failedEvents.sort((a, b) => a.id < b.id ? -1 : 1);
              const batches = [];
              let currentBatch = [];
              failedEvents.forEach((event) => {
                  if (currentBatch.length === this.batchSize ||
                      (currentBatch.length > 0 && !areEventContextsEqual(currentBatch[0].event, event.event))) {
                      batches.push({
                          request: buildLogEvent(currentBatch.map((e) => e.event)),
                          events: currentBatch,
                      });
                      currentBatch = [];
                  }
                  currentBatch.push(event);
              });
              if (currentBatch.length > 0) {
                  batches.push({
                      request: buildLogEvent(currentBatch.map((e) => e.event)),
                      events: currentBatch,
                  });
              }
              batches.forEach((batch) => {
                  this.dispatchBatch(batch, false);
              });
          });
      }
      createNewBatch() {
          if (this.eventQueue.length == 0) {
              return;
          }
          const events = [];
          const eventWithIds = [];
          this.eventQueue.forEach((event) => {
              events.push(event.event);
              eventWithIds.push(event);
          });
          this.eventQueue = [];
          return { request: buildLogEvent(events), events: eventWithIds };
      }
      executeDispatch(request, closing = false) {
          return __awaiter(this, void 0, void 0, function* () {
              const dispatcher = closing && this.closingEventDispatcher ? this.closingEventDispatcher : this.eventDispatcher;
              return dispatcher.dispatchEvent(request).then((res) => {
                  if (res.statusCode && !isSuccessStatusCode(res.statusCode)) {
                      return Promise.reject(new OptimizelyError(FAILED_TO_DISPATCH_EVENTS, res.statusCode));
                  }
                  return Promise.resolve(res);
              });
          });
      }
      dispatchBatch(batch, closing) {
          const { request, events } = batch;
          events.forEach((event) => {
              this.dispatchingEvents.set(event.id, event);
          });
          const runResult = this.retryConfig
              ? runWithRetry(() => this.executeDispatch(request, closing), this.retryConfig.backoffProvider(), this.retryConfig.maxRetries) : {
              result: this.executeDispatch(request, closing),
              cancelRetry: () => { },
          };
          this.eventEmitter.emit('dispatch', request);
          const taskId = this.idGenerator.getId();
          this.runningTask.set(taskId, runResult);
          runResult.result.then((res) => {
              events.forEach((event) => {
                  var _a;
                  (_a = this.eventStore) === null || _a === void 0 ? void 0 : _a.remove(event.id);
                  if (!event.notStored && this.eventCountInStore) {
                      this.eventCountInStore--;
                  }
              });
              return Promise.resolve();
          }).catch((err) => {
              var _a;
              // if the dispatch fails, the events will still be
              // in the store for future processing
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(err);
          }).finally(() => {
              this.runningTask.delete(taskId);
              events.forEach((event) => this.dispatchingEvents.delete(event.id));
          });
      }
      flush(closing = false) {
          return __awaiter(this, void 0, void 0, function* () {
              const batch = this.createNewBatch();
              if (!batch) {
                  return;
              }
              this.dispatchRepeater.reset();
              this.dispatchBatch(batch, closing);
          });
      }
      process(event) {
          return __awaiter(this, void 0, void 0, function* () {
              if (!this.isRunning()) {
                  return Promise.reject(new OptimizelyError(SERVICE_NOT_RUNNING, 'BatchEventProcessor'));
              }
              const eventWithId = {
                  id: this.idGenerator.getId(),
                  event: event,
              };
              yield this.storeEvent(eventWithId);
              if (this.eventQueue.length > 0 && !areEventContextsEqual(this.eventQueue[0].event, event)) {
                  this.flush();
              }
              this.eventQueue.push(eventWithId);
              if (this.eventQueue.length == this.batchSize) {
                  this.flush();
              }
              else if (!this.dispatchRepeater.isRunning()) {
                  this.dispatchRepeater.start();
              }
          });
      }
      readEventCountInStore(store) {
          var _a;
          return __awaiter(this, void 0, void 0, function* () {
              try {
                  const keys = yield store.getKeys();
                  this.eventCountInStore = keys.length;
              }
              catch (e) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(e);
              }
          });
      }
      findEventCountInStore() {
          return __awaiter(this, void 0, void 0, function* () {
              if (this.eventStore && this.eventCountInStore === undefined) {
                  const store = this.eventStore;
                  this.eventCountWaitPromise = this.eventCountWaitPromise.then(() => this.readEventCountInStore(store));
                  return this.eventCountWaitPromise;
              }
              return Promise.resolve();
          });
      }
      storeEvent(eventWithId) {
          var _a, _b;
          return __awaiter(this, void 0, void 0, function* () {
              yield this.findEventCountInStore();
              if (this.eventCountInStore !== undefined && this.eventCountInStore >= this.maxEventsInStore) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(EVENT_STORE_FULL, eventWithId.event.uuid);
                  eventWithId.notStored = true;
                  return;
              }
              yield Promise.resolve((_b = this.eventStore) === null || _b === void 0 ? void 0 : _b.set(eventWithId.id, eventWithId)).then(() => {
                  if (this.eventCountInStore !== undefined) {
                      this.eventCountInStore++;
                  }
              }).catch((e) => {
                  var _a;
                  eventWithId.notStored = true;
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(e);
              });
          });
      }
      start() {
          var _a;
          if (!this.isNew()) {
              return;
          }
          super.start();
          this.state = ServiceState.Running;
          if (!this.disposable) {
              (_a = this.failedEventRepeater) === null || _a === void 0 ? void 0 : _a.start();
          }
          this.retryFailedEvents();
          this.startPromise.resolve();
      }
      makeDisposable() {
          var _a, _b, _c;
          super.makeDisposable();
          this.batchSize = 1;
          this.retryConfig = {
              maxRetries: Math.min((_b = (_a = this.retryConfig) === null || _a === void 0 ? void 0 : _a.maxRetries) !== null && _b !== void 0 ? _b : 5, 5),
              backoffProvider: ((_c = this.retryConfig) === null || _c === void 0 ? void 0 : _c.backoffProvider) ||
                  (() => new ExponentialBackoff(DEFAULT_MIN_BACKOFF, DEFAULT_MAX_BACKOFF, 500)),
          };
      }
      stop() {
          var _a;
          if (this.isDone()) {
              return;
          }
          if (this.isNew()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'BatchEventProcessor')));
          }
          this.state = ServiceState.Stopping;
          this.dispatchRepeater.stop();
          (_a = this.failedEventRepeater) === null || _a === void 0 ? void 0 : _a.stop();
          this.flush(true);
          this.runningTask.forEach((task) => task.cancelRetry());
          Promise.allSettled(Array.from(this.runningTask.values()).map((task) => task.result)).then(() => {
              this.state = ServiceState.Terminated;
              this.stopPromise.resolve();
          });
      }
  }

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const INVALID_EVENT_DISPATCHER = 'Invalid event dispatcher';
  const FAILED_EVENT_RETRY_INTERVAL = 20 * 1000;
  const EVENT_STORE_PREFIX = 'optly_event:';
  const eventProcessorSymbol = Symbol();
  const validateEventDispatcher = (eventDispatcher) => {
      if (!eventDispatcher || typeof eventDispatcher !== 'object' || typeof eventDispatcher.dispatchEvent !== 'function') {
          throw new Error(INVALID_EVENT_DISPATCHER);
      }
  };
  const getBatchEventProcessor = (options, EventProcessorConstructor = BatchEventProcessor) => {
      const { eventDispatcher, closingEventDispatcher, retryOptions, eventStore } = options;
      validateEventDispatcher(eventDispatcher);
      if (closingEventDispatcher) {
          validateEventDispatcher(closingEventDispatcher);
      }
      if (eventStore) {
          validateStore(eventStore);
      }
      const retryConfig = retryOptions ? {
          maxRetries: retryOptions.maxRetries,
          backoffProvider: () => {
              var _a, _b;
              const minBackoff = (_a = retryOptions === null || retryOptions === void 0 ? void 0 : retryOptions.minBackoff) !== null && _a !== void 0 ? _a : DEFAULT_MIN_BACKOFF;
              const maxBackoff = (_b = retryOptions === null || retryOptions === void 0 ? void 0 : retryOptions.maxBackoff) !== null && _b !== void 0 ? _b : DEFAULT_MAX_BACKOFF;
              return new ExponentialBackoff(minBackoff, maxBackoff, 500);
          }
      } : undefined;
      const startupLogs = [];
      const { defaultFlushInterval, defaultBatchSize } = options;
      let flushInterval = defaultFlushInterval;
      if (options.flushInterval === undefined || options.flushInterval <= 0) {
          startupLogs.push({
              level: exports.LogLevel.Warn,
              message: 'Invalid flushInterval %s, defaulting to %s',
              params: [options.flushInterval, defaultFlushInterval],
          });
      }
      else {
          flushInterval = options.flushInterval;
      }
      let batchSize = defaultBatchSize;
      if (options.batchSize === undefined || options.batchSize <= 0) {
          startupLogs.push({
              level: exports.LogLevel.Warn,
              message: 'Invalid batchSize %s, defaulting to %s',
              params: [options.batchSize, defaultBatchSize],
          });
      }
      else {
          batchSize = options.batchSize;
      }
      const dispatchRepeater = new IntervalRepeater(flushInterval);
      const failedEventRepeater = options.failedEventRetryInterval ?
          new IntervalRepeater(options.failedEventRetryInterval) : undefined;
      return new EventProcessorConstructor({
          eventDispatcher,
          closingEventDispatcher,
          dispatchRepeater,
          failedEventRepeater,
          retryConfig,
          batchSize,
          eventStore,
          startupLogs,
      });
  };
  const wrapEventProcessor = (eventProcessor) => {
      return {
          [eventProcessorSymbol]: eventProcessor,
      };
  };
  const getOpaqueBatchEventProcessor = (options, EventProcessorConstructor = BatchEventProcessor) => {
      return wrapEventProcessor(getBatchEventProcessor(options, EventProcessorConstructor));
  };
  const extractEventProcessor = (eventProcessor) => {
      if (!eventProcessor || typeof eventProcessor !== 'object') {
          return undefined;
      }
      return eventProcessor[eventProcessorSymbol];
  };
  function getForwardingEventProcessor(dispatcher) {
      validateEventDispatcher(dispatcher);
      return new ForwardingEventProcessor(dispatcher);
  }

  /**
   * Copyright 2022-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class InMemoryLruCache {
      constructor(maxSize, ttl) {
          this.operation = 'sync';
          this.data = new Map();
          this.maxSize = maxSize;
          this.ttl = ttl;
      }
      lookup(key) {
          const element = this.data.get(key);
          if (!element)
              return undefined;
          this.data.delete(key);
          if (element.expiresAt && element.expiresAt <= Date.now()) {
              return undefined;
          }
          this.data.set(key, element);
          return element.value;
      }
      save(key, value) {
          this.data.delete(key);
          if (this.data.size === this.maxSize) {
              const firstMapEntryKey = this.data.keys().next().value;
              this.data.delete(firstMapEntryKey);
          }
          this.data.set(key, {
              value,
              expiresAt: this.ttl ? Date.now() + this.ttl : undefined,
          });
      }
      remove(key) {
          this.data.delete(key);
      }
      reset() {
          this.data.clear();
      }
      getKeys() {
          return Array.from(this.data.keys());
      }
  }

  /**
   * Copyright 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const LOGGER_NAME$4 = 'OdpEventApiManager';
  class DefaultOdpEventApiManager {
      constructor(requestHandler, requestDataGenerator, logger) {
          this.requestHandler = requestHandler;
          this.requestGenerator = requestDataGenerator;
          if (logger) {
              this.setLogger(logger);
          }
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$4);
      }
      sendEvents(odpConfig, events) {
          return __awaiter(this, void 0, void 0, function* () {
              if (events.length === 0) {
                  return {};
              }
              const { method, endpoint, headers, data } = this.requestGenerator(odpConfig, events);
              const request = this.requestHandler.makeRequest(endpoint, headers, method, data);
              return request.responsePromise;
          });
      }
  }
  const eventApiRequestGenerator = (odpConfig, events) => {
      const { apiHost, apiKey } = odpConfig;
      return {
          method: 'POST',
          endpoint: `${apiHost}/v3/events`,
          headers: {
              'Content-Type': 'application/json',
              'x-api-key': apiKey,
          },
          data: JSON.stringify(events, (_, value) => {
              return value instanceof Map ? Object.fromEntries(value) : value;
          }),
      };
  };

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  var ODP_USER_KEY;
  (function (ODP_USER_KEY) {
      ODP_USER_KEY["VUID"] = "vuid";
      ODP_USER_KEY["FS_USER_ID"] = "fs_user_id";
      ODP_USER_KEY["FS_USER_ID_ALIAS"] = "fs-user-id";
  })(ODP_USER_KEY || (ODP_USER_KEY = {}));
  var ODP_EVENT_ACTION;
  (function (ODP_EVENT_ACTION) {
      ODP_EVENT_ACTION["IDENTIFIED"] = "identified";
      ODP_EVENT_ACTION["INITIALIZED"] = "client_initialized";
  })(ODP_EVENT_ACTION || (ODP_EVENT_ACTION = {}));
  const ODP_DEFAULT_EVENT_TYPE = 'fullstack';

  /**
   * Copyright 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const LOGGER_NAME$3 = 'OdpEventManager';
  class DefaultOdpEventManager extends BaseService {
      constructor(config) {
          super(config.startUpLogs);
          this.queue = [];
          this.apiManager = config.apiManager;
          this.batchSize = config.batchSize;
          this.retryConfig = config.retryConfig;
          this.repeater = config.repeater;
          this.repeater.setTask(() => this.flush());
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$3);
          this.apiManager.setLogger(logger.child());
      }
      executeDispatch(odpConfig, batch) {
          return __awaiter(this, void 0, void 0, function* () {
              const res = yield this.apiManager.sendEvents(odpConfig, batch);
              if (res.statusCode && !isSuccessStatusCode(res.statusCode)) {
                  return Promise.reject(new OptimizelyError(FAILED_TO_DISPATCH_EVENTS, res.statusCode));
              }
              return yield Promise.resolve(res);
          });
      }
      flush() {
          return __awaiter(this, void 0, void 0, function* () {
              if (!this.odpIntegrationConfig || !this.odpIntegrationConfig.integrated) {
                  return;
              }
              const odpConfig = this.odpIntegrationConfig.odpConfig;
              const batch = this.queue;
              this.queue = [];
              // as the queue has been emptied, stop repeating flush
              // until more events become available
              this.repeater.reset();
              return runWithRetry(() => this.executeDispatch(odpConfig, batch), this.retryConfig.backoffProvider(), this.retryConfig.maxRetries).result.catch((err) => {
                  var _a;
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(FAILED_TO_SEND_ODP_EVENTS, err);
              });
          });
      }
      start() {
          if (!this.isNew()) {
              return;
          }
          super.start();
          if (this.odpIntegrationConfig) {
              this.goToRunningState();
          }
          else {
              this.state = ServiceState.Starting;
          }
      }
      makeDisposable() {
          super.makeDisposable();
          this.retryConfig.maxRetries = Math.min(this.retryConfig.maxRetries, 5);
          this.batchSize = 1;
      }
      updateConfig(odpIntegrationConfig) {
          if (this.isDone()) {
              return;
          }
          if (this.isNew()) {
              this.odpIntegrationConfig = odpIntegrationConfig;
              return;
          }
          if (this.isStarting()) {
              this.odpIntegrationConfig = odpIntegrationConfig;
              this.goToRunningState();
              return;
          }
          // already running, flush the queue using the previous config first before updating the config
          this.flush();
          this.odpIntegrationConfig = odpIntegrationConfig;
      }
      goToRunningState() {
          this.state = ServiceState.Running;
          this.startPromise.resolve();
      }
      stop() {
          if (this.isDone()) {
              return;
          }
          if (this.isNew()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'OdpEventManager')));
          }
          this.flush();
          this.state = ServiceState.Terminated;
          this.stopPromise.resolve();
      }
      sendEvent(event) {
          var _a, _b, _c, _d, _e, _f;
          if (!this.isRunning()) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(SERVICE_NOT_RUNNING, 'OdpEventManager');
              return;
          }
          if (!((_b = this.odpIntegrationConfig) === null || _b === void 0 ? void 0 : _b.integrated)) {
              (_c = this.logger) === null || _c === void 0 ? void 0 : _c.error(ODP_NOT_INTEGRATED);
              return;
          }
          if (event.identifiers.size === 0) {
              (_d = this.logger) === null || _d === void 0 ? void 0 : _d.error(ODP_EVENTS_SHOULD_HAVE_ATLEAST_ONE_KEY_VALUE);
              return;
          }
          if (!this.isDataValid(event.data)) {
              (_e = this.logger) === null || _e === void 0 ? void 0 : _e.error(EVENT_DATA_INVALID);
              return;
          }
          if (!event.action) {
              (_f = this.logger) === null || _f === void 0 ? void 0 : _f.error(EVENT_ACTION_INVALID);
              return;
          }
          if (event.type === '') {
              event.type = ODP_DEFAULT_EVENT_TYPE;
          }
          Array.from(event.identifiers.entries()).forEach(([key, value]) => {
              // Catch for fs-user-id, FS-USER-ID, and FS_USER_ID and assign value to fs_user_id identifier.
              if (ODP_USER_KEY.FS_USER_ID_ALIAS === key.toLowerCase() ||
                  ODP_USER_KEY.FS_USER_ID === key.toLowerCase()) {
                  event.identifiers.delete(key);
                  event.identifiers.set(ODP_USER_KEY.FS_USER_ID, value);
              }
          });
          this.processEvent(event);
      }
      isDataValid(data) {
          const validTypes = ['string', 'number', 'boolean'];
          return Array.from(data.values()).reduce((valid, value) => valid && (value === null || validTypes.includes(typeof value)), true);
      }
      processEvent(event) {
          this.queue.push(event);
          if (this.queue.length === this.batchSize) {
              this.flush();
          }
          else if (!this.repeater.isRunning()) {
              this.repeater.start();
          }
      }
  }

  /**
   * Copyright 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class OdpEvent {
      /**
       * Event to be sent and stored in the Optimizely Data Platform
       * @param type Type of event (typically "fullstack")
       * @param action Subcategory of the event type
       * @param identifiers Key-value map of user identifiers
       * @param data Event data in a key-value map.
       */
      constructor(type, action, identifiers, data) {
          this.type = type;
          this.action = action;
          this.identifiers = identifiers !== null && identifiers !== void 0 ? identifiers : new Map();
          this.data = data !== null && data !== void 0 ? data : new Map();
      }
  }

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const VUID_PREFIX = `vuid_`;
  const VUID_MAX_LENGTH = 32;
  const isVuid = (vuid) => vuid.startsWith(VUID_PREFIX) && vuid.length > VUID_PREFIX.length;
  const makeVuid = () => {
      // make sure UUIDv4 is used (not UUIDv1 or UUIDv6) since the trailing 5 chars will be truncated. See TDD for details.
      const uuid = v4();
      const formatted = uuid.replace(/-/g, '');
      const vuidFull = `${VUID_PREFIX}${formatted}`;
      return vuidFull.length <= VUID_MAX_LENGTH ? vuidFull : vuidFull.substring(0, VUID_MAX_LENGTH);
  };

  /**
   * Copyright 2023-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const LOGGER_NAME$2 = 'OdpManager';
  class DefaultOdpManager extends BaseService {
      constructor(config) {
          super();
          this.clientEngine = JAVASCRIPT_CLIENT_ENGINE;
          this.clientVersion = CLIENT_VERSION;
          this.segmentManager = config.segmentManager;
          this.eventManager = config.eventManager;
          this.configPromise = resolvablePromise();
          if (config.userAgentParser) {
              const { os, device } = config.userAgentParser.parseUserAgentInfo();
              const userAgentInfo = {
                  'os': os.name,
                  'os_version': os.version,
                  'device_type': device.type,
                  'model': device.model,
              };
              this.userAgentData = new Map(Object.entries(userAgentInfo).filter(([_, value]) => value != null && value != undefined));
          }
          if (config.logger) {
              this.setLogger(config.logger);
          }
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$2);
          this.eventManager.setLogger(logger.child());
          this.segmentManager.setLogger(logger.child());
      }
      setClientInfo(clientEngine, clientVersion) {
          this.clientEngine = clientEngine;
          this.clientVersion = clientVersion;
      }
      start() {
          if (!this.isNew()) {
              return;
          }
          this.state = ServiceState.Starting;
          this.eventManager.start();
          const startDependencies = [
              this.configPromise,
              this.eventManager.onRunning(),
          ];
          Promise.all(startDependencies)
              .then(() => {
              this.handleStartSuccess();
          }).catch((err) => {
              this.handleStartFailure(err);
          });
      }
      makeDisposable() {
          super.makeDisposable();
          this.eventManager.makeDisposable();
      }
      handleStartSuccess() {
          if (this.isDone()) {
              return;
          }
          this.state = ServiceState.Running;
          this.startPromise.resolve();
      }
      handleStartFailure(error) {
          if (this.isDone()) {
              return;
          }
          this.state = ServiceState.Failed;
          this.startPromise.reject(error);
          this.stopPromise.reject(error);
      }
      stop() {
          if (this.isDone()) {
              return;
          }
          if (!this.isRunning()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'OdpManager')));
          }
          this.state = ServiceState.Stopping;
          this.eventManager.stop();
          this.eventManager.onTerminated().then(() => {
              this.state = ServiceState.Terminated;
              this.stopPromise.resolve();
          }).catch((err) => {
              this.state = ServiceState.Failed;
              this.stopPromise.reject(err);
          });
      }
      updateConfig(odpIntegrationConfig) {
          // do nothing if config did not change
          if (this.odpIntegrationConfig && odpIntegrationsAreEqual(this.odpIntegrationConfig, odpIntegrationConfig)) {
              return false;
          }
          if (this.isDone()) {
              return false;
          }
          this.odpIntegrationConfig = odpIntegrationConfig;
          this.configPromise.resolve();
          this.segmentManager.updateConfig(odpIntegrationConfig);
          this.eventManager.updateConfig(odpIntegrationConfig);
          return true;
      }
      /**
       * Attempts to fetch and return a list of a user's qualified segments from the local segments cache.
       * If no cached data exists for the target user, this fetches and caches data from the ODP server instead.
       * @param {string}                          userId  - Unique identifier of a target user.
       * @param {Array<OptimizelySegmentOption>}  options - An array of OptimizelySegmentOption used to ignore and/or reset the cache.
       * @returns {Promise<string[] | null>}      A promise holding either a list of qualified segments or null.
       */
      fetchQualifiedSegments(userId, options = []) {
          return __awaiter(this, void 0, void 0, function* () {
              if (isVuid(userId)) {
                  return this.segmentManager.fetchQualifiedSegments(ODP_USER_KEY.VUID, userId, options);
              }
              return this.segmentManager.fetchQualifiedSegments(ODP_USER_KEY.FS_USER_ID, userId, options);
          });
      }
      identifyUser(userId, vuid) {
          const identifiers = new Map();
          let finalUserId = userId;
          let finalVuid = vuid;
          if (!vuid && isVuid(userId)) {
              finalVuid = userId;
              finalUserId = undefined;
          }
          if (finalVuid) {
              identifiers.set(ODP_USER_KEY.VUID, finalVuid);
          }
          if (finalUserId) {
              identifiers.set(ODP_USER_KEY.FS_USER_ID, finalUserId);
          }
          const event = new OdpEvent(ODP_DEFAULT_EVENT_TYPE, ODP_EVENT_ACTION.IDENTIFIED, identifiers);
          this.sendEvent(event);
      }
      sendEvent(event) {
          if (!event.identifiers.has(ODP_USER_KEY.VUID) && this.vuid) {
              event.identifiers.set(ODP_USER_KEY.VUID, this.vuid);
          }
          event.data = this.augmentCommonData(event.data);
          this.eventManager.sendEvent(event);
      }
      augmentCommonData(sourceData) {
          const data = new Map(this.userAgentData);
          data.set('idempotence_id', v4());
          data.set('data_source_type', 'sdk');
          data.set('data_source', this.clientEngine);
          data.set('data_source_version', this.clientVersion);
          sourceData.forEach((value, key) => data.set(key, value));
          return data;
      }
      setVuid(vuid) {
          this.vuid = vuid;
          this.onRunning().then(() => {
              var _a;
              if ((_a = this.odpIntegrationConfig) === null || _a === void 0 ? void 0 : _a.integrated) {
                  const event = new OdpEvent(ODP_DEFAULT_EVENT_TYPE, ODP_EVENT_ACTION.INITIALIZED);
                  this.sendEvent(event);
              }
          });
      }
  }

  var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

  function createCommonjsModule(fn, module) {
  	return module = { exports: {} }, fn(module, module.exports), module.exports;
  }

  var validate$4 = createCommonjsModule(function (module) {
  /**
   * JSONSchema Validator - Validates JavaScript objects using JSON Schemas
   *	(http://www.json.com/json-schema-proposal/)
   * Licensed under AFL-2.1 OR BSD-3-Clause
  To use the validator call the validate function with an instance object and an optional schema object.
  If a schema is provided, it will be used to validate. If the instance object refers to a schema (self-validating),
  that schema will be used to validate and the schema parameter is not necessary (if both exist,
  both validations will occur).
  The validate method will return an array of validation errors. If there are no errors, then an
  empty list will be returned. A validation error will have two properties:
  "property" which indicates which property had the error
  "message" which indicates what the error was
   */
  (function (root, factory) {
      if (module.exports) {
          // Node. Does not work with strict CommonJS, but
          // only CommonJS-like environments that support module.exports,
          // like Node.
          module.exports = factory();
      } else {
          // Browser globals
          root.jsonSchema = factory();
      }
  }(commonjsGlobal, function () {// setup primitive classes to be JSON Schema types
  var exports = validate;
  exports.Integer = {type:"integer"};
  var primitiveConstructors = {
  	String: String,
  	Boolean: Boolean,
  	Number: Number,
  	Object: Object,
  	Array: Array,
  	Date: Date
  };
  exports.validate = validate;
  function validate(/*Any*/instance,/*Object*/schema) {
  		// Summary:
  		//  	To use the validator call JSONSchema.validate with an instance object and an optional schema object.
  		// 		If a schema is provided, it will be used to validate. If the instance object refers to a schema (self-validating),
  		// 		that schema will be used to validate and the schema parameter is not necessary (if both exist,
  		// 		both validations will occur).
  		// 		The validate method will return an object with two properties:
  		// 			valid: A boolean indicating if the instance is valid by the schema
  		// 			errors: An array of validation errors. If there are no errors, then an
  		// 					empty list will be returned. A validation error will have two properties:
  		// 						property: which indicates which property had the error
  		// 						message: which indicates what the error was
  		//
  		return validate(instance, schema, {changing: false});//, coerce: false, existingOnly: false});
  	}exports.checkPropertyChange = function(/*Any*/value,/*Object*/schema, /*String*/property) {
  		// Summary:
  		// 		The checkPropertyChange method will check to see if an value can legally be in property with the given schema
  		// 		This is slightly different than the validate method in that it will fail if the schema is readonly and it will
  		// 		not check for self-validation, it is assumed that the passed in value is already internally valid.
  		// 		The checkPropertyChange method will return the same object type as validate, see JSONSchema.validate for
  		// 		information.
  		//
  		return validate(value, schema, {changing: property || "property"});
  	};
  var validate = exports._validate = function(/*Any*/instance,/*Object*/schema,/*Object*/options) {

  	if (!options) options = {};
  	var _changing = options.changing;

  	function getType(schema){
  		return schema.type || (primitiveConstructors[schema.name] == schema && schema.name.toLowerCase());
  	}
  	var errors = [];
  	// validate a value against a property definition
  	function checkProp(value, schema, path,i){

  		var l;
  		path += path ? typeof i == 'number' ? '[' + i + ']' : typeof i == 'undefined' ? '' : '.' + i : i;
  		function addError(message){
  			errors.push({property:path,message:message});
  		}

  		if((typeof schema != 'object' || schema instanceof Array) && (path || typeof schema != 'function') && !(schema && getType(schema))){
  			if(typeof schema == 'function'){
  				if(!(value instanceof schema)){
  					addError("is not an instance of the class/constructor " + schema.name);
  				}
  			}else if(schema){
  				addError("Invalid schema/property definition " + schema);
  			}
  			return null;
  		}
  		if(_changing && schema.readonly){
  			addError("is a readonly field, it can not be changed");
  		}
  		if(schema['extends']){ // if it extends another schema, it must pass that schema as well
  			checkProp(value,schema['extends'],path,i);
  		}
  		// validate a value against a type definition
  		function checkType(type,value){
  			if(type){
  				if(typeof type == 'string' && type != 'any' &&
  						(type == 'null' ? value !== null : typeof value != type) &&
  						!(value instanceof Array && type == 'array') &&
  						!(value instanceof Date && type == 'date') &&
  						!(type == 'integer' && value%1===0)){
  					return [{property:path,message:value + " - " + (typeof value) + " value found, but a " + type + " is required"}];
  				}
  				if(type instanceof Array){
  					var unionErrors=[];
  					for(var j = 0; j < type.length; j++){ // a union type
  						if(!(unionErrors=checkType(type[j],value)).length){
  							break;
  						}
  					}
  					if(unionErrors.length){
  						return unionErrors;
  					}
  				}else if(typeof type == 'object'){
  					var priorErrors = errors;
  					errors = [];
  					checkProp(value,type,path);
  					var theseErrors = errors;
  					errors = priorErrors;
  					return theseErrors;
  				}
  			}
  			return [];
  		}
  		if(value === undefined){
  			if(schema.required){
  				addError("is missing and it is required");
  			}
  		}else {
  			errors = errors.concat(checkType(getType(schema),value));
  			if(schema.disallow && !checkType(schema.disallow,value).length){
  				addError(" disallowed value was matched");
  			}
  			if(value !== null){
  				if(value instanceof Array){
  					if(schema.items){
  						var itemsIsArray = schema.items instanceof Array;
  						var propDef = schema.items;
  						for (i = 0, l = value.length; i < l; i += 1) {
  							if (itemsIsArray)
  								propDef = schema.items[i];
  							if (options.coerce)
  								value[i] = options.coerce(value[i], propDef);
  							errors.concat(checkProp(value[i],propDef,path,i));
  						}
  					}
  					if(schema.minItems && value.length < schema.minItems){
  						addError("There must be a minimum of " + schema.minItems + " in the array");
  					}
  					if(schema.maxItems && value.length > schema.maxItems){
  						addError("There must be a maximum of " + schema.maxItems + " in the array");
  					}
  				}else if(schema.properties || schema.additionalProperties){
  					errors.concat(checkObj(value, schema.properties, path, schema.additionalProperties));
  				}
  				if(schema.pattern && typeof value == 'string' && !value.match(schema.pattern)){
  					addError("does not match the regex pattern " + schema.pattern);
  				}
  				if(schema.maxLength && typeof value == 'string' && value.length > schema.maxLength){
  					addError("may only be " + schema.maxLength + " characters long");
  				}
  				if(schema.minLength && typeof value == 'string' && value.length < schema.minLength){
  					addError("must be at least " + schema.minLength + " characters long");
  				}
  				if(typeof schema.minimum !== 'undefined' && typeof value == typeof schema.minimum &&
  						schema.minimum > value){
  					addError("must have a minimum value of " + schema.minimum);
  				}
  				if(typeof schema.maximum !== 'undefined' && typeof value == typeof schema.maximum &&
  						schema.maximum < value){
  					addError("must have a maximum value of " + schema.maximum);
  				}
  				if(schema['enum']){
  					var enumer = schema['enum'];
  					l = enumer.length;
  					var found;
  					for(var j = 0; j < l; j++){
  						if(enumer[j]===value){
  							found=1;
  							break;
  						}
  					}
  					if(!found){
  						addError("does not have a value in the enumeration " + enumer.join(", "));
  					}
  				}
  				if(typeof schema.maxDecimal == 'number' &&
  					(value.toString().match(new RegExp("\\.[0-9]{" + (schema.maxDecimal + 1) + ",}")))){
  					addError("may only have " + schema.maxDecimal + " digits of decimal places");
  				}
  			}
  		}
  		return null;
  	}
  	// validate an object against a schema
  	function checkObj(instance,objTypeDef,path,additionalProp){

  		if(typeof objTypeDef =='object'){
  			if(typeof instance != 'object' || instance instanceof Array){
  				errors.push({property:path,message:"an object is required"});
  			}
  			
  			for(var i in objTypeDef){ 
  				if(objTypeDef.hasOwnProperty(i) && i != '__proto__' && i != 'constructor'){
  					var value = instance.hasOwnProperty(i) ? instance[i] : undefined;
  					// skip _not_ specified properties
  					if (value === undefined && options.existingOnly) continue;
  					var propDef = objTypeDef[i];
  					// set default
  					if(value === undefined && propDef["default"]){
  						value = instance[i] = propDef["default"];
  					}
  					if(options.coerce && i in instance){
  						value = instance[i] = options.coerce(value, propDef);
  					}
  					checkProp(value,propDef,path,i);
  				}
  			}
  		}
  		for(i in instance){
  			if(instance.hasOwnProperty(i) && !(i.charAt(0) == '_' && i.charAt(1) == '_') && objTypeDef && !objTypeDef[i] && additionalProp===false){
  				if (options.filter) {
  					delete instance[i];
  					continue;
  				} else {
  					errors.push({property:path,message:"The property " + i +
  						" is not defined in the schema and the schema does not allow additional properties"});
  				}
  			}
  			var requires = objTypeDef && objTypeDef[i] && objTypeDef[i].requires;
  			if(requires && !(requires in instance)){
  				errors.push({property:path,message:"the presence of the property " + i + " requires that " + requires + " also be present"});
  			}
  			value = instance[i];
  			if(additionalProp && (!(objTypeDef && typeof objTypeDef == 'object') || !(i in objTypeDef))){
  				if(options.coerce){
  					value = instance[i] = options.coerce(value, additionalProp);
  				}
  				checkProp(value,additionalProp,path,i);
  			}
  			if(!_changing && value && value.$schema){
  				errors = errors.concat(checkProp(value,value.$schema,path,i));
  			}
  		}
  		return errors;
  	}
  	if(schema){
  		checkProp(instance,schema,'',_changing || '');
  	}
  	if(!_changing && instance && instance.$schema){
  		checkProp(instance,instance.$schema,'','');
  	}
  	return {valid:!errors.length,errors:errors};
  };
  exports.mustBeValid = function(result){
  	//	summary:
  	//		This checks to ensure that the result is valid and will throw an appropriate error message if it is not
  	// result: the result returned from checkPropertyChange or validate
  	if(!result.valid){
  		throw new TypeError(result.errors.map(function(error){return "for property " + error.property + ': ' + error.message;}).join(", \n"));
  	}
  };

  return exports;
  }));
  });
  var validate_1 = validate$4.validate;

  var schemaDefinition = {
      $schema: 'http://json-schema.org/draft-04/schema#',
      title: 'Project Config JSON Schema',
      type: 'object',
      properties: {
          projectId: {
              type: 'string',
              required: true,
          },
          accountId: {
              type: 'string',
              required: true,
          },
          groups: {
              type: 'array',
              items: {
                  type: 'object',
                  properties: {
                      id: {
                          type: 'string',
                          required: true,
                      },
                      policy: {
                          type: 'string',
                          required: true,
                      },
                      trafficAllocation: {
                          type: 'array',
                          items: {
                              type: 'object',
                              properties: {
                                  entityId: {
                                      type: 'string',
                                      required: true,
                                  },
                                  endOfRange: {
                                      type: 'integer',
                                      required: true,
                                  },
                              },
                          },
                          required: true,
                      },
                      experiments: {
                          type: 'array',
                          items: {
                              type: 'object',
                              properties: {
                                  id: {
                                      type: 'string',
                                      required: true,
                                  },
                                  key: {
                                      type: 'string',
                                      required: true,
                                  },
                                  status: {
                                      type: 'string',
                                      required: true,
                                  },
                                  layerId: {
                                      type: 'string',
                                      required: true,
                                  },
                                  variations: {
                                      type: 'array',
                                      items: {
                                          type: 'object',
                                          properties: {
                                              id: {
                                                  type: 'string',
                                                  required: true,
                                              },
                                              key: {
                                                  type: 'string',
                                                  required: true,
                                              },
                                          },
                                      },
                                      required: true,
                                  },
                                  trafficAllocation: {
                                      type: 'array',
                                      items: {
                                          type: 'object',
                                          properties: {
                                              entityId: {
                                                  type: 'string',
                                                  required: true,
                                              },
                                              endOfRange: {
                                                  type: 'integer',
                                                  required: true,
                                              },
                                          },
                                      },
                                      required: true,
                                  },
                                  audienceIds: {
                                      type: 'array',
                                      items: {
                                          type: 'string',
                                      },
                                      required: true,
                                  },
                                  forcedVariations: {
                                      type: 'object',
                                      required: true,
                                  },
                              },
                          },
                          required: true,
                      },
                  },
              },
              required: true,
          },
          experiments: {
              type: 'array',
              items: {
                  type: 'object',
                  properties: {
                      id: {
                          type: 'string',
                          required: true,
                      },
                      key: {
                          type: 'string',
                          required: true,
                      },
                      status: {
                          type: 'string',
                          required: true,
                      },
                      layerId: {
                          type: 'string',
                          required: true,
                      },
                      variations: {
                          type: 'array',
                          items: {
                              type: 'object',
                              properties: {
                                  id: {
                                      type: 'string',
                                      required: true,
                                  },
                                  key: {
                                      type: 'string',
                                      required: true,
                                  },
                              },
                          },
                          required: true,
                      },
                      trafficAllocation: {
                          type: 'array',
                          items: {
                              type: 'object',
                              properties: {
                                  entityId: {
                                      type: 'string',
                                      required: true,
                                  },
                                  endOfRange: {
                                      type: 'integer',
                                      required: true,
                                  },
                              },
                          },
                          required: true,
                      },
                      audienceIds: {
                          type: 'array',
                          items: {
                              type: 'string',
                          },
                          required: true,
                      },
                      forcedVariations: {
                          type: 'object',
                          required: true,
                      },
                      cmab: {
                          type: 'object',
                          required: false,
                          properties: {
                              attributes: {
                                  type: 'array',
                                  items: {
                                      type: 'string',
                                  },
                                  required: true,
                              }
                          }
                      }
                  },
              },
              required: true,
          },
          events: {
              type: 'array',
              items: {
                  type: 'object',
                  properties: {
                      key: {
                          type: 'string',
                          required: true,
                      },
                      experimentIds: {
                          type: 'array',
                          items: {
                              type: 'string',
                              required: true,
                          },
                      },
                      id: {
                          type: 'string',
                          required: true,
                      },
                  },
              },
              required: true,
          },
          audiences: {
              type: 'array',
              items: {
                  type: 'object',
                  properties: {
                      id: {
                          type: 'string',
                          required: true,
                      },
                      name: {
                          type: 'string',
                          required: true,
                      },
                      conditions: {
                          type: 'string',
                          required: true,
                      },
                  },
              },
              required: true,
          },
          attributes: {
              type: 'array',
              items: {
                  type: 'object',
                  properties: {
                      id: {
                          type: 'string',
                          required: true,
                      },
                      key: {
                          type: 'string',
                          required: true,
                      },
                  },
              },
              required: true,
          },
          version: {
              type: 'string',
              required: true,
          },
          revision: {
              type: 'string',
              required: true,
          },
          integrations: {
              type: 'array',
              items: {
                  type: 'object',
                  properties: {
                      key: {
                          type: 'string',
                          required: true
                      },
                      host: {
                          type: 'string'
                      },
                      publicKey: {
                          type: 'string'
                      },
                      pixelUrl: {
                          type: 'string'
                      },
                  },
              },
          },
      },
  };
  const schema = schemaDefinition;

  /**
   * Copyright 2016-2017, 2020, 2022, 2024 Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Validate the given json object against the specified schema
   * @param {unknown} jsonObject The object to validate against the schema
   * @param {JSONSchema4} validationSchema Provided schema to use for validation
   * @param {boolean} shouldThrowOnError Should validation throw if invalid JSON object
   * @return {boolean} true if the given object is valid; throws or false if invalid
   */
  function validate$3(jsonObject, validationSchema = schema, shouldThrowOnError = true) {
      if (typeof jsonObject !== 'object' || jsonObject === null) {
          throw new OptimizelyError(NO_JSON_PROVIDED);
      }
      const result = validate_1(jsonObject, validationSchema);
      if (result.valid) {
          return true;
      }
      if (!shouldThrowOnError) {
          return false;
      }
      if (Array.isArray(result.errors)) {
          throw new OptimizelyError(INVALID_DATAFILE, result.errors[0].property, result.errors[0].message);
      }
      throw new OptimizelyError(INVALID_JSON);
  }

  /**
   * Copyright 2022, 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the 'License');
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an 'AS IS' BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * JSON Schema used to validate the ODP GraphQL response
   */
  const OdpResponseSchema = {
      $schema: 'https://json-schema.org/draft/2019-09/schema',
      $id: 'https://example.com/example.json',
      title: 'ODP Response Schema',
      type: 'object',
      required: [
          'data',
      ],
      properties: {
          data: {
              title: 'The data Schema',
              type: 'object',
              required: [
                  'customer',
              ],
              properties: {
                  customer: {
                      title: 'The customer Schema',
                      type: 'object',
                      required: [],
                      properties: {
                          audiences: {
                              title: 'The audiences Schema',
                              type: 'object',
                              required: [
                                  'edges',
                              ],
                              properties: {
                                  edges: {
                                      title: 'The edges Schema',
                                      type: 'array',
                                      items: {
                                          title: 'A Schema',
                                          type: 'object',
                                          required: [
                                              'node',
                                          ],
                                          properties: {
                                              node: {
                                                  title: 'The node Schema',
                                                  type: 'object',
                                                  required: [
                                                      'name',
                                                      'state',
                                                  ],
                                                  properties: {
                                                      name: {
                                                          title: 'The name Schema',
                                                          type: 'string',
                                                          examples: [
                                                              'has_email',
                                                              'has_email_opted_in',
                                                          ],
                                                      },
                                                      state: {
                                                          title: 'The state Schema',
                                                          type: 'string',
                                                          examples: [
                                                              'qualified',
                                                          ],
                                                      },
                                                  },
                                                  examples: [],
                                              },
                                          },
                                          examples: [],
                                      },
                                      examples: [],
                                  },
                              },
                              examples: [],
                          },
                      },
                      examples: [],
                  },
              },
              examples: [],
          },
          errors: {
              title: 'The errors Schema',
              type: 'array',
              default: [],
              items: {
                  title: 'A Schema',
                  type: 'object',
                  required: [
                      'message',
                      'locations',
                      'extensions',
                  ],
                  properties: {
                      message: {
                          title: 'The message Schema',
                          type: 'string',
                          examples: [
                              'Exception while fetching data (/customer) : java.lang.RuntimeException: could not resolve _fs_user_id = asdsdaddddd',
                          ],
                      },
                      locations: {
                          title: 'The locations Schema',
                          type: 'array',
                          items: {
                              title: 'A Schema',
                              type: 'object',
                              required: [
                                  'line',
                                  'column',
                              ],
                              properties: {
                                  line: {
                                      title: 'The line Schema',
                                      type: 'integer',
                                      examples: [
                                          2,
                                      ],
                                  },
                                  column: {
                                      title: 'The column Schema',
                                      type: 'integer',
                                      examples: [
                                          3,
                                      ],
                                  },
                              },
                              examples: [],
                          },
                          examples: [],
                      },
                      path: {
                          title: 'The path Schema',
                          type: 'array',
                          items: {
                              title: 'A Schema',
                              type: 'string',
                              examples: [
                                  'customer',
                              ],
                          },
                          examples: [],
                      },
                      extensions: {
                          title: 'The extensions Schema',
                          type: 'object',
                          required: [
                              'classification',
                          ],
                          properties: {
                              classification: {
                                  title: 'The classification Schema',
                                  type: 'string',
                                  examples: [
                                      'InvalidIdentifierException',
                                  ],
                              },
                          },
                          examples: [],
                      },
                  },
                  examples: [],
              },
              examples: [],
          },
      },
      examples: [],
  };

  /**
   * Copyright 2022-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Expected value for a qualified/valid segment
   */
  const QUALIFIED = 'qualified';
  /**
   * Return value when no valid segments found
   */
  const EMPTY_SEGMENTS_COLLECTION = [];
  /**
   * Return value for scenarios with no valid JSON
   */
  const EMPTY_JSON_RESPONSE = null;
  /**
   * Standard message for audience querying fetch errors
   */
  const AUDIENCE_FETCH_FAILURE_MESSAGE = 'Audience segments fetch failed';
  const LOGGER_NAME$1 = 'OdpSegmentApiManager';
  class DefaultOdpSegmentApiManager {
      constructor(requestHandler, logger) {
          /**
           * Converts the query parameters to a GraphQL JSON payload
           * @returns GraphQL JSON string
           */
          this.toGraphQLJson = (userKey, userValue, segmentsToCheck) => [
              '{"query" : "query {customer',
              `(${userKey} : \\"${userValue}\\") `,
              '{audiences',
              '(subset: [',
              ...((segmentsToCheck === null || segmentsToCheck === void 0 ? void 0 : segmentsToCheck.map((segment, index) => `\\"${segment}\\"${index < segmentsToCheck.length - 1 ? ',' : ''}`)) || ''),
              ']) {edges {node {name state}}}}}"}',
          ].join('');
          this.requestHandler = requestHandler;
          if (logger) {
              this.setLogger(logger);
          }
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME$1);
      }
      /**
       * Retrieves the audience segments from ODP
       * @param apiKey ODP public key
       * @param apiHost Host of ODP endpoint
       * @param userKey 'vuid' or 'fs_user_id key'
       * @param userValue Associated value to query for the user key
       * @param segmentsToCheck Audience segments to check for experiment inclusion
       */
      fetchSegments(apiKey, apiHost, userKey, userValue, segmentsToCheck) {
          var _a, _b, _c, _d, _e, _f, _g, _h, _j;
          return __awaiter(this, void 0, void 0, function* () {
              if ((segmentsToCheck === null || segmentsToCheck === void 0 ? void 0 : segmentsToCheck.length) === 0) {
                  return EMPTY_SEGMENTS_COLLECTION;
              }
              const endpoint = `${apiHost}/v3/graphql`;
              const query = this.toGraphQLJson(userKey, userValue, segmentsToCheck);
              const segmentsResponse = yield this.querySegments(apiKey, endpoint, query);
              if (!segmentsResponse) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(`${AUDIENCE_FETCH_FAILURE_MESSAGE} (network error)`);
                  return null;
              }
              const parsedSegments = this.parseSegmentsResponseJson(segmentsResponse);
              if (!parsedSegments) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(`${AUDIENCE_FETCH_FAILURE_MESSAGE} (decode error)`);
                  return null;
              }
              if (((_c = parsedSegments.errors) === null || _c === void 0 ? void 0 : _c.length) > 0) {
                  const { code, classification } = parsedSegments.errors[0].extensions;
                  if (code == 'INVALID_IDENTIFIER_EXCEPTION') {
                      (_d = this.logger) === null || _d === void 0 ? void 0 : _d.error(`${AUDIENCE_FETCH_FAILURE_MESSAGE} (invalid identifier)`);
                  }
                  else {
                      (_e = this.logger) === null || _e === void 0 ? void 0 : _e.error(`${AUDIENCE_FETCH_FAILURE_MESSAGE} (${classification})`);
                  }
                  return null;
              }
              const edges = (_h = (_g = (_f = parsedSegments === null || parsedSegments === void 0 ? void 0 : parsedSegments.data) === null || _f === void 0 ? void 0 : _f.customer) === null || _g === void 0 ? void 0 : _g.audiences) === null || _h === void 0 ? void 0 : _h.edges;
              if (!edges) {
                  (_j = this.logger) === null || _j === void 0 ? void 0 : _j.error(`${AUDIENCE_FETCH_FAILURE_MESSAGE} (decode error)`);
                  return null;
              }
              return edges.filter(edge => edge.node.state == QUALIFIED).map(edge => edge.node.name);
          });
      }
      /**
       * Handler for querying the ODP GraphQL endpoint
       * @param apiKey ODP API key
       * @param endpoint Fully-qualified GraphQL endpoint URL
       * @param userKey 'vuid' or 'fs_user_id'
       * @param userValue userKey's value
       * @param query GraphQL formatted query string
       * @returns JSON response string from ODP or null
       */
      querySegments(apiKey, endpoint, query) {
          return __awaiter(this, void 0, void 0, function* () {
              const method = 'POST';
              const url = endpoint;
              const headers = {
                  'Content-Type': 'application/json',
                  'x-api-key': apiKey,
              };
              try {
                  const request = this.requestHandler.makeRequest(url, headers, method, query);
                  const { statusCode, body } = yield request.responsePromise;
                  if (!(statusCode >= 200 && statusCode < 300)) {
                      return null;
                  }
                  return body;
              }
              catch (_a) {
                  return null;
              }
          });
      }
      /**
       * Parses JSON response
       * @param jsonResponse JSON response from ODP
       * @private
       * @returns Response Strongly-typed ODP Response object
       */
      parseSegmentsResponseJson(jsonResponse) {
          let jsonObject = {};
          try {
              jsonObject = JSON.parse(jsonResponse);
          }
          catch (_a) {
              return EMPTY_JSON_RESPONSE;
          }
          if (validate$3(jsonObject, OdpResponseSchema, false)) {
              return jsonObject;
          }
          return EMPTY_JSON_RESPONSE;
      }
  }

  /**
   * Copyright 2022, 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  // Options for defining behavior of OdpSegmentManager's caching mechanism when calling fetchSegments()
  var OptimizelySegmentOption;
  (function (OptimizelySegmentOption) {
      OptimizelySegmentOption["IGNORE_CACHE"] = "IGNORE_CACHE";
      OptimizelySegmentOption["RESET_CACHE"] = "RESET_CACHE";
  })(OptimizelySegmentOption || (OptimizelySegmentOption = {}));

  /**
   * Copyright 2022-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const LOGGER_NAME = 'OdpSegmentManager';
  class DefaultOdpSegmentManager {
      constructor(segmentsCache, odpSegmentApiManager, logger) {
          this.segmentsCache = segmentsCache;
          this.odpSegmentApiManager = odpSegmentApiManager;
          if (logger) {
              this.setLogger(logger);
          }
      }
      setLogger(logger) {
          this.logger = logger;
          this.logger.setName(LOGGER_NAME);
          this.odpSegmentApiManager.setLogger(logger.child());
      }
      /**
       * Attempts to fetch and return a list of a user's qualified segments from the local segments cache.
       * If no cached data exists for the target user, this fetches and caches data from the ODP server instead.
       * @param userKey Key used for identifying the id type.
       * @param userValue The id value itself.
       * @param options An array of OptimizelySegmentOption used to ignore and/or reset the cache.
       * @returns Qualified segments for the user from the cache or the ODP server if the cache is empty.
       */
      fetchQualifiedSegments(userKey, userValue, options) {
          var _a, _b;
          return __awaiter(this, void 0, void 0, function* () {
              if (!this.odpIntegrationConfig) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(ODP_CONFIG_NOT_AVAILABLE);
                  return null;
              }
              if (!this.odpIntegrationConfig.integrated) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.warn(ODP_NOT_INTEGRATED);
                  return null;
              }
              const odpConfig = this.odpIntegrationConfig.odpConfig;
              const segmentsToCheck = odpConfig.segmentsToCheck;
              if (!segmentsToCheck || segmentsToCheck.length <= 0) {
                  return [];
              }
              const cacheKey = this.makeCacheKey(userKey, userValue);
              const ignoreCache = options === null || options === void 0 ? void 0 : options.includes(OptimizelySegmentOption.IGNORE_CACHE);
              const resetCache = options === null || options === void 0 ? void 0 : options.includes(OptimizelySegmentOption.RESET_CACHE);
              if (resetCache) {
                  this.segmentsCache.reset();
              }
              if (!ignoreCache) {
                  const cachedSegments = yield this.segmentsCache.lookup(cacheKey);
                  if (cachedSegments) {
                      return cachedSegments;
                  }
              }
              const segments = yield this.odpSegmentApiManager.fetchSegments(odpConfig.apiKey, odpConfig.apiHost, userKey, userValue, segmentsToCheck);
              if (segments && !ignoreCache) {
                  this.segmentsCache.save(cacheKey, segments);
              }
              return segments;
          });
      }
      makeCacheKey(userKey, userValue) {
          return `${userKey}-$-${userValue}`;
      }
      updateConfig(config) {
          this.odpIntegrationConfig = config;
          this.segmentsCache.reset();
      }
  }

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const DEFAULT_CACHE_SIZE = 1000;
  const DEFAULT_CACHE_TIMEOUT = 600000;
  const DEFAULT_EVENT_BATCH_SIZE$1 = 100;
  const DEFAULT_EVENT_FLUSH_INTERVAL$1 = 10000;
  const DEFAULT_EVENT_MAX_RETRIES = 5;
  const DEFAULT_EVENT_MIN_BACKOFF = 1000;
  const DEFAULT_EVENT_MAX_BACKOFF = 32000;
  const INVALID_CACHE = 'Invalid cache';
  const INVALID_CACHE_METHOD = 'Invalid cache method %s';
  const odpManagerSymbol = Symbol();
  const validateCache = (cache) => {
      const errors = [];
      if (!cache || typeof cache !== 'object') {
          throw new Error(INVALID_CACHE);
      }
      for (const method of ['save', 'lookup', 'reset']) {
          if (typeof cache[method] !== 'function') {
              errors.push(INVALID_CACHE_METHOD.replace('%s', method));
          }
      }
      if (errors.length > 0) {
          throw new Error(errors.join(', '));
      }
  };
  const getDefaultSegmentsCache = (cacheSize, cacheTimeout) => {
      return new InMemoryLruCache(cacheSize || DEFAULT_CACHE_SIZE, cacheTimeout || DEFAULT_CACHE_TIMEOUT);
  };
  const getDefaultSegmentManager = (options) => {
      if (options.segmentsCache) {
          validateCache(options.segmentsCache);
      }
      return new DefaultOdpSegmentManager(options.segmentsCache || getDefaultSegmentsCache(options.segmentsCacheSize, options.segmentsCacheTimeout), new DefaultOdpSegmentApiManager(options.segmentRequestHandler));
  };
  const getDefaultEventManager = (options) => {
      return new DefaultOdpEventManager({
          apiManager: new DefaultOdpEventApiManager(options.eventRequestHandler, options.eventRequestGenerator),
          batchSize: options.eventBatchSize || DEFAULT_EVENT_BATCH_SIZE$1,
          repeater: new IntervalRepeater(options.eventFlushInterval || DEFAULT_EVENT_FLUSH_INTERVAL$1),
          retryConfig: {
              maxRetries: options.eventMaxRetries || DEFAULT_EVENT_MAX_RETRIES,
              backoffProvider: () => new ExponentialBackoff(options.eventMinBackoff || DEFAULT_EVENT_MIN_BACKOFF, options.eventMaxBackoff || DEFAULT_EVENT_MAX_BACKOFF, 500),
          },
      });
  };
  const getOdpManager = (options) => {
      const segmentManager = getDefaultSegmentManager(options);
      const eventManager = getDefaultEventManager(options);
      return new DefaultOdpManager({
          segmentManager,
          eventManager,
          userAgentParser: options.userAgentParser,
      });
  };
  const getOpaqueOdpManager = (options) => {
      return {
          [odpManagerSymbol]: getOdpManager(options),
      };
  };
  const extractOdpManager = (manager) => {
      if (!manager || typeof manager !== 'object') {
          return undefined;
      }
      return manager[odpManagerSymbol];
  };

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const vuidManagerSymbol = Symbol();
  const extractVuidManager = (opaqueVuidManager) => {
      if (!opaqueVuidManager || typeof opaqueVuidManager !== 'object') {
          return undefined;
      }
      return opaqueVuidManager[vuidManagerSymbol];
  };
  const wrapVuidManager = (vuidManager) => {
      return {
          [vuidManagerSymbol]: vuidManager
      };
  };

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const DECISION_NOTIFICATION_TYPES = {
      AB_TEST: 'ab-test',
      FEATURE: 'feature',
      FEATURE_TEST: 'feature-test',
      FEATURE_VARIABLE: 'feature-variable',
      ALL_FEATURE_VARIABLES: 'all-feature-variables',
      FLAG: 'flag',
  };
  const NOTIFICATION_TYPES = {
      ACTIVATE: 'ACTIVATE',
      DECISION: 'DECISION',
      LOG_EVENT: 'LOG_EVENT',
      OPTIMIZELY_CONFIG_UPDATE: 'OPTIMIZELY_CONFIG_UPDATE',
      TRACK: 'TRACK',
  };

  class ErrorReporter {
      constructor(logger, errorNotifier) {
          this.logger = logger;
          this.errorNotifier = errorNotifier;
      }
      report(error, ...params) {
          if (typeof error === 'string') {
              error = new OptimizelyError(error, ...params);
              this.report(error);
              return;
          }
          if (this.errorNotifier) {
              this.errorNotifier.notify(error);
          }
          if (this.logger) {
              this.logger.error(error);
          }
      }
      setLogger(logger) {
          this.logger = logger;
      }
      setErrorNotifier(errorNotifier) {
          this.errorNotifier = errorNotifier;
      }
  }

  /**
   * NotificationCenter allows registration and triggering of callback functions using
   * notification event types defined in NOTIFICATION_TYPES of utils/enums/index.js:
   * - ACTIVATE: An impression event will be sent to Optimizely.
   * - TRACK a conversion event will be sent to Optimizely
   */
  class DefaultNotificationCenter {
      /**
       * @constructor
       * @param   {NotificationCenterOptions}  options
       * @param   {LogHandler}                 options.logger       An instance of a logger to log messages with
       * @param   {ErrorHandler}               options.errorHandler An instance of errorHandler to handle any unexpected error
       */
      constructor(options) {
          this.removerId = 1;
          this.eventEmitter = new EventEmitter();
          this.removers = new Map();
          this.errorReporter = new ErrorReporter(options.logger, options.errorNotifier);
      }
      /**
       * Add a notification callback to the notification center
       * @param   {string}                   notificationType     One of the values from NOTIFICATION_TYPES in utils/enums/index.js
       * @param   {NotificationListener<T>}  callback             Function that will be called when the event is triggered
       * @returns {number}                   If the callback was successfully added, returns a listener ID which can be used
       * to remove the callback by calling removeNotificationListener. The ID is a number greater than 0.
       * If there was an error and the listener was not added, addNotificationListener returns -1. This
       * can happen if the first argument is not a valid notification type, or if the same callback
       * function was already added as a listener by a prior call to this function.
       */
      addNotificationListener(notificationType, callback) {
          const notificationTypeValues = objectValues(NOTIFICATION_TYPES);
          const isNotificationTypeValid = notificationTypeValues.indexOf(notificationType) > -1;
          if (!isNotificationTypeValid) {
              return -1;
          }
          const returnId = this.removerId++;
          const remover = this.eventEmitter.on(notificationType, this.wrapWithErrorReporting(notificationType, callback));
          this.removers.set(returnId, remover);
          return returnId;
      }
      wrapWithErrorReporting(notificationType, callback) {
          return (notificationData) => {
              try {
                  callback(notificationData);
              }
              catch (ex) {
                  const message = ex instanceof Error ? ex.message : String(ex);
                  this.errorReporter.report(NOTIFICATION_LISTENER_EXCEPTION, notificationType, message);
              }
          };
      }
      /**
       * Remove a previously added notification callback
       * @param   {number}                 listenerId ID of listener to be removed
       * @returns {boolean}                Returns true if the listener was found and removed, and false
       * otherwise.
       */
      removeNotificationListener(listenerId) {
          const remover = this.removers.get(listenerId);
          if (remover) {
              remover();
              return true;
          }
          return false;
      }
      /**
       * Removes all previously added notification listeners, for all notification types
       */
      clearAllNotificationListeners() {
          this.eventEmitter.removeAllListeners();
      }
      /**
       * Remove all previously added notification listeners for the argument type
       * @param   {NotificationType}    notificationType One of NotificationType
       */
      clearNotificationListeners(notificationType) {
          this.eventEmitter.removeListeners(notificationType);
      }
      /**
       * Fires notifications for the argument type. All registered callbacks for this type will be
       * called. The notificationData object will be passed on to callbacks called.
       * @param {NotificationType} notificationType One of NotificationType
       * @param {Object} notificationData Will be passed to callbacks called
       */
      sendNotifications(notificationType, notificationData) {
          this.eventEmitter.emit(notificationType, notificationData);
      }
  }
  /**
   * Create an instance of NotificationCenter
   * @param   {NotificationCenterOptions}   options
   * @returns {NotificationCenter}          An instance of NotificationCenter
   */
  function createNotificationCenter(options) {
      return new DefaultNotificationCenter(options);
  }

  /**
   * Copyright 2020-2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  var VariableType;
  (function (VariableType) {
      VariableType["BOOLEAN"] = "boolean";
      VariableType["DOUBLE"] = "double";
      VariableType["INTEGER"] = "integer";
      VariableType["STRING"] = "string";
      VariableType["JSON"] = "json";
  })(VariableType || (VariableType = {}));
  //TODO: Move OptimizelyDecideOption to @optimizely/optimizely-sdk/lib/utils/enums
  exports.OptimizelyDecideOption = void 0;
  (function (OptimizelyDecideOption) {
      OptimizelyDecideOption["DISABLE_DECISION_EVENT"] = "DISABLE_DECISION_EVENT";
      OptimizelyDecideOption["ENABLED_FLAGS_ONLY"] = "ENABLED_FLAGS_ONLY";
      OptimizelyDecideOption["IGNORE_USER_PROFILE_SERVICE"] = "IGNORE_USER_PROFILE_SERVICE";
      OptimizelyDecideOption["INCLUDE_REASONS"] = "INCLUDE_REASONS";
      OptimizelyDecideOption["EXCLUDE_VARIABLES"] = "EXCLUDE_VARIABLES";
      OptimizelyDecideOption["IGNORE_CMAB_CACHE"] = "IGNORE_CMAB_CACHE";
      OptimizelyDecideOption["RESET_CMAB_CACHE"] = "RESET_CMAB_CACHE";
      OptimizelyDecideOption["INVALIDATE_USER_CMAB_CACHE"] = "INVALIDATE_USER_CMAB_CACHE";
  })(exports.OptimizelyDecideOption || (exports.OptimizelyDecideOption = {}));

  function newErrorDecision(key, user, reasons) {
      return {
          variationKey: null,
          enabled: false,
          variables: {},
          ruleKey: null,
          flagKey: key,
          userContext: user,
          reasons: reasons,
      };
  }

  const FORCED_DECISION_NULL_RULE_KEY = '$opt_null_rule_key';
  class OptimizelyUserContext {
      constructor({ optimizely, userId, attributes }) {
          this._qualifiedSegments = null;
          this.optimizely = optimizely;
          this.userId = userId;
          this.attributes = Object.assign({}, attributes);
          this.forcedDecisionsMap = {};
      }
      /**
       * Sets an attribute for a given key.
       * @param     {string}                     key         An attribute key
       * @param     {any}                        value       An attribute value
       */
      setAttribute(key, value) {
          this.attributes[key] = value;
      }
      getUserId() {
          return this.userId;
      }
      getAttributes() {
          return Object.assign({}, this.attributes);
      }
      getOptimizely() {
          return this.optimizely;
      }
      get qualifiedSegments() {
          return this._qualifiedSegments;
      }
      set qualifiedSegments(qualifiedSegments) {
          this._qualifiedSegments = qualifiedSegments;
      }
      /**
       * Returns a decision result for a given flag key and a user context, which contains all data required to deliver the flag.
       * If the SDK finds an error, it will return a decision with null for variationKey. The decision will include an error message in reasons.
       * @param     {string}                     key         A flag key for which a decision will be made.
       * @param     {OptimizelyDecideOption}     options     An array of options for decision-making.
       * @return    {OptimizelyDecision}                     A decision result.
       */
      decide(key, options = []) {
          return this.optimizely.decide(this.cloneUserContext(), key, options);
      }
      /**
       * Returns a promise that resolves in decision result for a given flag key and a user context, which contains all data required to deliver the flag.
       * If the SDK finds an error, it will return a decision with null for variationKey. The decision will include an error message in reasons.
       * @param     {string}                     key         A flag key for which a decision will be made.
       * @param     {OptimizelyDecideOption}     options     An array of options for decision-making.
       * @return    {Promise<OptimizelyDecision>}                     A Promise that resolves decision result.
       */
      decideAsync(key, options) {
          return this.optimizely.decideAsync(this.cloneUserContext(), key, options);
      }
      /**
       * Returns an object of decision results for multiple flag keys and a user context.
       * If the SDK finds an error for a key, the response will include a decision for the key showing reasons for the error.
       * The SDK will always return key-mapped decisions. When it cannot process requests, it will return an empty map after logging the errors.
       * @param     {string[]}                   keys        An array of flag keys for which decisions will be made.
       * @param     {OptimizelyDecideOption[]}   options     An array of options for decision-making.
       * @return    {[key: string]: OptimizelyDecision}      An object of decision results mapped by flag keys.
       */
      decideForKeys(keys, options = []) {
          return this.optimizely.decideForKeys(this.cloneUserContext(), keys, options);
      }
      /**
       * Returns a promise that resolves in an object of decision results for multiple flag keys and a user context.
       * If the SDK finds an error for a key, the response will include a decision for the key showing reasons for the error.
       * The SDK will always return key-mapped decisions. When it cannot process requests, it will return an empty map after logging the errors.
       * @param     {string[]}                   keys        An array of flag keys for which decisions will be made.
       * @param     {OptimizelyDecideOption[]}   options     An array of options for decision-making.
       * @return    {Promise<Record<string, OptimizelyDecision>>}      A promise that resolves in an object of decision results mapped by flag keys.
       */
      decideForKeysAsync(keys, options) {
          return this.optimizely.decideForKeysAsync(this.cloneUserContext(), keys, options);
      }
      /**
       * Returns an object of decision results for all active flag keys.
       * @param     {OptimizelyDecideOption[]}   options     An array of options for decision-making.
       * @return    {[key: string]: OptimizelyDecision}      An object of all decision results mapped by flag keys.
       */
      decideAll(options = []) {
          return this.optimizely.decideAll(this.cloneUserContext(), options);
      }
      /**
       * Returns a promise that resolves in an object of decision results for all active flag keys.
       * @param     {OptimizelyDecideOption[]}   options     An array of options for decision-making.
       * @return    {Promise<Record<string ,OptimizelyDecision>>}      A promise that resolves in an object of all decision results mapped by flag keys.
       */
      decideAllAsync(options = []) {
          return this.optimizely.decideAllAsync(this.cloneUserContext(), options);
      }
      /**
       * Tracks an event.
       * @param     {string}                     eventName The event name.
       * @param     {EventTags}                  eventTags An optional map of event tag names to event tag values.
       */
      trackEvent(eventName, eventTags) {
          this.optimizely.track(eventName, this.userId, this.attributes, eventTags);
      }
      /**
       * Sets the forced decision for specified optimizely decision context.
       * @param     {OptimizelyDecisionContext}   context      OptimizelyDecisionContext containing flagKey and optional ruleKey.
       * @param     {OptimizelyForcedDecision}    decision     OptimizelyForcedDecision containing forced variation key.
       * @return    {boolean}                     true if the forced decision has been set successfully.
       */
      setForcedDecision(context, decision) {
          var _a;
          const flagKey = context.flagKey;
          const ruleKey = (_a = context.ruleKey) !== null && _a !== void 0 ? _a : FORCED_DECISION_NULL_RULE_KEY;
          const variationKey = decision.variationKey;
          const forcedDecision = { variationKey };
          if (!this.forcedDecisionsMap[flagKey]) {
              this.forcedDecisionsMap[flagKey] = {};
          }
          this.forcedDecisionsMap[flagKey][ruleKey] = forcedDecision;
          return true;
      }
      /**
       * Returns the forced decision for specified optimizely decision context.
       * @param     {OptimizelyDecisionContext}  context  OptimizelyDecisionContext containing flagKey and optional ruleKey.
       * @return    {OptimizelyForcedDecision|null}       OptimizelyForcedDecision for specified context if exists or null.
       */
      getForcedDecision(context) {
          return this.findForcedDecision(context);
      }
      /**
       * Removes the forced decision for specified optimizely decision context.
       * @param     {OptimizelyDecisionContext}  context  OptimizelyDecisionContext containing flagKey and optional ruleKey.
       * @return    {boolean}                    true if the forced decision has been removed successfully
       */
      removeForcedDecision(context) {
          var _a;
          const ruleKey = (_a = context.ruleKey) !== null && _a !== void 0 ? _a : FORCED_DECISION_NULL_RULE_KEY;
          const flagKey = context.flagKey;
          let isForcedDecisionRemoved = false;
          if (this.forcedDecisionsMap.hasOwnProperty(flagKey)) {
              const forcedDecisionByRuleKey = this.forcedDecisionsMap[flagKey];
              if (forcedDecisionByRuleKey.hasOwnProperty(ruleKey)) {
                  delete this.forcedDecisionsMap[flagKey][ruleKey];
                  isForcedDecisionRemoved = true;
              }
              if (Object.keys(this.forcedDecisionsMap[flagKey]).length === 0) {
                  delete this.forcedDecisionsMap[flagKey];
              }
          }
          return isForcedDecisionRemoved;
      }
      /**
       * Removes all forced decisions bound to this user context.
       * @return    {boolean}                    true if the forced decision has been removed successfully
       */
      removeAllForcedDecisions() {
          this.forcedDecisionsMap = {};
          return true;
      }
      /**
       * Finds a forced decision in forcedDecisionsMap for provided optimizely decision context.
       * @param     {OptimizelyDecisionContext}     context  OptimizelyDecisionContext containing flagKey and optional ruleKey.
       * @return    {OptimizelyForcedDecision|null}          OptimizelyForcedDecision for specified context if exists or null.
       */
      findForcedDecision(context) {
          var _a;
          let variationKey;
          const validRuleKey = (_a = context.ruleKey) !== null && _a !== void 0 ? _a : FORCED_DECISION_NULL_RULE_KEY;
          const flagKey = context.flagKey;
          if (this.forcedDecisionsMap.hasOwnProperty(context.flagKey)) {
              const forcedDecisionByRuleKey = this.forcedDecisionsMap[flagKey];
              if (forcedDecisionByRuleKey.hasOwnProperty(validRuleKey)) {
                  variationKey = forcedDecisionByRuleKey[validRuleKey].variationKey;
                  return { variationKey };
              }
          }
          return null;
      }
      cloneUserContext() {
          const userContext = new OptimizelyUserContext({
              optimizely: this.getOptimizely(),
              userId: this.getUserId(),
              attributes: this.getAttributes(),
          });
          if (Object.keys(this.forcedDecisionsMap).length > 0) {
              userContext.forcedDecisionsMap = Object.assign({}, this.forcedDecisionsMap);
          }
          userContext._qualifiedSegments = this._qualifiedSegments;
          return userContext;
      }
      /**
       * Fetches a target user's list of qualified segments filtered by any given segment options and stores in qualifiedSegments.
       * @param {OptimizelySegmentOption[]} options   (Optional) List of segment options used to filter qualified segment results.
       * @returns Boolean representing if segments were populated.
       */
      fetchQualifiedSegments(options) {
          return __awaiter(this, void 0, void 0, function* () {
              const segments = yield this.optimizely.fetchQualifiedSegments(this.userId, options);
              this.qualifiedSegments = segments;
              return segments !== null;
          });
      }
      /**
       * Returns a boolean representing if a user is qualified for a particular segment.
       * @param   {string}  segment   Target segment to be evaluated for user qualification.
       * @returns {boolean}           Boolean representing if a user qualified for the passed in segment.
       */
      isQualifiedFor(segment) {
          if (!this._qualifiedSegments) {
              return false;
          }
          return this._qualifiedSegments.indexOf(segment) > -1;
      }
  }

  var murmurhash = createCommonjsModule(function (module) {
  (function(){

    const createBuffer = (val) => new TextEncoder().encode(val);

    /**
     * JS Implementation of MurmurHash2
     *
     * @author <a href="mailto:gary.court@gmail.com">Gary Court</a>
     * @see http://github.com/garycourt/murmurhash-js
     * @author <a href="mailto:aappleby@gmail.com">Austin Appleby</a>
     * @see http://sites.google.com/site/murmurhash/
     *
     * @param {Uint8Array | string} str ASCII only
     * @param {number} seed Positive integer only
     * @return {number} 32-bit positive integer hash
     */
    function MurmurHashV2(str, seed) {
      if (typeof str === 'string') str = createBuffer(str);
      let
        l = str.length,
        h = seed ^ l,
        i = 0,
        k;

      while (l >= 4) {
        k =
          ((str[i] & 0xff)) |
          ((str[++i] & 0xff) << 8) |
          ((str[++i] & 0xff) << 16) |
          ((str[++i] & 0xff) << 24);

        k = (((k & 0xffff) * 0x5bd1e995) + ((((k >>> 16) * 0x5bd1e995) & 0xffff) << 16));
        k ^= k >>> 24;
        k = (((k & 0xffff) * 0x5bd1e995) + ((((k >>> 16) * 0x5bd1e995) & 0xffff) << 16));

      h = (((h & 0xffff) * 0x5bd1e995) + ((((h >>> 16) * 0x5bd1e995) & 0xffff) << 16)) ^ k;

        l -= 4;
        ++i;
      }

      switch (l) {
      case 3: h ^= (str[i + 2] & 0xff) << 16;
      case 2: h ^= (str[i + 1] & 0xff) << 8;
      case 1: h ^= (str[i] & 0xff);
              h = (((h & 0xffff) * 0x5bd1e995) + ((((h >>> 16) * 0x5bd1e995) & 0xffff) << 16));
      }

      h ^= h >>> 13;
      h = (((h & 0xffff) * 0x5bd1e995) + ((((h >>> 16) * 0x5bd1e995) & 0xffff) << 16));
      h ^= h >>> 15;

      return h >>> 0;
    }
    /*
     * JS Implementation of MurmurHash3 (r136) (as of May 20, 2011)
     *
     * @author <a href="mailto:gary.court@gmail.com">Gary Court</a>
     * @see http://github.com/garycourt/murmurhash-js
     * @author <a href="mailto:aappleby@gmail.com">Austin Appleby</a>
     * @see http://sites.google.com/site/murmurhash/
     *
     * @param {Uint8Array | string} key ASCII only
     * @param {number} seed Positive integer only
     * @return {number} 32-bit positive integer hash
     */
    function MurmurHashV3(key, seed) {
      if (typeof key === 'string') key = createBuffer(key);

      let remainder, bytes, h1, h1b, c1, c2, k1, i;

      remainder = key.length & 3; // key.length % 4
      bytes = key.length - remainder;
      h1 = seed;
      c1 = 0xcc9e2d51;
      c2 = 0x1b873593;
      i = 0;

      while (i < bytes) {
          k1 =
            ((key[i] & 0xff)) |
            ((key[++i] & 0xff) << 8) |
            ((key[++i] & 0xff) << 16) |
            ((key[++i] & 0xff) << 24);
        ++i;

        k1 = ((((k1 & 0xffff) * c1) + ((((k1 >>> 16) * c1) & 0xffff) << 16))) & 0xffffffff;
        k1 = (k1 << 15) | (k1 >>> 17);
        k1 = ((((k1 & 0xffff) * c2) + ((((k1 >>> 16) * c2) & 0xffff) << 16))) & 0xffffffff;

        h1 ^= k1;
            h1 = (h1 << 13) | (h1 >>> 19);
        h1b = ((((h1 & 0xffff) * 5) + ((((h1 >>> 16) * 5) & 0xffff) << 16))) & 0xffffffff;
        h1 = (((h1b & 0xffff) + 0x6b64) + ((((h1b >>> 16) + 0xe654) & 0xffff) << 16));
      }

      k1 = 0;

      switch (remainder) {
        case 3: k1 ^= (key[i + 2] & 0xff) << 16;
        case 2: k1 ^= (key[i + 1] & 0xff) << 8;
        case 1: k1 ^= (key[i] & 0xff);

        k1 = (((k1 & 0xffff) * c1) + ((((k1 >>> 16) * c1) & 0xffff) << 16)) & 0xffffffff;
        k1 = (k1 << 15) | (k1 >>> 17);
        k1 = (((k1 & 0xffff) * c2) + ((((k1 >>> 16) * c2) & 0xffff) << 16)) & 0xffffffff;
        h1 ^= k1;
      }

      h1 ^= key.length;

      h1 ^= h1 >>> 16;
      h1 = (((h1 & 0xffff) * 0x85ebca6b) + ((((h1 >>> 16) * 0x85ebca6b) & 0xffff) << 16)) & 0xffffffff;
      h1 ^= h1 >>> 13;
      h1 = ((((h1 & 0xffff) * 0xc2b2ae35) + ((((h1 >>> 16) * 0xc2b2ae35) & 0xffff) << 16))) & 0xffffffff;
      h1 ^= h1 >>> 16;

      return h1 >>> 0;
    }

    const murmur = MurmurHashV3;
    murmur.v2 = MurmurHashV2;
    murmur.v3 = MurmurHashV3;

    {
      module.exports = murmur;
    }
  }());
  });

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const HASH_SEED = 1;
  const MAX_HASH_VALUE = Math.pow(2, 32);
  const MAX_TRAFFIC_VALUE = 10000;
  /**
   * Helper function to generate bucket value in half-closed interval [0, MAX_TRAFFIC_VALUE)
   * @param  {string}               bucketingKey          String value for bucketing
   * @return {number}               The generated bucket value
   * @throws                        If bucketing value is not a valid string
   */
  const generateBucketValue = function (bucketingKey) {
      try {
          // NOTE: the mmh library already does cast the hash value as an unsigned 32bit int
          // https://github.com/perezd/node-murmurhash/blob/master/murmurhash.js#L115
          const hashValue = murmurhash.v3(bucketingKey, HASH_SEED);
          const ratio = hashValue / MAX_HASH_VALUE;
          return Math.floor(ratio * MAX_TRAFFIC_VALUE);
      }
      catch (ex) {
          throw new OptimizelyError(INVALID_BUCKETING_ID, bucketingKey, ex.message);
      }
  };

  /**
   * Copyright 2016, 2019-2022, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const USER_NOT_IN_ANY_EXPERIMENT = 'User %s is not in any experiment of group %s.';
  const USER_NOT_BUCKETED_INTO_EXPERIMENT_IN_GROUP = 'User %s is not in experiment %s of group %s.';
  const USER_BUCKETED_INTO_EXPERIMENT_IN_GROUP = 'User %s is in experiment %s of group %s.';
  const USER_ASSIGNED_TO_EXPERIMENT_BUCKET = 'Assigned bucket %s to user with bucketing ID %s.';
  const INVALID_VARIATION_ID = 'Bucketed into an invalid variation ID. Returning null.';
  const RANDOM_POLICY = 'random';
  /**
   * Determines ID of variation to be shown for the given input params
   * @param  {Object}             bucketerParams
   * @param  {string}             bucketerParams.experimentId
   * @param  {string}             bucketerParams.experimentKey
   * @param  {string}             bucketerParams.userId
   * @param  {Object[]}           bucketerParams.trafficAllocationConfig
   * @param  {Array}              bucketerParams.experimentKeyMap
   * @param  {Object}             bucketerParams.groupIdMap
   * @param  {Object}             bucketerParams.variationIdMap
   * @param  {string}             bucketerParams.varationIdMap[].key
   * @param  {Object}             bucketerParams.logger
   * @param  {string}             bucketerParams.bucketingId
   * @return {Object}             DecisionResponse                         DecisionResponse containing variation ID that user has been bucketed into,
   *                                                                       null if user is not bucketed into any experiment and the decide reasons.
   */
  const bucket = function (bucketerParams) {
      var _a, _b, _c, _d, _e;
      const decideReasons = [];
      // Check if user is in a random group; if so, check if user is bucketed into a specific experiment
      const experiment = bucketerParams.experimentIdMap[bucketerParams.experimentId];
      const groupId = experiment['groupId'];
      if (groupId) {
          const group = bucketerParams.groupIdMap[groupId];
          if (!group) {
              throw new OptimizelyError(INVALID_GROUP_ID, groupId);
          }
          if (group.policy === RANDOM_POLICY) {
              const bucketedExperimentId = bucketUserIntoExperiment(group, bucketerParams.bucketingId, bucketerParams.userId, bucketerParams.logger);
              // Return if user is not bucketed into any experiment
              if (bucketedExperimentId === null) {
                  (_a = bucketerParams.logger) === null || _a === void 0 ? void 0 : _a.info(USER_NOT_IN_ANY_EXPERIMENT, bucketerParams.userId, groupId);
                  decideReasons.push([
                      USER_NOT_IN_ANY_EXPERIMENT,
                      bucketerParams.userId,
                      groupId,
                  ]);
                  return {
                      result: null,
                      reasons: decideReasons,
                  };
              }
              // Return if user is bucketed into a different experiment than the one specified
              if (bucketedExperimentId !== bucketerParams.experimentId) {
                  (_b = bucketerParams.logger) === null || _b === void 0 ? void 0 : _b.info(USER_NOT_BUCKETED_INTO_EXPERIMENT_IN_GROUP, bucketerParams.userId, bucketerParams.experimentKey, groupId);
                  decideReasons.push([
                      USER_NOT_BUCKETED_INTO_EXPERIMENT_IN_GROUP,
                      bucketerParams.userId,
                      bucketerParams.experimentKey,
                      groupId,
                  ]);
                  return {
                      result: null,
                      reasons: decideReasons,
                  };
              }
              // Continue bucketing if user is bucketed into specified experiment      
              (_c = bucketerParams.logger) === null || _c === void 0 ? void 0 : _c.info(USER_BUCKETED_INTO_EXPERIMENT_IN_GROUP, bucketerParams.userId, bucketerParams.experimentKey, groupId);
              decideReasons.push([
                  USER_BUCKETED_INTO_EXPERIMENT_IN_GROUP,
                  bucketerParams.userId,
                  bucketerParams.experimentKey,
                  groupId,
              ]);
          }
      }
      const bucketingId = `${bucketerParams.bucketingId}${bucketerParams.experimentId}`;
      const bucketValue = generateBucketValue(bucketingId);
      (_d = bucketerParams.logger) === null || _d === void 0 ? void 0 : _d.debug(USER_ASSIGNED_TO_EXPERIMENT_BUCKET, bucketValue, bucketerParams.userId);
      decideReasons.push([
          USER_ASSIGNED_TO_EXPERIMENT_BUCKET,
          bucketValue,
          bucketerParams.userId,
      ]);
      const entityId = _findBucket(bucketValue, bucketerParams.trafficAllocationConfig);
      if (entityId !== null) {
          if (!bucketerParams.variationIdMap[entityId]) {
              if (entityId) {
                  (_e = bucketerParams.logger) === null || _e === void 0 ? void 0 : _e.warn(INVALID_VARIATION_ID);
                  decideReasons.push([INVALID_VARIATION_ID]);
              }
              return {
                  result: null,
                  reasons: decideReasons,
              };
          }
      }
      return {
          result: entityId,
          reasons: decideReasons,
      };
  };
  /**
   * Returns bucketed experiment ID to compare against experiment user is being called into
   * @param  {Group}       group        Group that experiment is in
   * @param  {string}      bucketingId  Bucketing ID
   * @param  {string}      userId       ID of user to be bucketed into experiment
   * @param  {LoggerFacade}  logger       Logger implementation
   * @return {string|null}              ID of experiment if user is bucketed into experiment within the group, null otherwise
   */
  const bucketUserIntoExperiment = function (group, bucketingId, userId, logger) {
      const bucketingKey = `${bucketingId}${group.id}`;
      const bucketValue = generateBucketValue(bucketingKey);
      logger === null || logger === void 0 ? void 0 : logger.debug(USER_ASSIGNED_TO_EXPERIMENT_BUCKET, bucketValue, userId);
      const trafficAllocationConfig = group.trafficAllocation;
      const bucketedExperimentId = _findBucket(bucketValue, trafficAllocationConfig);
      return bucketedExperimentId;
  };
  /**
   * Returns entity ID associated with bucket value
   * @param  {number}                bucketValue
   * @param  {TrafficAllocation[]}   trafficAllocationConfig
   * @param  {number}                trafficAllocationConfig[].endOfRange
   * @param  {string}                trafficAllocationConfig[].entityId
   * @return {string|null}           Entity ID for bucketing if bucket value is within traffic allocation boundaries, null otherwise
   */
  const _findBucket = function (bucketValue, trafficAllocationConfig) {
      for (let i = 0; i < trafficAllocationConfig.length; i++) {
          if (bucketValue < trafficAllocationConfig[i].endOfRange) {
              return trafficAllocationConfig[i].entityId;
          }
      }
      return null;
  };

  /**
   * Copyright 2020, 2022, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Evaluate if provided string is number only
   * @param  {unknown}  content
   * @return {boolean}  true if the string is number only
   *
   */
  function isNumber(content) {
      return /^\d+$/.test(content);
  }
  /**
   * Evaluate if provided version contains pre-release "-"
   * @param  {unknown}  version
   * @return {boolean}  true if the version contains "-" and meets condition
   *
   */
  function isPreReleaseVersion(version) {
      const preReleaseIndex = version.indexOf("-" /* VERSION_TYPE.PRE_RELEASE_VERSION_DELIMITER */);
      const buildIndex = version.indexOf("+" /* VERSION_TYPE.BUILD_VERSION_DELIMITER */);
      if (preReleaseIndex < 0) {
          return false;
      }
      if (buildIndex < 0) {
          return true;
      }
      return preReleaseIndex < buildIndex;
  }
  /**
   * Evaluate if provided version contains build "+"
   * @param  {unknown}  version
   * @return {boolean}  true if the version contains "+" and meets condition
   *
   */
  function isBuildVersion(version) {
      const preReleaseIndex = version.indexOf("-" /* VERSION_TYPE.PRE_RELEASE_VERSION_DELIMITER */);
      const buildIndex = version.indexOf("+" /* VERSION_TYPE.BUILD_VERSION_DELIMITER */);
      if (buildIndex < 0) {
          return false;
      }
      if (preReleaseIndex < 0) {
          return true;
      }
      return buildIndex < preReleaseIndex;
  }
  /**
   * check if there is any white spaces " " in version
   * @param  {unknown}  version
   * @return {boolean}  true if the version contains " "
   *
   */
  function hasWhiteSpaces(version) {
      return /\s/.test(version);
  }
  /**
   * split version in parts
   * @param  {unknown}  version
   * @return {boolean}  The array of version split into smaller parts i.e major, minor, patch etc
   *                    null if given version is in invalid format
   */
  function splitVersion(version, logger) {
      let targetPrefix = version;
      let targetSuffix = '';
      // check that version shouldn't have white space
      if (hasWhiteSpaces(version)) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNKNOWN_MATCH_TYPE, version);
          return null;
      }
      //check for pre release e.g. 1.0.0-alpha where 'alpha' is a pre release
      //otherwise check for build e.g. 1.0.0+001 where 001 is a build metadata
      if (isPreReleaseVersion(version)) {
          targetPrefix = version.substring(0, version.indexOf("-" /* VERSION_TYPE.PRE_RELEASE_VERSION_DELIMITER */));
          targetSuffix = version.substring(version.indexOf("-" /* VERSION_TYPE.PRE_RELEASE_VERSION_DELIMITER */) + 1);
      }
      else if (isBuildVersion(version)) {
          targetPrefix = version.substring(0, version.indexOf("+" /* VERSION_TYPE.BUILD_VERSION_DELIMITER */));
          targetSuffix = version.substring(version.indexOf("+" /* VERSION_TYPE.BUILD_VERSION_DELIMITER */) + 1);
      }
      // check dot counts in target_prefix
      if (typeof targetPrefix !== 'string' || typeof targetSuffix !== 'string') {
          return null;
      }
      const dotCount = targetPrefix.split('.').length - 1;
      if (dotCount > 2) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNKNOWN_MATCH_TYPE, version);
          return null;
      }
      const targetVersionParts = targetPrefix.split('.');
      if (targetVersionParts.length != dotCount + 1) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNKNOWN_MATCH_TYPE, version);
          return null;
      }
      for (const part of targetVersionParts) {
          if (!isNumber(part)) {
              logger === null || logger === void 0 ? void 0 : logger.warn(UNKNOWN_MATCH_TYPE, version);
              return null;
          }
      }
      if (targetSuffix) {
          targetVersionParts.push(targetSuffix);
      }
      return targetVersionParts;
  }
  /**
   * Compare user version with condition version
   * @param  {string}  conditionsVersion
   * @param  {string}  userProvidedVersion
   * @return {number | null}  0 if user version is equal to condition version
   *                          1 if user version is greater than condition version
   *                         -1 if user version is less than condition version
   *                          null if invalid user or condition version is provided
   */
  function compareVersion(conditionsVersion, userProvidedVersion, logger) {
      const userVersionParts = splitVersion(userProvidedVersion, logger);
      const conditionsVersionParts = splitVersion(conditionsVersion, logger);
      if (!userVersionParts || !conditionsVersionParts) {
          return null;
      }
      const userVersionPartsLen = userVersionParts.length;
      for (let idx = 0; idx < conditionsVersionParts.length; idx++) {
          if (userVersionPartsLen <= idx) {
              return isPreReleaseVersion(conditionsVersion) || isBuildVersion(conditionsVersion) ? 1 : -1;
          }
          else if (!isNumber(userVersionParts[idx])) {
              if (userVersionParts[idx] < conditionsVersionParts[idx]) {
                  return isPreReleaseVersion(conditionsVersion) && !isPreReleaseVersion(userProvidedVersion) ? 1 : -1;
              }
              else if (userVersionParts[idx] > conditionsVersionParts[idx]) {
                  return !isPreReleaseVersion(conditionsVersion) && isPreReleaseVersion(userProvidedVersion) ? -1 : 1;
              }
          }
          else {
              const userVersionPart = parseInt(userVersionParts[idx]);
              const conditionsVersionPart = parseInt(conditionsVersionParts[idx]);
              if (userVersionPart > conditionsVersionPart) {
                  return 1;
              }
              else if (userVersionPart < conditionsVersionPart) {
                  return -1;
              }
          }
      }
      // check if user version contains release and target version does not
      if (isPreReleaseVersion(userProvidedVersion) && !isPreReleaseVersion(conditionsVersion)) {
          return -1;
      }
      return 0;
  }

  const EXACT_MATCH_TYPE = 'exact';
  const EXISTS_MATCH_TYPE = 'exists';
  const GREATER_OR_EQUAL_THAN_MATCH_TYPE = 'ge';
  const GREATER_THAN_MATCH_TYPE = 'gt';
  const LESS_OR_EQUAL_THAN_MATCH_TYPE = 'le';
  const LESS_THAN_MATCH_TYPE = 'lt';
  const SEMVER_EXACT_MATCH_TYPE = 'semver_eq';
  const SEMVER_GREATER_OR_EQUAL_THAN_MATCH_TYPE = 'semver_ge';
  const SEMVER_GREATER_THAN_MATCH_TYPE = 'semver_gt';
  const SEMVER_LESS_OR_EQUAL_THAN_MATCH_TYPE = 'semver_le';
  const SEMVER_LESS_THAN_MATCH_TYPE = 'semver_lt';
  const SUBSTRING_MATCH_TYPE = 'substring';
  const MATCH_TYPES$1 = [
      EXACT_MATCH_TYPE,
      EXISTS_MATCH_TYPE,
      GREATER_THAN_MATCH_TYPE,
      GREATER_OR_EQUAL_THAN_MATCH_TYPE,
      LESS_THAN_MATCH_TYPE,
      LESS_OR_EQUAL_THAN_MATCH_TYPE,
      SUBSTRING_MATCH_TYPE,
      SEMVER_EXACT_MATCH_TYPE,
      SEMVER_LESS_THAN_MATCH_TYPE,
      SEMVER_LESS_OR_EQUAL_THAN_MATCH_TYPE,
      SEMVER_GREATER_THAN_MATCH_TYPE,
      SEMVER_GREATER_OR_EQUAL_THAN_MATCH_TYPE
  ];
  const EVALUATORS_BY_MATCH_TYPE$1 = {};
  EVALUATORS_BY_MATCH_TYPE$1[EXACT_MATCH_TYPE] = exactEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[EXISTS_MATCH_TYPE] = existsEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[GREATER_THAN_MATCH_TYPE] = greaterThanEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[GREATER_OR_EQUAL_THAN_MATCH_TYPE] = greaterThanOrEqualEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[LESS_THAN_MATCH_TYPE] = lessThanEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[LESS_OR_EQUAL_THAN_MATCH_TYPE] = lessThanOrEqualEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[SUBSTRING_MATCH_TYPE] = substringEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[SEMVER_EXACT_MATCH_TYPE] = semverEqualEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[SEMVER_GREATER_THAN_MATCH_TYPE] = semverGreaterThanEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[SEMVER_GREATER_OR_EQUAL_THAN_MATCH_TYPE] = semverGreaterThanOrEqualEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[SEMVER_LESS_THAN_MATCH_TYPE] = semverLessThanEvaluator;
  EVALUATORS_BY_MATCH_TYPE$1[SEMVER_LESS_OR_EQUAL_THAN_MATCH_TYPE] = semverLessThanOrEqualEvaluator;
  const getEvaluator$1 = (logger) => {
      return {
          evaluate(condition, user) {
              return evaluate$1(condition, user, logger);
          }
      };
  };
  /**
   * Given a custom attribute audience condition and user attributes, evaluate the
   * condition against the attributes.
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @return {?boolean}               true/false if the given user attributes match/don't match the given condition,
   *                                  null if the given user attributes and condition can't be evaluated
   * TODO: Change to accept and object with named properties
   */
  function evaluate$1(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const conditionMatch = condition.match;
      if (typeof conditionMatch !== 'undefined' && MATCH_TYPES$1.indexOf(conditionMatch) === -1) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNKNOWN_MATCH_TYPE, JSON.stringify(condition));
          return null;
      }
      const attributeKey = condition.name;
      if (!userAttributes.hasOwnProperty(attributeKey) && conditionMatch != EXISTS_MATCH_TYPE) {
          logger === null || logger === void 0 ? void 0 : logger.debug(MISSING_ATTRIBUTE_VALUE, JSON.stringify(condition), attributeKey);
          return null;
      }
      let evaluatorForMatch;
      if (!conditionMatch) {
          evaluatorForMatch = exactEvaluator;
      }
      else {
          evaluatorForMatch = EVALUATORS_BY_MATCH_TYPE$1[conditionMatch] || exactEvaluator;
      }
      return evaluatorForMatch(condition, user, logger);
  }
  /**
   * Returns true if the value is valid for exact conditions. Valid values include
   * strings, booleans, and numbers that aren't NaN, -Infinity, or Infinity.
   * @param value
   * @returns {boolean}
   */
  function isValueTypeValidForExactConditions(value) {
      return typeof value === 'string' || typeof value === 'boolean' || fns.isNumber(value);
  }
  /**
   * Evaluate the given exact match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @return  {?boolean}              true if the user attribute value is equal (===) to the condition value,
   *                                  false if the user attribute value is not equal (!==) to the condition value,
   *                                  null if the condition value or user attribute value has an invalid type, or
   *                                  if there is a mismatch between the user attribute type and the condition value
   *                                  type
   */
  function exactEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const conditionValue = condition.value;
      const conditionValueType = typeof conditionValue;
      const conditionName = condition.name;
      const userValue = userAttributes[conditionName];
      const userValueType = typeof userValue;
      if (!isValueTypeValidForExactConditions(conditionValue) ||
          (fns.isNumber(conditionValue) && !fns.isSafeInteger(conditionValue))) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_CONDITION_VALUE, JSON.stringify(condition));
          return null;
      }
      if (userValue === null) {
          logger === null || logger === void 0 ? void 0 : logger.debug(UNEXPECTED_TYPE_NULL, JSON.stringify(condition), conditionName);
          return null;
      }
      if (!isValueTypeValidForExactConditions(userValue) || conditionValueType !== userValueType) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_TYPE, JSON.stringify(condition), userValueType, conditionName);
          return null;
      }
      if (fns.isNumber(userValue) && !fns.isSafeInteger(userValue)) {
          logger === null || logger === void 0 ? void 0 : logger.warn(OUT_OF_BOUNDS, JSON.stringify(condition), conditionName);
          return null;
      }
      return conditionValue === userValue;
  }
  /**
   * Evaluate the given exists match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {boolean}               true if both:
   *                                    1) the user attributes have a value for the given condition, and
   *                                    2) the user attribute value is neither null nor undefined
   *                                  Returns false otherwise
   */
  function existsEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const userValue = userAttributes[condition.name];
      return typeof userValue !== 'undefined' && userValue !== null;
  }
  /**
   * Validate user and condition values
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?boolean}              true if values are valid,
   *                                  false if values are not valid
   */
  function validateValuesForNumericCondition(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const conditionName = condition.name;
      const userValue = userAttributes[conditionName];
      const userValueType = typeof userValue;
      const conditionValue = condition.value;
      if (conditionValue === null || !fns.isSafeInteger(conditionValue)) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_CONDITION_VALUE, JSON.stringify(condition));
          return false;
      }
      if (userValue === null) {
          logger === null || logger === void 0 ? void 0 : logger.debug(UNEXPECTED_TYPE_NULL, JSON.stringify(condition), conditionName);
          return false;
      }
      if (!fns.isNumber(userValue)) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_TYPE, JSON.stringify(condition), userValueType, conditionName);
          return false;
      }
      if (!fns.isSafeInteger(userValue)) {
          logger === null || logger === void 0 ? void 0 : logger.warn(OUT_OF_BOUNDS, JSON.stringify(condition), conditionName);
          return false;
      }
      return true;
  }
  /**
   * Evaluate the given greater than match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?boolean}              true if the user attribute value is greater than the condition value,
   *                                  false if the user attribute value is less than or equal to the condition value,
   *                                  null if the condition value isn't a number or the user attribute value
   *                                  isn't a number
   */
  function greaterThanEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const userValue = userAttributes[condition.name];
      const conditionValue = condition.value;
      if (!validateValuesForNumericCondition(condition, user, logger) || conditionValue === null) {
          return null;
      }
      return userValue > conditionValue;
  }
  /**
   * Evaluate the given greater or equal than match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute value is greater or equal than the condition value,
   *                                  false if the user attribute value is less than to the condition value,
   *                                  null if the condition value isn't a number or the user attribute value isn't a
   *                                  number
   */
  function greaterThanOrEqualEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const userValue = userAttributes[condition.name];
      const conditionValue = condition.value;
      if (!validateValuesForNumericCondition(condition, user, logger) || conditionValue === null) {
          return null;
      }
      return userValue >= conditionValue;
  }
  /**
   * Evaluate the given less than match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?boolean}              true if the user attribute value is less than the condition value,
   *                                  false if the user attribute value is greater than or equal to the condition value,
   *                                  null if the condition value isn't a number or the user attribute value isn't a
   *                                  number
   */
  function lessThanEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const userValue = userAttributes[condition.name];
      const conditionValue = condition.value;
      if (!validateValuesForNumericCondition(condition, user, logger) || conditionValue === null) {
          return null;
      }
      return userValue < conditionValue;
  }
  /**
   * Evaluate the given less or equal than match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute value is less or equal than the condition value,
   *                                  false if the user attribute value is greater than to the condition value,
   *                                  null if the condition value isn't a number or the user attribute value isn't a
   *                                  number
   */
  function lessThanOrEqualEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const userValue = userAttributes[condition.name];
      const conditionValue = condition.value;
      if (!validateValuesForNumericCondition(condition, user, logger) || conditionValue === null) {
          return null;
      }
      return userValue <= conditionValue;
  }
  /**
   * Evaluate the given substring match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the condition value is a substring of the user attribute value,
   *                                  false if the condition value is not a substring of the user attribute value,
   *                                  null if the condition value isn't a string or the user attribute value
   *                                  isn't a string
   */
  function substringEvaluator(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const conditionName = condition.name;
      const userValue = userAttributes[condition.name];
      const userValueType = typeof userValue;
      const conditionValue = condition.value;
      if (typeof conditionValue !== 'string') {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_CONDITION_VALUE, JSON.stringify(condition));
          return null;
      }
      if (userValue === null) {
          logger === null || logger === void 0 ? void 0 : logger.debug(UNEXPECTED_TYPE_NULL, JSON.stringify(condition), conditionName);
          return null;
      }
      if (typeof userValue !== 'string') {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_TYPE, JSON.stringify(condition), userValueType, conditionName);
          return null;
      }
      return userValue.indexOf(conditionValue) !== -1;
  }
  /**
   * Evaluate the given semantic version match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?number}               returns compareVersion result
   *                                  null if the user attribute version has an invalid type
   */
  function evaluateSemanticVersion(condition, user, logger) {
      const userAttributes = user.getAttributes();
      const conditionName = condition.name;
      const userValue = userAttributes[conditionName];
      const userValueType = typeof userValue;
      const conditionValue = condition.value;
      if (typeof conditionValue !== 'string') {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_CONDITION_VALUE, JSON.stringify(condition));
          return null;
      }
      if (userValue === null) {
          logger === null || logger === void 0 ? void 0 : logger.debug(UNEXPECTED_TYPE_NULL, JSON.stringify(condition), conditionName);
          return null;
      }
      if (typeof userValue !== 'string') {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNEXPECTED_TYPE, JSON.stringify(condition), userValueType, conditionName);
          return null;
      }
      return compareVersion(conditionValue, userValue, logger);
  }
  /**
   * Evaluate the given version match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute version is equal (===) to the condition version,
   *                                  false if the user attribute version is not equal (!==) to the condition version,
   *                                  null if the user attribute version has an invalid type
   */
  function semverEqualEvaluator(condition, user, logger) {
      const result = evaluateSemanticVersion(condition, user, logger);
      if (result === null) {
          return null;
      }
      return result === 0;
  }
  /**
   * Evaluate the given version match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute version is greater (>) than the condition version,
   *                                  false if the user attribute version is not greater than the condition version,
   *                                  null if the user attribute version has an invalid type
   */
  function semverGreaterThanEvaluator(condition, user, logger) {
      const result = evaluateSemanticVersion(condition, user, logger);
      if (result === null) {
          return null;
      }
      return result > 0;
  }
  /**
   * Evaluate the given version match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute version is less (<) than the condition version,
   *                                  false if the user attribute version is not less than the condition version,
   *                                  null if the user attribute version has an invalid type
   */
  function semverLessThanEvaluator(condition, user, logger) {
      const result = evaluateSemanticVersion(condition, user, logger);
      if (result === null) {
          return null;
      }
      return result < 0;
  }
  /**
   * Evaluate the given version match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute version is greater than or equal (>=) to the condition version,
   *                                  false if the user attribute version is not greater than or equal to the condition version,
   *                                  null if the user attribute version has an invalid type
   */
  function semverGreaterThanOrEqualEvaluator(condition, user, logger) {
      const result = evaluateSemanticVersion(condition, user, logger);
      if (result === null) {
          return null;
      }
      return result >= 0;
  }
  /**
   * Evaluate the given version match condition for the given user attributes
   * @param  {Condition}              condition
   * @param  {OptimizelyUserContext}  user
   * @returns {?Boolean}              true if the user attribute version is less than or equal (<=) to the condition version,
   *                                  false if the user attribute version is not less than or equal to the condition version,
   *                                  null if the user attribute version has an invalid type
   */
  function semverLessThanOrEqualEvaluator(condition, user, logger) {
      const result = evaluateSemanticVersion(condition, user, logger);
      if (result === null) {
          return null;
      }
      return result <= 0;
  }

  /****************************************************************************
   * Copyright 2022 Optimizely, Inc. and contributors              *
   *                                                                          *
   * Licensed under the Apache License, Version 2.0 (the "License");          *
   * you may not use this file except in compliance with the License.         *
   * You may obtain a copy of the License at                                  *
   *                                                                          *
   *    http://www.apache.org/licenses/LICENSE-2.0                            *
   *                                                                          *
   * Unless required by applicable law or agreed to in writing, software      *
   * distributed under the License is distributed on an "AS IS" BASIS,        *
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
   * See the License for the specific language governing permissions and      *
   * limitations under the License.                                           *
   ***************************************************************************/
  const QUALIFIED_MATCH_TYPE = 'qualified';
  const MATCH_TYPES = [
      QUALIFIED_MATCH_TYPE,
  ];
  const EVALUATORS_BY_MATCH_TYPE = {};
  EVALUATORS_BY_MATCH_TYPE[QUALIFIED_MATCH_TYPE] = qualifiedEvaluator;
  const getEvaluator = (logger) => {
      return {
          evaluate(condition, user) {
              return evaluate(condition, user, logger);
          }
      };
  };
  /**
   * Given a custom attribute audience condition and user attributes, evaluate the
   * condition against the attributes.
   * @param  {Condition}        condition
   * @param  {OptimizelyUserContext} user
   * @return {?boolean}         true/false if the given user attributes match/don't match the given condition,
   *                            null if the given user attributes and condition can't be evaluated
   * TODO: Change to accept and object with named properties
   */
  function evaluate(condition, user, logger) {
      const conditionMatch = condition.match;
      if (typeof conditionMatch !== 'undefined' && MATCH_TYPES.indexOf(conditionMatch) === -1) {
          logger === null || logger === void 0 ? void 0 : logger.warn(UNKNOWN_MATCH_TYPE, JSON.stringify(condition));
          return null;
      }
      let evaluator;
      if (!conditionMatch) {
          evaluator = qualifiedEvaluator;
      }
      else {
          evaluator = EVALUATORS_BY_MATCH_TYPE[conditionMatch] || qualifiedEvaluator;
      }
      return evaluator(condition, user);
  }
  function qualifiedEvaluator(condition, user) {
      return user.isQualifiedFor(condition.value);
  }

  /**
   * Copyright 2016, 2018-2022, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class AudienceEvaluator {
      /**
       * Construct an instance of AudienceEvaluator with given options
       * @param {Object=} UNSTABLE_conditionEvaluators     A map of condition evaluators provided by the consumer. This enables matching
       *                                                   condition types which are not supported natively by the SDK. Note that built in
       *                                                   Optimizely evaluators cannot be overridden.
       * @constructor
       */
      constructor(UNSTABLE_conditionEvaluators, logger) {
          this.logger = logger;
          this.typeToEvaluatorMap = Object.assign(Object.assign({}, UNSTABLE_conditionEvaluators), { custom_attribute: getEvaluator$1(this.logger), third_party_dimension: getEvaluator(this.logger) });
      }
      /**
       * Determine if the given user attributes satisfy the given audience conditions
       * @param  {Array<string|string[]}        audienceConditions    Audience conditions to match the user attributes against - can be an array
       *                                                              of audience IDs, a nested array of conditions, or a single leaf condition.
       *                                                              Examples: ["5", "6"], ["and", ["or", "1", "2"], "3"], "1"
       * @param  {[id: string]: Audience}       audiencesById         Object providing access to full audience objects for audience IDs
       *                                                              contained in audienceConditions. Keys should be audience IDs, values
       *                                                              should be full audience objects with conditions properties
       * @param  {OptimizelyUserContext}        userAttributes        User context which contains the attributes and segments which will be used in
       *                                                              determining if audience conditions are met.
       * @return {boolean}                                            true if the user attributes match the given audience conditions, false
       *                                                              otherwise
       */
      evaluate(audienceConditions, audiencesById, user) {
          // if there are no audiences, return true because that means ALL users are included in the experiment
          if (!audienceConditions || audienceConditions.length === 0) {
              return true;
          }
          const evaluateAudience = (audienceId) => {
              var _a, _b;
              const audience = audiencesById[audienceId];
              if (audience) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(EVALUATING_AUDIENCE, audienceId, JSON.stringify(audience.conditions));
                  const result = evaluate$2(audience.conditions, this.evaluateConditionWithUserAttributes.bind(this, user));
                  const resultText = result === null ? 'UNKNOWN' : result.toString().toUpperCase();
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.debug(AUDIENCE_EVALUATION_RESULT, audienceId, resultText);
                  return result;
              }
              return null;
          };
          return !!evaluate$2(audienceConditions, evaluateAudience);
      }
      /**
       * Wrapper around evaluator.evaluate that is passed to the conditionTreeEvaluator.
       * Evaluates the condition provided given the user attributes if an evaluator has been defined for the condition type.
       * @param  {OptimizelyUserContext}  user             Optimizely user context containing attributes and segments
       * @param  {Condition}              condition        A single condition object to evaluate.
       * @return {boolean|null}                            true if the condition is satisfied, null if a matcher is not found.
       */
      evaluateConditionWithUserAttributes(user, condition) {
          var _a, _b;
          const evaluator = this.typeToEvaluatorMap[condition.type];
          if (!evaluator) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(UNKNOWN_CONDITION_TYPE, JSON.stringify(condition));
              return null;
          }
          try {
              return evaluator.evaluate(condition, user);
          }
          catch (err) {
              (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(CONDITION_EVALUATOR_ERROR, condition.type, err.message);
          }
          return null;
      }
  }
  const createAudienceEvaluator = function (UNSTABLE_conditionEvaluators, logger) {
      return new AudienceEvaluator(UNSTABLE_conditionEvaluators, logger);
  };

  /**
   * Copyright 2018, 2020, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Validates provided value is a non-empty string
   * @param  {unknown}  input
   * @return {boolean}  true for non-empty string, false otherwise
   */
  function validate$2(input) {
      return typeof input === 'string' && input !== '';
  }

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const CMAB_FETCH_FAILED$1 = 'CMAB decision fetch failed with status: %s';
  const INVALID_CMAB_FETCH_RESPONSE = 'Invalid CMAB fetch response';
  const PROMISE_NOT_ALLOWED = "Promise value is not allowed in sync operation";

  const isPromise = (val) => {
      return val && typeof val.then === 'function';
  };
  /**
   * A class that wraps a value that can be either a synchronous value or a promise and provides
   * a promise like interface. This class is used to handle both synchronous and asynchronous values
   * in a uniform way.
   */
  class Value {
      constructor(op, val) {
          this.op = op;
          this.val = val;
      }
      get() {
          return this.val;
      }
      then(fn) {
          if (this.op === 'sync') {
              const newVal = fn(this.val);
              return Value.of(this.op, newVal.get());
          }
          return Value.of(this.op, this.val.then(fn));
      }
      static of(op, val) {
          if (op === 'sync') {
              if (isPromise(val)) {
                  throw new OptimizelyError(PROMISE_NOT_ALLOWED);
              }
              return new Value(op, val);
          }
          return new Value(op, Promise.resolve(val));
      }
  }
  Value.all = (op, vals) => {
      if (op === 'sync') {
          const values = vals.map(v => v.get());
          return Value.of(op, values);
      }
      const promises = vals.map(v => v.get());
      return Value.of(op, Promise.all(promises));
  };

  const EXPERIMENT_NOT_RUNNING = 'Experiment %s is not running.';
  const RETURNING_STORED_VARIATION = 'Returning previously activated variation "%s" of experiment "%s" for user "%s" from user profile.';
  const USER_NOT_IN_EXPERIMENT = 'User %s does not meet conditions to be in experiment %s.';
  const USER_HAS_NO_VARIATION = 'User %s is in no variation of experiment %s.';
  const USER_HAS_VARIATION = 'User %s is in variation %s of experiment %s.';
  const USER_FORCED_IN_VARIATION = 'User %s is forced in variation %s.';
  const FORCED_BUCKETING_FAILED = 'Variation key %s is not in datafile. Not activating user %s.';
  const EVALUATING_AUDIENCES_COMBINED = 'Evaluating audiences for %s "%s": %s.';
  const AUDIENCE_EVALUATION_RESULT_COMBINED = 'Audiences for %s %s collectively evaluated to %s.';
  const USER_IN_ROLLOUT = 'User %s is in rollout of feature %s.';
  const USER_NOT_IN_ROLLOUT = 'User %s is not in rollout of feature %s.';
  const FEATURE_HAS_NO_EXPERIMENTS = 'Feature %s is not attached to any experiments.';
  const USER_DOESNT_MEET_CONDITIONS_FOR_TARGETING_RULE = 'User %s does not meet conditions for targeting rule %s.';
  const USER_NOT_BUCKETED_INTO_TARGETING_RULE = 'User %s not bucketed into targeting rule %s due to traffic allocation. Trying everyone rule.';
  const USER_BUCKETED_INTO_TARGETING_RULE = 'User %s bucketed into targeting rule %s.';
  const NO_ROLLOUT_EXISTS = 'There is no rollout of feature %s.';
  const INVALID_ROLLOUT_ID = 'Invalid rollout ID %s attached to feature %s';
  const ROLLOUT_HAS_NO_EXPERIMENTS = 'Rollout of feature %s has no experiments';
  const IMPROPERLY_FORMATTED_EXPERIMENT = 'Experiment key %s is improperly formatted.';
  const USER_HAS_FORCED_VARIATION = 'Variation %s is mapped to experiment %s and user %s in the forced variation map.';
  const USER_MEETS_CONDITIONS_FOR_TARGETING_RULE = 'User %s meets conditions for targeting rule %s.';
  const USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED = 'Variation (%s) is mapped to flag (%s), rule (%s) and user (%s) in the forced decision map.';
  const USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED = 'Variation (%s) is mapped to flag (%s) and user (%s) in the forced decision map.';
  const USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED_BUT_INVALID = 'Invalid variation is mapped to flag (%s), rule (%s) and user (%s) in the forced decision map.';
  const USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED_BUT_INVALID = 'Invalid variation is mapped to flag (%s) and user (%s) in the forced decision map.';
  const CMAB_NOT_SUPPORTED_IN_SYNC = 'CMAB is not supported in sync mode.';
  const CMAB_FETCH_FAILED = 'Failed to fetch CMAB data for experiment %s.';
  const CMAB_DUMMY_ENTITY_ID = '$';
  /**
   * Optimizely's decision service that determines which variation of an experiment the user will be allocated to.
   *
   * The decision service contains all logic around how a user decision is made. This includes all of the following (in order):
   *   1. Checking experiment status
   *   2. Checking forced bucketing
   *   3. Checking whitelisting
   *   4. Checking user profile service for past bucketing decisions (sticky bucketing)
   *   5. Checking audience targeting
   *   6. Using Murmurhash3 to bucket the user.
   *
   * @constructor
   * @param   {DecisionServiceOptions}      options
   * @returns {DecisionService}
   */
  class DecisionService {
      constructor(options) {
          this.logger = options.logger;
          this.audienceEvaluator = createAudienceEvaluator(options.UNSTABLE_conditionEvaluators, this.logger);
          this.forcedVariationMap = {};
          this.userProfileService = options.userProfileService;
          this.userProfileServiceAsync = options.userProfileServiceAsync;
          this.cmabService = options.cmabService;
      }
      isCmab(experiment) {
          return !!experiment.cmab;
      }
      /**
       * Resolves the variation into which the visitor will be bucketed.
       *
       * @param {ProjectConfig} configObj - The parsed project configuration object.
       * @param {Experiment} experiment - The experiment for which the variation is being resolved.
       * @param {OptimizelyUserContext} user - The user context associated with this decision.
       * @returns {DecisionResponse<string|null>} - A DecisionResponse containing the variation the user is bucketed into,
       *                                            along with the decision reasons.
       */
      resolveVariation(op, configObj, experiment, user, decideOptions, userProfileTracker) {
          var _a, _b, _c;
          const userId = user.getUserId();
          const experimentKey = experiment.key;
          if (!isActive(configObj, experimentKey)) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(EXPERIMENT_NOT_RUNNING, experimentKey);
              return Value.of(op, {
                  result: {},
                  reasons: [[EXPERIMENT_NOT_RUNNING, experimentKey]],
              });
          }
          const decideReasons = [];
          const decisionForcedVariation = this.getForcedVariation(configObj, experimentKey, userId);
          decideReasons.push(...decisionForcedVariation.reasons);
          const forcedVariationKey = decisionForcedVariation.result;
          if (forcedVariationKey) {
              return Value.of(op, {
                  result: { variationKey: forcedVariationKey },
                  reasons: decideReasons,
              });
          }
          const decisionWhitelistedVariation = this.getWhitelistedVariation(experiment, userId);
          decideReasons.push(...decisionWhitelistedVariation.reasons);
          let variation = decisionWhitelistedVariation.result;
          if (variation) {
              return Value.of(op, {
                  result: { variationKey: variation.key },
                  reasons: decideReasons,
              });
          }
          // check for sticky bucketing
          if (userProfileTracker) {
              variation = this.getStoredVariation(configObj, experiment, userId, userProfileTracker.userProfile);
              if (variation) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(RETURNING_STORED_VARIATION, variation.key, experimentKey, userId);
                  decideReasons.push([
                      RETURNING_STORED_VARIATION,
                      variation.key,
                      experimentKey,
                      userId,
                  ]);
                  return Value.of(op, {
                      result: { variationKey: variation.key },
                      reasons: decideReasons,
                  });
              }
          }
          const decisionifUserIsInAudience = this.checkIfUserIsInAudience(configObj, experiment, AUDIENCE_EVALUATION_TYPES.EXPERIMENT, user, '');
          decideReasons.push(...decisionifUserIsInAudience.reasons);
          if (!decisionifUserIsInAudience.result) {
              (_c = this.logger) === null || _c === void 0 ? void 0 : _c.info(USER_NOT_IN_EXPERIMENT, userId, experimentKey);
              decideReasons.push([
                  USER_NOT_IN_EXPERIMENT,
                  userId,
                  experimentKey,
              ]);
              return Value.of(op, {
                  result: {},
                  reasons: decideReasons,
              });
          }
          const decisionVariationValue = this.isCmab(experiment) ?
              this.getDecisionForCmabExperiment(op, configObj, experiment, user, decideOptions) :
              this.getDecisionFromBucketer(op, configObj, experiment, user);
          return decisionVariationValue.then((variationResult) => {
              var _a, _b;
              decideReasons.push(...variationResult.reasons);
              if (variationResult.error) {
                  return Value.of(op, {
                      error: true,
                      result: {},
                      reasons: decideReasons,
                  });
              }
              const variationId = variationResult.result.variationId;
              variation = variationId ? configObj.variationIdMap[variationId] : null;
              if (!variation) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(USER_HAS_NO_VARIATION, userId, experimentKey);
                  decideReasons.push([
                      USER_HAS_NO_VARIATION,
                      userId,
                      experimentKey,
                  ]);
                  return Value.of(op, {
                      result: {},
                      reasons: decideReasons,
                  });
              }
              (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(USER_HAS_VARIATION, userId, variation.key, experimentKey);
              decideReasons.push([
                  USER_HAS_VARIATION,
                  userId,
                  variation.key,
                  experimentKey,
              ]);
              // update experiment bucket map if decide options do not include shouldIgnoreUPS
              if (userProfileTracker) {
                  this.updateUserProfile(experiment, variation, userProfileTracker);
              }
              return Value.of(op, {
                  result: { variationKey: variation.key, cmabUuid: variationResult.result.cmabUuid },
                  reasons: decideReasons,
              });
          });
      }
      getDecisionForCmabExperiment(op, configObj, experiment, user, decideOptions) {
          if (op === 'sync') {
              return Value.of(op, {
                  error: false,
                  result: {},
                  reasons: [[CMAB_NOT_SUPPORTED_IN_SYNC]],
              });
          }
          const userId = user.getUserId();
          const attributes = user.getAttributes();
          const bucketingId = this.getBucketingId(userId, attributes);
          const bucketerParams = this.buildBucketerParams(configObj, experiment, bucketingId, userId);
          const bucketerResult = bucket(bucketerParams);
          // this means the user is not in the cmab experiment
          if (bucketerResult.result !== CMAB_DUMMY_ENTITY_ID) {
              return Value.of(op, {
                  error: false,
                  result: {},
                  reasons: bucketerResult.reasons,
              });
          }
          const cmabPromise = this.cmabService.getDecision(configObj, user, experiment.id, decideOptions).then((cmabDecision) => {
              return {
                  error: false,
                  result: cmabDecision,
                  reasons: [],
              };
          }).catch((ex) => {
              var _a;
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(CMAB_FETCH_FAILED, experiment.key);
              return {
                  error: true,
                  result: {},
                  reasons: [[CMAB_FETCH_FAILED, experiment.key]],
              };
          });
          return Value.of(op, cmabPromise);
      }
      getDecisionFromBucketer(op, configObj, experiment, user) {
          const userId = user.getUserId();
          const attributes = user.getAttributes();
          // by default, the bucketing ID should be the user ID
          const bucketingId = this.getBucketingId(userId, attributes);
          const bucketerParams = this.buildBucketerParams(configObj, experiment, bucketingId, userId);
          const decisionVariation = bucket(bucketerParams);
          return Value.of(op, {
              result: {
                  variationId: decisionVariation.result || undefined,
              },
              reasons: decisionVariation.reasons,
          });
      }
      /**
       * Gets variation where visitor will be bucketed.
       * @param  {ProjectConfig}                          configObj         The parsed project configuration object
       * @param  {Experiment}                             experiment
       * @param  {OptimizelyUserContext}                  user              A user context
       * @param  {[key: string]: boolean}                 options           Optional map of decide options
       * @return {DecisionResponse<string|null>}          DecisionResponse containing the variation the user is bucketed into
       *                                                                    and the decide reasons.
       */
      getVariation(configObj, experiment, user, options = {}) {
          const shouldIgnoreUPS = options[exports.OptimizelyDecideOption.IGNORE_USER_PROFILE_SERVICE];
          const userProfileTracker = shouldIgnoreUPS ? undefined
              : {
                  isProfileUpdated: false,
                  userProfile: this.resolveExperimentBucketMap('sync', user.getUserId(), user.getAttributes()).get(),
              };
          const result = this.resolveVariation('sync', configObj, experiment, user, options, userProfileTracker).get();
          if (userProfileTracker) {
              this.saveUserProfile('sync', user.getUserId(), userProfileTracker);
          }
          return {
              result: result.result.variationKey || null,
              reasons: result.reasons,
          };
      }
      /**
       * Merges attributes from attributes[STICKY_BUCKETING_KEY] and userProfileService
       * @param  {string}               userId
       * @param  {UserAttributes}       attributes
       * @return {ExperimentBucketMap}  finalized copy of experiment_bucket_map
       */
      resolveExperimentBucketMap(op, userId, attributes = {}) {
          const fromAttributes = (attributes[CONTROL_ATTRIBUTES.STICKY_BUCKETING_KEY] || {});
          return this.getUserProfile(op, userId).then((userProfile) => {
              const fromUserProfileService = (userProfile === null || userProfile === void 0 ? void 0 : userProfile.experiment_bucket_map) || {};
              return Value.of(op, Object.assign(Object.assign({}, fromUserProfileService), fromAttributes));
          });
      }
      /**
       * Checks if user is whitelisted into any variation and return that variation if so
       * @param  {Experiment}                                 experiment
       * @param  {string}                                     userId
       * @return {DecisionResponse<Variation|null>}           DecisionResponse containing the forced variation if it exists
       *                                                      or user ID and the decide reasons.
       */
      getWhitelistedVariation(experiment, userId) {
          var _a, _b;
          const decideReasons = [];
          if (experiment.forcedVariations && experiment.forcedVariations.hasOwnProperty(userId)) {
              const forcedVariationKey = experiment.forcedVariations[userId];
              if (experiment.variationKeyMap.hasOwnProperty(forcedVariationKey)) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(USER_FORCED_IN_VARIATION, userId, forcedVariationKey);
                  decideReasons.push([
                      USER_FORCED_IN_VARIATION,
                      userId,
                      forcedVariationKey,
                  ]);
                  return {
                      result: experiment.variationKeyMap[forcedVariationKey],
                      reasons: decideReasons,
                  };
              }
              else {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(FORCED_BUCKETING_FAILED, forcedVariationKey, userId);
                  decideReasons.push([
                      FORCED_BUCKETING_FAILED,
                      forcedVariationKey,
                      userId,
                  ]);
                  return {
                      result: null,
                      reasons: decideReasons,
                  };
              }
          }
          return {
              result: null,
              reasons: decideReasons,
          };
      }
      /**
       * Checks whether the user is included in experiment audience
       * @param  {ProjectConfig}                configObj            The parsed project configuration object
       * @param  {string}                       experimentKey        Key of experiment being validated
       * @param  {string}                       evaluationAttribute  String representing experiment key or rule
       * @param  {string}                       userId               ID of user
       * @param  {UserAttributes}               attributes           Optional parameter for user's attributes
       * @param  {string}                       loggingKey           String representing experiment key or rollout rule. To be used in log messages only.
       * @return {DecisionResponse<boolean>}    DecisionResponse     DecisionResponse containing result true if user meets audience conditions and
       *                                                             the decide reasons.
       */
      checkIfUserIsInAudience(configObj, experiment, evaluationAttribute, user, loggingKey) {
          var _a, _b;
          const decideReasons = [];
          const experimentAudienceConditions = getExperimentAudienceConditions(configObj, experiment.id);
          const audiencesById = getAudiencesById(configObj);
          (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(EVALUATING_AUDIENCES_COMBINED, evaluationAttribute, loggingKey || experiment.key, JSON.stringify(experimentAudienceConditions));
          decideReasons.push([
              EVALUATING_AUDIENCES_COMBINED,
              evaluationAttribute,
              loggingKey || experiment.key,
              JSON.stringify(experimentAudienceConditions),
          ]);
          const result = this.audienceEvaluator.evaluate(experimentAudienceConditions, audiencesById, user);
          (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(AUDIENCE_EVALUATION_RESULT_COMBINED, evaluationAttribute, loggingKey || experiment.key, result.toString().toUpperCase());
          decideReasons.push([
              AUDIENCE_EVALUATION_RESULT_COMBINED,
              evaluationAttribute,
              loggingKey || experiment.key,
              result.toString().toUpperCase(),
          ]);
          return {
              result: result,
              reasons: decideReasons,
          };
      }
      /**
       * Given an experiment key and user ID, returns params used in bucketer call
       * @param  {ProjectConfig}         configObj     The parsed project configuration object
       * @param  {string}                experimentKey Experiment key used for bucketer
       * @param  {string}                bucketingId   ID to bucket user into
       * @param  {string}                userId        ID of user to be bucketed
       * @return {BucketerParams}
       */
      buildBucketerParams(configObj, experiment, bucketingId, userId) {
          let trafficAllocationConfig = getTrafficAllocation(configObj, experiment.id);
          if (experiment.cmab) {
              trafficAllocationConfig = [{
                      entityId: CMAB_DUMMY_ENTITY_ID,
                      endOfRange: experiment.cmab.trafficAllocation
                  }];
          }
          return {
              bucketingId,
              experimentId: experiment.id,
              experimentKey: experiment.key,
              experimentIdMap: configObj.experimentIdMap,
              experimentKeyMap: configObj.experimentKeyMap,
              groupIdMap: configObj.groupIdMap,
              logger: this.logger,
              trafficAllocationConfig,
              userId,
              variationIdMap: configObj.variationIdMap,
          };
      }
      /**
       * Pull the stored variation out of the experimentBucketMap for an experiment/userId
       * @param  {ProjectConfig}        configObj            The parsed project configuration object
       * @param  {Experiment}           experiment
       * @param  {string}               userId
       * @param  {ExperimentBucketMap}  experimentBucketMap  mapping experiment => { variation_id: <variationId> }
       * @return {Variation|null}       the stored variation or null if the user profile does not have one for the given experiment
       */
      getStoredVariation(configObj, experiment, userId, experimentBucketMap) {
          var _a;
          if (experimentBucketMap === null || experimentBucketMap === void 0 ? void 0 : experimentBucketMap.hasOwnProperty(experiment.id)) {
              const decision = experimentBucketMap[experiment.id];
              const variationId = decision.variation_id;
              if (configObj.variationIdMap.hasOwnProperty(variationId)) {
                  return configObj.variationIdMap[decision.variation_id];
              }
              else {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(SAVED_VARIATION_NOT_FOUND, userId, variationId, experiment.key);
              }
          }
          return null;
      }
      /**
       * Get the user profile with the given user ID
       * @param  {string} userId
       * @return {UserProfile} the stored user profile or an empty profile if one isn't found or error
       */
      getUserProfile(op, userId) {
          var _a;
          const emptyProfile = {
              user_id: userId,
              experiment_bucket_map: {},
          };
          if (this.userProfileService) {
              try {
                  return Value.of(op, this.userProfileService.lookup(userId));
              }
              catch (ex) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(USER_PROFILE_LOOKUP_ERROR, userId, ex.message);
              }
              return Value.of(op, emptyProfile);
          }
          if (this.userProfileServiceAsync && op === 'async') {
              return Value.of(op, this.userProfileServiceAsync.lookup(userId).catch((ex) => {
                  var _a;
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(USER_PROFILE_LOOKUP_ERROR, userId, ex.message);
                  return emptyProfile;
              }));
          }
          return Value.of(op, emptyProfile);
      }
      updateUserProfile(experiment, variation, userProfileTracker) {
          if (!userProfileTracker.userProfile) {
              return;
          }
          userProfileTracker.userProfile[experiment.id] = {
              variation_id: variation.id
          };
          userProfileTracker.isProfileUpdated = true;
      }
      /**
       * Saves the bucketing decision to the user profile
       * @param {Experiment}          experiment
       * @param {Variation}           variation
       * @param {string}              userId
       * @param {ExperimentBucketMap} experimentBucketMap
       */
      saveUserProfile(op, userId, userProfileTracker) {
          var _a, _b;
          const { userProfile, isProfileUpdated } = userProfileTracker;
          if (!userProfile || !isProfileUpdated) {
              return Value.of(op, undefined);
          }
          if (op === 'sync' && !this.userProfileService) {
              return Value.of(op, undefined);
          }
          if (this.userProfileService) {
              try {
                  this.userProfileService.save({
                      user_id: userId,
                      experiment_bucket_map: userProfile,
                  });
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(SAVED_USER_VARIATION, userId);
              }
              catch (ex) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(USER_PROFILE_SAVE_ERROR, userId, ex.message);
              }
              return Value.of(op, undefined);
          }
          if (this.userProfileServiceAsync) {
              return Value.of(op, this.userProfileServiceAsync.save({
                  user_id: userId,
                  experiment_bucket_map: userProfile,
              }).catch((ex) => {
                  var _a;
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(USER_PROFILE_SAVE_ERROR, userId, ex.message);
              }));
          }
          return Value.of(op, undefined);
      }
      /**
       * Determines variations for the specified feature flags.
       *
       * @param {ProjectConfig} configObj - The parsed project configuration object.
       * @param {FeatureFlag[]} featureFlags - The feature flags for which variations are to be determined.
       * @param {OptimizelyUserContext} user - The user context associated with this decision.
       * @param {Record<string, boolean>} options - An optional map of decision options.
       * @returns {DecisionResponse<DecisionObj>[]} - An array of DecisionResponse containing objects with
       *                                               experiment, variation, decisionSource properties, and decision reasons.
       */
      getVariationsForFeatureList(configObj, featureFlags, user, options = {}) {
          return this.resolveVariationsForFeatureList('sync', configObj, featureFlags, user, options).get();
      }
      resolveVariationsForFeatureList(op, configObj, featureFlags, user, options) {
          const userId = user.getUserId();
          const attributes = user.getAttributes();
          // const userProfileTracker : UserProfileTracker = {
          //   isProfileUpdated: false,
          //   userProfile: null,
          // }
          const shouldIgnoreUPS = !!options[exports.OptimizelyDecideOption.IGNORE_USER_PROFILE_SERVICE];
          const userProfileTrackerValue = shouldIgnoreUPS ? Value.of(op, undefined)
              : this.resolveExperimentBucketMap(op, userId, attributes).then((userProfile) => {
                  return Value.of(op, {
                      isProfileUpdated: false,
                      userProfile: userProfile,
                  });
              });
          return userProfileTrackerValue.then((userProfileTracker) => {
              const flagResults = featureFlags.map((feature) => this.resolveVariationForFlag(op, configObj, feature, user, options, userProfileTracker));
              const opFlagResults = Value.all(op, flagResults);
              return opFlagResults.then(() => {
                  if (userProfileTracker) {
                      this.saveUserProfile(op, userId, userProfileTracker);
                  }
                  return opFlagResults;
              });
          });
      }
      resolveVariationForFlag(op, configObj, feature, user, decideOptions, userProfileTracker) {
          const decideReasons = [];
          const forcedDecisionResponse = this.findValidatedForcedDecision(configObj, user, feature.key);
          decideReasons.push(...forcedDecisionResponse.reasons);
          if (forcedDecisionResponse.result) {
              return Value.of(op, {
                  result: {
                      variation: forcedDecisionResponse.result,
                      experiment: null,
                      decisionSource: DECISION_SOURCES.FEATURE_TEST,
                  },
                  reasons: decideReasons,
              });
          }
          return this.getVariationForFeatureExperiment(op, configObj, feature, user, decideOptions, userProfileTracker).then((experimentDecision) => {
              var _a, _b;
              if (experimentDecision.error || experimentDecision.result.variation !== null) {
                  return Value.of(op, Object.assign(Object.assign({}, experimentDecision), { reasons: [...decideReasons, ...experimentDecision.reasons] }));
              }
              decideReasons.push(...experimentDecision.reasons);
              const rolloutDecision = this.getVariationForRollout(configObj, feature, user);
              decideReasons.push(...rolloutDecision.reasons);
              const rolloutDecisionResult = rolloutDecision.result;
              const userId = user.getUserId();
              if (rolloutDecisionResult.variation) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(USER_IN_ROLLOUT, userId, feature.key);
                  decideReasons.push([USER_IN_ROLLOUT, userId, feature.key]);
              }
              else {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.debug(USER_NOT_IN_ROLLOUT, userId, feature.key);
                  decideReasons.push([USER_NOT_IN_ROLLOUT, userId, feature.key]);
              }
              return Value.of(op, {
                  result: rolloutDecisionResult,
                  reasons: decideReasons,
              });
          });
      }
      /**
       * Given a feature, user ID, and attributes, returns a decision response containing
       * an object representing a decision and decide reasons. If the user was bucketed into
       * a variation for the given feature and attributes, the decision object will have variation and
       * experiment properties (both objects), as well as a decisionSource property.
       * decisionSource indicates whether the decision was due to a rollout or an
       * experiment.
       * @param   {ProjectConfig}               configObj         The parsed project configuration object
       * @param   {FeatureFlag}                 feature           A feature flag object from project configuration
       * @param   {OptimizelyUserContext}       user              A user context
       * @param   {[key: string]: boolean}      options           Map of decide options
       * @return  {DecisionResponse}            DecisionResponse  DecisionResponse containing an object with experiment, variation, and decisionSource
       *                                                          properties and decide reasons. If the user was not bucketed into a variation, the variation
       *                                                          property in decision object is null.
       */
      getVariationForFeature(configObj, feature, user, options = {}) {
          return this.resolveVariationsForFeatureList('sync', configObj, [feature], user, options).get()[0];
      }
      getVariationForFeatureExperiment(op, configObj, feature, user, decideOptions, userProfileTracker) {
          // const decideReasons: DecisionReason[] = [];
          // let variationKey = null;
          // let decisionVariation;
          // let index;
          // let variationForFeatureExperiment;
          var _a;
          if (feature.experimentIds.length === 0) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(FEATURE_HAS_NO_EXPERIMENTS, feature.key);
              return Value.of(op, {
                  result: {
                      experiment: null,
                      variation: null,
                      decisionSource: DECISION_SOURCES.FEATURE_TEST,
                  },
                  reasons: [
                      [FEATURE_HAS_NO_EXPERIMENTS, feature.key],
                  ],
              });
          }
          return this.traverseFeatureExperimentList(op, configObj, feature, 0, user, [], decideOptions, userProfileTracker);
      }
      traverseFeatureExperimentList(op, configObj, feature, fromIndex, user, decideReasons, decideOptions, userProfileTracker) {
          const experimentIds = feature.experimentIds;
          if (fromIndex >= experimentIds.length) {
              return Value.of(op, {
                  result: {
                      experiment: null,
                      variation: null,
                      decisionSource: DECISION_SOURCES.FEATURE_TEST,
                  },
                  reasons: decideReasons,
              });
          }
          const experiment = getExperimentFromId(configObj, experimentIds[fromIndex], this.logger);
          if (!experiment) {
              return this.traverseFeatureExperimentList(op, configObj, feature, fromIndex + 1, user, decideReasons, decideOptions, userProfileTracker);
          }
          const decisionVariationValue = this.getVariationFromExperimentRule(op, configObj, feature.key, experiment, user, decideOptions, userProfileTracker);
          return decisionVariationValue.then((decisionVariation) => {
              decideReasons.push(...decisionVariation.reasons);
              if (decisionVariation.error) {
                  return Value.of(op, {
                      error: true,
                      result: {
                          experiment,
                          variation: null,
                          decisionSource: DECISION_SOURCES.FEATURE_TEST,
                      },
                      reasons: decideReasons,
                  });
              }
              if (!decisionVariation.result.variationKey) {
                  return this.traverseFeatureExperimentList(op, configObj, feature, fromIndex + 1, user, decideReasons, decideOptions, userProfileTracker);
              }
              const variationKey = decisionVariation.result.variationKey;
              let variation = experiment.variationKeyMap[variationKey];
              if (!variation) {
                  variation = getFlagVariationByKey(configObj, feature.key, variationKey);
              }
              return Value.of(op, {
                  result: {
                      cmabUuid: decisionVariation.result.cmabUuid,
                      experiment,
                      variation,
                      decisionSource: DECISION_SOURCES.FEATURE_TEST,
                  },
                  reasons: decideReasons,
              });
          });
      }
      getVariationForRollout(configObj, feature, user) {
          var _a, _b, _c;
          const decideReasons = [];
          let decisionObj;
          if (!feature.rolloutId) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(NO_ROLLOUT_EXISTS, feature.key);
              decideReasons.push([NO_ROLLOUT_EXISTS, feature.key]);
              decisionObj = {
                  experiment: null,
                  variation: null,
                  decisionSource: DECISION_SOURCES.ROLLOUT,
              };
              return {
                  result: decisionObj,
                  reasons: decideReasons,
              };
          }
          const rollout = configObj.rolloutIdMap[feature.rolloutId];
          if (!rollout) {
              (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(INVALID_ROLLOUT_ID, feature.rolloutId, feature.key);
              decideReasons.push([INVALID_ROLLOUT_ID, feature.rolloutId, feature.key]);
              decisionObj = {
                  experiment: null,
                  variation: null,
                  decisionSource: DECISION_SOURCES.ROLLOUT,
              };
              return {
                  result: decisionObj,
                  reasons: decideReasons,
              };
          }
          const rolloutRules = rollout.experiments;
          if (rolloutRules.length === 0) {
              (_c = this.logger) === null || _c === void 0 ? void 0 : _c.error(ROLLOUT_HAS_NO_EXPERIMENTS, feature.rolloutId);
              decideReasons.push([ROLLOUT_HAS_NO_EXPERIMENTS, feature.rolloutId]);
              decisionObj = {
                  experiment: null,
                  variation: null,
                  decisionSource: DECISION_SOURCES.ROLLOUT,
              };
              return {
                  result: decisionObj,
                  reasons: decideReasons,
              };
          }
          let decisionVariation;
          let skipToEveryoneElse;
          let variation;
          let rolloutRule;
          let index = 0;
          while (index < rolloutRules.length) {
              decisionVariation = this.getVariationFromDeliveryRule(configObj, feature.key, rolloutRules, index, user);
              decideReasons.push(...decisionVariation.reasons);
              variation = decisionVariation.result;
              skipToEveryoneElse = decisionVariation.skipToEveryoneElse;
              if (variation) {
                  rolloutRule = configObj.experimentIdMap[rolloutRules[index].id];
                  decisionObj = {
                      experiment: rolloutRule,
                      variation: variation,
                      decisionSource: DECISION_SOURCES.ROLLOUT
                  };
                  return {
                      result: decisionObj,
                      reasons: decideReasons,
                  };
              }
              // the last rule is special for "Everyone Else"
              index = skipToEveryoneElse ? (rolloutRules.length - 1) : (index + 1);
          }
          decisionObj = {
              experiment: null,
              variation: null,
              decisionSource: DECISION_SOURCES.ROLLOUT,
          };
          return {
              result: decisionObj,
              reasons: decideReasons,
          };
      }
      /**
       * Get bucketing Id from user attributes.
       * @param   {string}          userId
       * @param   {UserAttributes}  attributes
       * @returns {string}          Bucketing Id if it is a string type in attributes, user Id otherwise.
       */
      getBucketingId(userId, attributes) {
          var _a, _b;
          let bucketingId = userId;
          // If the bucketing ID key is defined in attributes, than use that in place of the userID for the murmur hash key
          if (attributes != null &&
              typeof attributes === 'object' &&
              attributes.hasOwnProperty(CONTROL_ATTRIBUTES.BUCKETING_ID)) {
              if (typeof attributes[CONTROL_ATTRIBUTES.BUCKETING_ID] === 'string') {
                  bucketingId = String(attributes[CONTROL_ATTRIBUTES.BUCKETING_ID]);
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(VALID_BUCKETING_ID, bucketingId);
              }
              else {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.warn(BUCKETING_ID_NOT_STRING);
              }
          }
          return bucketingId;
      }
      /**
       * Finds a validated forced decision for specific flagKey and optional ruleKey.
       * @param     {ProjectConfig}         config               A projectConfig.
       * @param     {OptimizelyUserContext} user                 A Optimizely User Context.
       * @param     {string}                flagKey              A flagKey.
       * @param     {ruleKey}               ruleKey              A ruleKey (optional).
       * @return    {DecisionResponse<Variation|null>}  DecisionResponse object containing valid variation object and decide reasons.
       */
      findValidatedForcedDecision(config, user, flagKey, ruleKey) {
          var _a, _b, _c, _d;
          const decideReasons = [];
          const forcedDecision = user.getForcedDecision({ flagKey, ruleKey });
          let variation = null;
          let variationKey;
          const userId = user.getUserId();
          if (config && forcedDecision) {
              variationKey = forcedDecision.variationKey;
              variation = getFlagVariationByKey(config, flagKey, variationKey);
              if (variation) {
                  if (ruleKey) {
                      (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED, variationKey, flagKey, ruleKey, userId);
                      decideReasons.push([
                          USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED,
                          variationKey,
                          flagKey,
                          ruleKey,
                          userId
                      ]);
                  }
                  else {
                      (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED, variationKey, flagKey, userId);
                      decideReasons.push([
                          USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED,
                          variationKey,
                          flagKey,
                          userId
                      ]);
                  }
              }
              else {
                  if (ruleKey) {
                      (_c = this.logger) === null || _c === void 0 ? void 0 : _c.info(USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED_BUT_INVALID, flagKey, ruleKey, userId);
                      decideReasons.push([
                          USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED_BUT_INVALID,
                          flagKey,
                          ruleKey,
                          userId
                      ]);
                  }
                  else {
                      (_d = this.logger) === null || _d === void 0 ? void 0 : _d.info(USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED_BUT_INVALID, flagKey, userId);
                      decideReasons.push([
                          USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED_BUT_INVALID,
                          flagKey,
                          userId
                      ]);
                  }
              }
          }
          return {
              result: variation,
              reasons: decideReasons,
          };
      }
      /**
       * Removes forced variation for given userId and experimentKey
       * @param  {string} userId         String representing the user id
       * @param  {string} experimentId   Number representing the experiment id
       * @param  {string} experimentKey  Key representing the experiment id
       * @throws If the user id is not valid or not in the forced variation map
       */
      removeForcedVariation(userId, experimentId, experimentKey) {
          var _a;
          if (!userId) {
              throw new OptimizelyError(INVALID_USER_ID);
          }
          if (this.forcedVariationMap.hasOwnProperty(userId)) {
              delete this.forcedVariationMap[userId][experimentId];
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(VARIATION_REMOVED_FOR_USER, experimentKey, userId);
          }
          else {
              throw new OptimizelyError(USER_NOT_IN_FORCED_VARIATION, userId);
          }
      }
      /**
       * Sets forced variation for given userId and experimentKey
       * @param  {string} userId        String representing the user id
       * @param  {string} experimentId  Number representing the experiment id
       * @param  {number} variationId   Number representing the variation id
       * @throws If the user id is not valid
       */
      setInForcedVariationMap(userId, experimentId, variationId) {
          var _a;
          if (this.forcedVariationMap.hasOwnProperty(userId)) {
              this.forcedVariationMap[userId][experimentId] = variationId;
          }
          else {
              this.forcedVariationMap[userId] = {};
              this.forcedVariationMap[userId][experimentId] = variationId;
          }
          (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(USER_MAPPED_TO_FORCED_VARIATION, variationId, experimentId, userId);
      }
      /**
       * Gets the forced variation key for the given user and experiment.
       * @param  {ProjectConfig}                  configObj         Object representing project configuration
       * @param  {string}                         experimentKey     Key for experiment.
       * @param  {string}                         userId            The user Id.
       * @return {DecisionResponse<string|null>}                    DecisionResponse containing variation which the given user and experiment
       *                                                            should be forced into and the decide reasons.
       */
      getForcedVariation(configObj, experimentKey, userId) {
          var _a, _b, _c, _d, _e, _f;
          const decideReasons = [];
          const experimentToVariationMap = this.forcedVariationMap[userId];
          if (!experimentToVariationMap) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(USER_HAS_NO_FORCED_VARIATION, userId);
              return {
                  result: null,
                  reasons: decideReasons,
              };
          }
          let experimentId;
          try {
              const experiment = getExperimentFromKey(configObj, experimentKey);
              if (experiment.hasOwnProperty('id')) {
                  experimentId = experiment['id'];
              }
              else {
                  // catching improperly formatted experiments
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(IMPROPERLY_FORMATTED_EXPERIMENT, experimentKey);
                  decideReasons.push([
                      IMPROPERLY_FORMATTED_EXPERIMENT,
                      experimentKey,
                  ]);
                  return {
                      result: null,
                      reasons: decideReasons,
                  };
              }
          }
          catch (ex) {
              // catching experiment not in datafile
              (_c = this.logger) === null || _c === void 0 ? void 0 : _c.error(ex);
              decideReasons.push(ex.message);
              return {
                  result: null,
                  reasons: decideReasons,
              };
          }
          const variationId = experimentToVariationMap[experimentId];
          if (!variationId) {
              (_d = this.logger) === null || _d === void 0 ? void 0 : _d.debug(USER_HAS_NO_FORCED_VARIATION_FOR_EXPERIMENT, experimentKey, userId);
              return {
                  result: null,
                  reasons: decideReasons,
              };
          }
          const variationKey = getVariationKeyFromId(configObj, variationId);
          if (variationKey) {
              (_e = this.logger) === null || _e === void 0 ? void 0 : _e.debug(USER_HAS_FORCED_VARIATION, variationKey, experimentKey, userId);
              decideReasons.push([
                  USER_HAS_FORCED_VARIATION,
                  variationKey,
                  experimentKey,
                  userId,
              ]);
          }
          else {
              (_f = this.logger) === null || _f === void 0 ? void 0 : _f.debug(USER_HAS_NO_FORCED_VARIATION_FOR_EXPERIMENT, experimentKey, userId);
          }
          return {
              result: variationKey,
              reasons: decideReasons,
          };
      }
      /**
       * Sets the forced variation for a user in a given experiment
       * @param  {ProjectConfig}  configObj      Object representing project configuration
       * @param  {string}         experimentKey  Key for experiment.
       * @param  {string}         userId         The user Id.
       * @param  {string|null}    variationKey   Key for variation. If null, then clear the existing experiment-to-variation mapping
       * @return {boolean}     A boolean value that indicates if the set completed successfully.
       */
      setForcedVariation(configObj, experimentKey, userId, variationKey) {
          var _a, _b, _c, _d, _e, _f;
          if (variationKey != null && !validate$2(variationKey)) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(INVALID_VARIATION_KEY);
              return false;
          }
          let experimentId;
          try {
              const experiment = getExperimentFromKey(configObj, experimentKey);
              if (experiment.hasOwnProperty('id')) {
                  experimentId = experiment['id'];
              }
              else {
                  // catching improperly formatted experiments
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(IMPROPERLY_FORMATTED_EXPERIMENT, experimentKey);
                  return false;
              }
          }
          catch (ex) {
              // catching experiment not in datafile
              (_c = this.logger) === null || _c === void 0 ? void 0 : _c.error(ex);
              return false;
          }
          if (variationKey == null) {
              try {
                  this.removeForcedVariation(userId, experimentId, experimentKey);
                  return true;
              }
              catch (ex) {
                  (_d = this.logger) === null || _d === void 0 ? void 0 : _d.error(ex);
                  return false;
              }
          }
          const variationId = getVariationIdFromExperimentAndVariationKey(configObj, experimentKey, variationKey);
          if (!variationId) {
              (_e = this.logger) === null || _e === void 0 ? void 0 : _e.error(NO_VARIATION_FOR_EXPERIMENT_KEY, variationKey, experimentKey);
              return false;
          }
          try {
              this.setInForcedVariationMap(userId, experimentId, variationId);
              return true;
          }
          catch (ex) {
              (_f = this.logger) === null || _f === void 0 ? void 0 : _f.error(ex);
              return false;
          }
      }
      getVariationFromExperimentRule(op, configObj, flagKey, rule, user, decideOptions, userProfileTracker) {
          const decideReasons = [];
          // check forced decision first
          const forcedDecisionResponse = this.findValidatedForcedDecision(configObj, user, flagKey, rule.key);
          decideReasons.push(...forcedDecisionResponse.reasons);
          const forcedVariation = forcedDecisionResponse.result;
          if (forcedVariation) {
              return Value.of(op, {
                  result: { variationKey: forcedVariation.key },
                  reasons: decideReasons,
              });
          }
          const decisionVariationValue = this.resolveVariation(op, configObj, rule, user, decideOptions, userProfileTracker);
          return decisionVariationValue.then((variationResult) => {
              decideReasons.push(...variationResult.reasons);
              return Value.of(op, {
                  error: variationResult.error,
                  result: variationResult.result,
                  reasons: decideReasons,
              });
          });
          // return response;
          // decideReasons.push(...decisionVariation.reasons);
          // const variationKey = decisionVariation.result;
          // return {
          //   result: variationKey,
          //   reasons: decideReasons,
          // };
      }
      getVariationFromDeliveryRule(configObj, flagKey, rules, ruleIndex, user) {
          var _a, _b, _c, _d;
          const decideReasons = [];
          let skipToEveryoneElse = false;
          // check forced decision first
          const rule = rules[ruleIndex];
          const forcedDecisionResponse = this.findValidatedForcedDecision(configObj, user, flagKey, rule.key);
          decideReasons.push(...forcedDecisionResponse.reasons);
          const forcedVariation = forcedDecisionResponse.result;
          if (forcedVariation) {
              return {
                  result: forcedVariation,
                  reasons: decideReasons,
                  skipToEveryoneElse,
              };
          }
          const userId = user.getUserId();
          const attributes = user.getAttributes();
          const bucketingId = this.getBucketingId(userId, attributes);
          const everyoneElse = ruleIndex === rules.length - 1;
          const loggingKey = everyoneElse ? "Everyone Else" : ruleIndex + 1;
          let bucketedVariation = null;
          let bucketerVariationId;
          let bucketerParams;
          let decisionVariation;
          const decisionifUserIsInAudience = this.checkIfUserIsInAudience(configObj, rule, AUDIENCE_EVALUATION_TYPES.RULE, user, loggingKey);
          decideReasons.push(...decisionifUserIsInAudience.reasons);
          if (decisionifUserIsInAudience.result) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(USER_MEETS_CONDITIONS_FOR_TARGETING_RULE, userId, loggingKey);
              decideReasons.push([
                  USER_MEETS_CONDITIONS_FOR_TARGETING_RULE,
                  userId,
                  loggingKey
              ]);
              bucketerParams = this.buildBucketerParams(configObj, rule, bucketingId, userId);
              decisionVariation = bucket(bucketerParams);
              decideReasons.push(...decisionVariation.reasons);
              bucketerVariationId = decisionVariation.result;
              if (bucketerVariationId) {
                  bucketedVariation = getVariationFromId(configObj, bucketerVariationId);
              }
              if (bucketedVariation) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.debug(USER_BUCKETED_INTO_TARGETING_RULE, userId, loggingKey);
                  decideReasons.push([
                      USER_BUCKETED_INTO_TARGETING_RULE,
                      userId,
                      loggingKey
                  ]);
              }
              else if (!everyoneElse) {
                  // skip this logging for EveryoneElse since this has a message not for EveryoneElse
                  (_c = this.logger) === null || _c === void 0 ? void 0 : _c.debug(USER_NOT_BUCKETED_INTO_TARGETING_RULE, userId, loggingKey);
                  decideReasons.push([
                      USER_NOT_BUCKETED_INTO_TARGETING_RULE,
                      userId,
                      loggingKey
                  ]);
                  // skip the rest of rollout rules to the everyone-else rule if audience matches but not bucketed
                  skipToEveryoneElse = true;
              }
          }
          else {
              (_d = this.logger) === null || _d === void 0 ? void 0 : _d.debug(USER_DOESNT_MEET_CONDITIONS_FOR_TARGETING_RULE, userId, loggingKey);
              decideReasons.push([
                  USER_DOESNT_MEET_CONDITIONS_FOR_TARGETING_RULE,
                  userId,
                  loggingKey
              ]);
          }
          return {
              result: bucketedVariation,
              reasons: decideReasons,
              skipToEveryoneElse,
          };
      }
  }
  /**
   * Creates an instance of the DecisionService.
   * @param  {DecisionServiceOptions}     options       Configuration options
   * @return {Object}                     An instance of the DecisionService
   */
  function createDecisionService(options) {
      return new DecisionService(options);
  }

  /**
   * Copyright 2017, 2020, 2022 Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Validates user's provided event tags
   * @param  {unknown}  eventTags
   * @return {boolean} true if event tags are valid
   * @throws If event tags are not valid
   */
  function validate$1(eventTags) {
      if (typeof eventTags === 'object' && !Array.isArray(eventTags) && eventTags !== null) {
          return true;
      }
      else {
          throw new OptimizelyError(INVALID_EVENT_TAGS);
      }
  }

  /****************************************************************************
   * Copyright 2017, 2020, 2022, Optimizely, Inc. and contributors                  *
   *                                                                          *
   * Licensed under the Apache License, Version 2.0 (the "License");          *
   * you may not use this file except in compliance with the License.         *
   * You may obtain a copy of the License at                                  *
   *                                                                          *
   *    http://www.apache.org/licenses/LICENSE-2.0                            *
   *                                                                          *
   * Unless required by applicable law or agreed to in writing, software      *
   * distributed under the License is distributed on an "AS IS" BASIS,        *
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
   * See the License for the specific language governing permissions and      *
   * limitations under the License.                                           *
   ***************************************************************************/
  /**
   * Validates user's provided user profile service instance
   * @param  {unknown}  userProfileServiceInstance
   * @return {boolean} true if the instance is valid
   * @throws If the instance is not valid
   */
  function validate(userProfileServiceInstance) {
      if (typeof userProfileServiceInstance === 'object' && userProfileServiceInstance !== null) {
          if (typeof userProfileServiceInstance['lookup'] !== 'function') {
              throw new OptimizelyError(INVALID_USER_PROFILE_SERVICE, "Missing function 'lookup'");
          }
          else if (typeof userProfileServiceInstance['save'] !== 'function') {
              throw new OptimizelyError(INVALID_USER_PROFILE_SERVICE, "Missing function 'save'");
          }
          return true;
      }
      throw new OptimizelyError(INVALID_USER_PROFILE_SERVICE, 'Not an object');
  }

  const DEFAULT_ONREADY_TIMEOUT = 30000;
  const INSTANCE_CLOSED = 'Instance closed';
  const ONREADY_TIMEOUT = 'onReady timeout expired after %s ms';
  const INVALID_IDENTIFIER = 'Invalid identifier';
  const INVALID_ATTRIBUTES = 'Invalid attributes';
  class Optimizely extends BaseService {
      constructor(config) {
          var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
          super();
          this.cleanupTasks = new Map();
          this.nextCleanupTaskId = 0;
          let clientEngine = config.clientEngine;
          if (!clientEngine) {
              (_a = config.logger) === null || _a === void 0 ? void 0 : _a.info(INVALID_CLIENT_ENGINE, clientEngine);
              clientEngine = NODE_CLIENT_ENGINE;
          }
          this.clientEngine = clientEngine;
          this.clientVersion = config.clientVersion || CLIENT_VERSION;
          this.errorNotifier = config.errorNotifier;
          this.logger = config.logger;
          this.projectConfigManager = config.projectConfigManager;
          this.errorReporter = new ErrorReporter(this.logger, this.errorNotifier);
          this.odpManager = config.odpManager;
          this.vuidManager = config.vuidManager;
          this.eventProcessor = config.eventProcessor;
          if (config.disposable) {
              this.projectConfigManager.makeDisposable();
              (_b = this.eventProcessor) === null || _b === void 0 ? void 0 : _b.makeDisposable();
              (_c = this.odpManager) === null || _c === void 0 ? void 0 : _c.makeDisposable();
          }
          // pass a child logger to sub-components
          if (this.logger) {
              this.projectConfigManager.setLogger(this.logger.child());
              (_d = this.eventProcessor) === null || _d === void 0 ? void 0 : _d.setLogger(this.logger.child());
              (_e = this.odpManager) === null || _e === void 0 ? void 0 : _e.setLogger(this.logger.child());
          }
          let decideOptionsArray = (_f = config.defaultDecideOptions) !== null && _f !== void 0 ? _f : [];
          if (!Array.isArray(decideOptionsArray)) {
              (_g = this.logger) === null || _g === void 0 ? void 0 : _g.debug(INVALID_DEFAULT_DECIDE_OPTIONS);
              decideOptionsArray = [];
          }
          const defaultDecideOptions = {};
          decideOptionsArray.forEach(option => {
              var _a;
              // Filter out all provided default decide options that are not in OptimizelyDecideOption[]
              if (exports.OptimizelyDecideOption[option]) {
                  defaultDecideOptions[option] = true;
              }
              else {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(UNRECOGNIZED_DECIDE_OPTION, option);
              }
          });
          this.defaultDecideOptions = defaultDecideOptions;
          this.projectConfigManager = config.projectConfigManager;
          this.projectConfigManager.onUpdate((configObj) => {
              var _a;
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(UPDATED_OPTIMIZELY_CONFIG, configObj.revision, configObj.projectId);
              this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.OPTIMIZELY_CONFIG_UPDATE, undefined);
              this.updateOdpSettings();
          });
          this.eventProcessor = config.eventProcessor;
          (_h = this.eventProcessor) === null || _h === void 0 ? void 0 : _h.onDispatch((event) => {
              this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.LOG_EVENT, event);
          });
          this.odpManager = config.odpManager;
          let userProfileService = undefined;
          if (config.userProfileService) {
              try {
                  if (validate(config.userProfileService)) {
                      userProfileService = config.userProfileService;
                      (_j = this.logger) === null || _j === void 0 ? void 0 : _j.info(VALID_USER_PROFILE_SERVICE);
                  }
              }
              catch (ex) {
                  (_k = this.logger) === null || _k === void 0 ? void 0 : _k.warn(ex);
              }
          }
          this.decisionService = createDecisionService({
              userProfileService: userProfileService,
              userProfileServiceAsync: config.userProfileServiceAsync || undefined,
              cmabService: config.cmabService,
              logger: this.logger,
              UNSTABLE_conditionEvaluators: config.UNSTABLE_conditionEvaluators,
          });
          this.notificationCenter = createNotificationCenter({ logger: this.logger, errorNotifier: this.errorNotifier });
          this.start();
      }
      start() {
          var _a, _b;
          if (!this.isNew()) {
              return;
          }
          super.start();
          this.state = ServiceState.Starting;
          this.projectConfigManager.start();
          (_a = this.eventProcessor) === null || _a === void 0 ? void 0 : _a.start();
          (_b = this.odpManager) === null || _b === void 0 ? void 0 : _b.start();
          Promise.all([
              this.projectConfigManager.onRunning(),
              this.eventProcessor ? this.eventProcessor.onRunning() : Promise.resolve(),
              this.odpManager ? this.odpManager.onRunning() : Promise.resolve(),
              this.vuidManager ? this.vuidManager.initialize() : Promise.resolve(),
          ]).then(() => {
              var _a, _b;
              this.state = ServiceState.Running;
              this.startPromise.resolve();
              const vuid = (_a = this.vuidManager) === null || _a === void 0 ? void 0 : _a.getVuid();
              if (vuid) {
                  (_b = this.odpManager) === null || _b === void 0 ? void 0 : _b.setVuid(vuid);
              }
          }).catch((err) => {
              this.state = ServiceState.Failed;
              this.errorReporter.report(err);
              this.startPromise.reject(err);
          });
      }
      /**
       * Returns the project configuration retrieved from projectConfigManager
       * @return {projectConfig.ProjectConfig}
       */
      getProjectConfig() {
          return this.projectConfigManager.getConfig() || null;
      }
      /**
       * Buckets visitor and sends impression event to Optimizely.
       * @param  {string}             experimentKey
       * @param  {string}             userId
       * @param  {UserAttributes}     attributes
       * @return {string|null}        variation key
       */
      activate(experimentKey, userId, attributes) {
          var _a, _b;
          try {
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'activate');
                  return null;
              }
              if (!this.validateInputs({ experiment_key: experimentKey, user_id: userId }, attributes)) {
                  return this.notActivatingExperiment(experimentKey, userId);
              }
              try {
                  const variationKey = this.getVariation(experimentKey, userId, attributes);
                  if (variationKey === null) {
                      return this.notActivatingExperiment(experimentKey, userId);
                  }
                  // If experiment is not set to 'Running' status, log accordingly and return variation key
                  if (!isRunning(configObj, experimentKey)) {
                      (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(SHOULD_NOT_DISPATCH_ACTIVATE, experimentKey);
                      return variationKey;
                  }
                  const experiment = getExperimentFromKey(configObj, experimentKey);
                  const variation = experiment.variationKeyMap[variationKey];
                  const decisionObj = {
                      experiment: experiment,
                      variation: variation,
                      decisionSource: DECISION_SOURCES.EXPERIMENT,
                  };
                  this.sendImpressionEvent(decisionObj, '', userId, true, attributes);
                  return variationKey;
              }
              catch (ex) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(NOT_ACTIVATING_USER, userId, experimentKey);
                  this.errorReporter.report(ex);
                  return null;
              }
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Create an impression event and call the event dispatcher's dispatch method to
       * send this event to Optimizely. Then use the notification center to trigger
       * any notification listeners for the ACTIVATE notification type.
       * @param {DecisionObj}    decisionObj    Decision Object
       * @param {string}         flagKey        Key for a feature flag
       * @param {string}         userId         ID of user to whom the variation was shown
       * @param {UserAttributes} attributes     Optional user attributes
       * @param {boolean}        enabled        Boolean representing if feature is enabled
       */
      sendImpressionEvent(decisionObj, flagKey, userId, enabled, attributes) {
          var _a;
          if (!this.eventProcessor) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(NO_EVENT_PROCESSOR);
              return;
          }
          const configObj = this.getProjectConfig();
          if (!configObj) {
              return;
          }
          const impressionEvent = buildImpressionEvent({
              decisionObj: decisionObj,
              flagKey: flagKey,
              enabled: enabled,
              userId: userId,
              userAttributes: attributes,
              clientEngine: this.clientEngine,
              clientVersion: this.clientVersion,
              configObj: configObj,
          });
          this.eventProcessor.process(impressionEvent);
          const logEvent = buildLogEvent([impressionEvent]);
          this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.ACTIVATE, {
              experiment: decisionObj.experiment,
              userId: userId,
              attributes: attributes,
              variation: decisionObj.variation,
              logEvent,
          });
      }
      /**
       * Sends conversion event to Optimizely.
       * @param  {string}         eventKey
       * @param  {string}         userId
       * @param  {UserAttributes} attributes
       * @param  {EventTags}      eventTags Values associated with the event.
       */
      track(eventKey, userId, attributes, eventTags) {
          var _a, _b, _c, _d, _e;
          try {
              if (!this.eventProcessor) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(NO_EVENT_PROCESSOR);
                  return;
              }
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'track');
                  return;
              }
              if (!this.validateInputs({ user_id: userId, event_key: eventKey }, attributes, eventTags)) {
                  return;
              }
              if (!eventWithKeyExists(configObj, eventKey)) {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.warn(EVENT_KEY_NOT_FOUND, eventKey);
                  (_c = this.logger) === null || _c === void 0 ? void 0 : _c.warn(NOT_TRACKING_USER, userId);
                  return;
              }
              // remove null values from eventTags
              eventTags = this.filterEmptyValues(eventTags);
              const conversionEvent = buildConversionEvent({
                  eventKey: eventKey,
                  eventTags: eventTags,
                  userId: userId,
                  userAttributes: attributes,
                  clientEngine: this.clientEngine,
                  clientVersion: this.clientVersion,
                  configObj: configObj,
              }, this.logger);
              (_d = this.logger) === null || _d === void 0 ? void 0 : _d.info(TRACK_EVENT, eventKey, userId);
              // TODO is it okay to not pass a projectConfig as second argument
              this.eventProcessor.process(conversionEvent);
              const logEvent = buildLogEvent([conversionEvent]);
              this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.TRACK, {
                  eventKey,
                  userId,
                  attributes,
                  eventTags,
                  logEvent,
              });
          }
          catch (e) {
              this.errorReporter.report(e);
              (_e = this.logger) === null || _e === void 0 ? void 0 : _e.error(NOT_TRACKING_USER, userId);
          }
      }
      /**
       * Gets variation where visitor will be bucketed.
       * @param  {string}              experimentKey
       * @param  {string}              userId
       * @param  {UserAttributes}      attributes
       * @return {string|null}         variation key
       */
      getVariation(experimentKey, userId, attributes) {
          var _a;
          try {
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getVariation');
                  return null;
              }
              try {
                  if (!this.validateInputs({ experiment_key: experimentKey, user_id: userId }, attributes)) {
                      return null;
                  }
                  const experiment = configObj.experimentKeyMap[experimentKey];
                  if (!experiment || experiment.isRollout) {
                      (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(INVALID_EXPERIMENT_KEY_INFO, experimentKey);
                      return null;
                  }
                  const variationKey = this.decisionService.getVariation(configObj, experiment, this.createInternalUserContext(userId, attributes)).result;
                  const decisionNotificationType = isFeatureExperiment(configObj, experiment.id)
                      ? DECISION_NOTIFICATION_TYPES.FEATURE_TEST
                      : DECISION_NOTIFICATION_TYPES.AB_TEST;
                  this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.DECISION, {
                      type: decisionNotificationType,
                      userId: userId,
                      attributes: attributes || {},
                      decisionInfo: {
                          experimentKey: experimentKey,
                          variationKey: variationKey,
                      },
                  });
                  return variationKey;
              }
              catch (ex) {
                  this.errorReporter.report(ex);
                  return null;
              }
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Force a user into a variation for a given experiment.
       * @param  {string}      experimentKey
       * @param  {string}      userId
       * @param  {string|null} variationKey   user will be forced into. If null,
       *                                      then clear the existing experiment-to-variation mapping.
       * @return {boolean}                    A boolean value that indicates if the set completed successfully.
       */
      setForcedVariation(experimentKey, userId, variationKey) {
          if (!this.validateInputs({ experiment_key: experimentKey, user_id: userId })) {
              return false;
          }
          const configObj = this.getProjectConfig();
          if (!configObj) {
              return false;
          }
          try {
              return this.decisionService.setForcedVariation(configObj, experimentKey, userId, variationKey);
          }
          catch (ex) {
              this.errorReporter.report(ex);
              return false;
          }
      }
      /**
       * Gets the forced variation for a given user and experiment.
       * @param  {string}      experimentKey
       * @param  {string}      userId
       * @return {string|null} The forced variation key.
       */
      getForcedVariation(experimentKey, userId) {
          if (!this.validateInputs({ experiment_key: experimentKey, user_id: userId })) {
              return null;
          }
          const configObj = this.getProjectConfig();
          if (!configObj) {
              return null;
          }
          try {
              return this.decisionService.getForcedVariation(configObj, experimentKey, userId).result;
          }
          catch (ex) {
              this.errorReporter.report(ex);
              return null;
          }
      }
      /**
       * Validate string inputs, user attributes and event tags.
       * @param  {StringInputs}  stringInputs   Map of string keys and associated values
       * @param  {unknown}       userAttributes Optional parameter for user's attributes
       * @param  {unknown}       eventTags      Optional parameter for event tags
       * @return {boolean}                      True if inputs are valid
       *
       */
      validateInputs(stringInputs, userAttributes, eventTags) {
          try {
              if (stringInputs.hasOwnProperty('user_id')) {
                  const userId = stringInputs['user_id'];
                  if (typeof userId !== 'string' || userId === null || userId === 'undefined') {
                      throw new OptimizelyError(INVALID_INPUT_FORMAT, 'user_id');
                  }
                  delete stringInputs['user_id'];
              }
              Object.keys(stringInputs).forEach(key => {
                  if (!validate$2(stringInputs[key])) {
                      throw new OptimizelyError(INVALID_INPUT_FORMAT, key);
                  }
              });
              if (userAttributes) {
                  validate$5(userAttributes);
              }
              if (eventTags) {
                  validate$1(eventTags);
              }
              return true;
          }
          catch (ex) {
              this.errorReporter.report(ex);
              return false;
          }
      }
      /**
       * Shows failed activation log message and returns null when user is not activated in experiment
       * @param  {string} experimentKey
       * @param  {string} userId
       * @return {null}
       */
      notActivatingExperiment(experimentKey, userId) {
          var _a;
          (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(NOT_ACTIVATING_USER, userId, experimentKey);
          return null;
      }
      /**
       * Filters out attributes/eventTags with null or undefined values
       * @param   {EventTags | undefined} map
       * @returns {EventTags | undefined}
       */
      filterEmptyValues(map) {
          for (const key in map) {
              const typedKey = key;
              if (map.hasOwnProperty(typedKey) && (map[typedKey] === null || map[typedKey] === undefined)) {
                  delete map[typedKey];
              }
          }
          return map;
      }
      /**
       * Returns true if the feature is enabled for the given user.
       * @param  {string}         featureKey   Key of feature which will be checked
       * @param  {string}         userId       ID of user which will be checked
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {boolean}                     true if the feature is enabled for the user, false otherwise
       */
      isFeatureEnabled(featureKey, userId, attributes) {
          var _a, _b;
          try {
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'isFeatureEnabled');
                  return false;
              }
              if (!this.validateInputs({ feature_key: featureKey, user_id: userId }, attributes)) {
                  return false;
              }
              const feature = getFeatureFromKey(configObj, featureKey, this.logger);
              if (!feature) {
                  return false;
              }
              let sourceInfo = {};
              const user = this.createInternalUserContext(userId, attributes);
              const decisionObj = this.decisionService.getVariationForFeature(configObj, feature, user).result;
              const decisionSource = decisionObj.decisionSource;
              const experimentKey = getExperimentKey(decisionObj);
              const variationKey = getVariationKey(decisionObj);
              let featureEnabled = getFeatureEnabledFromVariation(decisionObj);
              if (decisionSource === DECISION_SOURCES.FEATURE_TEST) {
                  sourceInfo = {
                      experimentKey: experimentKey,
                      variationKey: variationKey,
                  };
              }
              if (decisionSource === DECISION_SOURCES.FEATURE_TEST ||
                  (decisionSource === DECISION_SOURCES.ROLLOUT && getSendFlagDecisionsValue(configObj))) {
                  this.sendImpressionEvent(decisionObj, feature.key, userId, featureEnabled, attributes);
              }
              if (featureEnabled === true) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(FEATURE_ENABLED_FOR_USER, featureKey, userId);
              }
              else {
                  (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(FEATURE_NOT_ENABLED_FOR_USER, featureKey, userId);
                  featureEnabled = false;
              }
              const featureInfo = {
                  featureKey: featureKey,
                  featureEnabled: featureEnabled,
                  source: decisionObj.decisionSource,
                  sourceInfo: sourceInfo,
              };
              this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.DECISION, {
                  type: DECISION_NOTIFICATION_TYPES.FEATURE,
                  userId: userId,
                  attributes: attributes || {},
                  decisionInfo: featureInfo,
              });
              return featureEnabled;
          }
          catch (e) {
              this.errorReporter.report(e);
              return false;
          }
      }
      /**
       * Returns an Array containing the keys of all features in the project that are
       * enabled for the given user.
       * @param  {string}         userId
       * @param  {UserAttributes} attributes
       * @return {string[]}       Array of feature keys (strings)
       */
      getEnabledFeatures(userId, attributes) {
          try {
              const enabledFeatures = [];
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getEnabledFeatures');
                  return enabledFeatures;
              }
              if (!this.validateInputs({ user_id: userId })) {
                  return enabledFeatures;
              }
              objectValues(configObj.featureKeyMap).forEach((feature) => {
                  if (this.isFeatureEnabled(feature.key, userId, attributes)) {
                      enabledFeatures.push(feature.key);
                  }
              });
              return enabledFeatures;
          }
          catch (e) {
              this.errorReporter.report(e);
              return [];
          }
      }
      /**
       * Returns dynamically-typed value of the variable attached to the given
       * feature flag. Returns null if the feature key or variable key is invalid.
       *
       * @param  {string}          featureKey           Key of the feature whose variable's
       *                                                value is being accessed
       * @param  {string}          variableKey          Key of the variable whose value is
       *                                                being accessed
       * @param  {string}          userId               ID for the user
       * @param  {UserAttributes}  attributes           Optional user attributes
       * @return {unknown}                              Value of the variable cast to the appropriate
       *                                                type, or null if the feature key is invalid or
       *                                                the variable key is invalid
       */
      getFeatureVariable(featureKey, variableKey, userId, attributes) {
          try {
              if (!this.getProjectConfig()) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getFeatureVariable');
                  return null;
              }
              return this.getFeatureVariableForType(featureKey, variableKey, null, userId, attributes);
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Helper method to get the value for a variable of a certain type attached to a
       * feature flag. Returns null if the feature key is invalid, the variable key is
       * invalid, the given variable type does not match the variable's actual type,
       * or the variable value cannot be cast to the required type. If the given variable
       * type is null, the value of the variable cast to the appropriate type is returned.
       *
       * @param   {string}         featureKey           Key of the feature whose variable's value is
       *                                                being accessed
       * @param   {string}         variableKey          Key of the variable whose value is being
       *                                                accessed
       * @param   {string|null}    variableType         Type of the variable whose value is being
       *                                                accessed (must be one of FEATURE_VARIABLE_TYPES
       *                                                in lib/utils/enums/index.js), or null to return the
       *                                                value of the variable cast to the appropriate type
       * @param   {string}         userId               ID for the user
       * @param   {UserAttributes} attributes           Optional user attributes
       * @return  {unknown}                             Value of the variable cast to the appropriate
       *                                                type, or null if the feature key is invalid, thevariable
       *                                                key is invalid, or there is a mismatch with the type of
       *                                                the variable
       */
      getFeatureVariableForType(featureKey, variableKey, variableType, userId, attributes) {
          var _a;
          if (!this.validateInputs({ feature_key: featureKey, variable_key: variableKey, user_id: userId }, attributes)) {
              return null;
          }
          const configObj = this.getProjectConfig();
          if (!configObj) {
              return null;
          }
          const featureFlag = getFeatureFromKey(configObj, featureKey, this.logger);
          if (!featureFlag) {
              return null;
          }
          const variable = getVariableForFeature(configObj, featureKey, variableKey, this.logger);
          if (!variable) {
              return null;
          }
          if (variableType && variable.type !== variableType) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(VARIABLE_REQUESTED_WITH_WRONG_TYPE, variableType, variable.type);
              return null;
          }
          const user = this.createInternalUserContext(userId, attributes);
          const decisionObj = this.decisionService.getVariationForFeature(configObj, featureFlag, user).result;
          const featureEnabled = getFeatureEnabledFromVariation(decisionObj);
          const variableValue = this.getFeatureVariableValueFromVariation(featureKey, featureEnabled, decisionObj.variation, variable, userId);
          let sourceInfo = {};
          if (decisionObj.decisionSource === DECISION_SOURCES.FEATURE_TEST &&
              decisionObj.experiment !== null &&
              decisionObj.variation !== null) {
              sourceInfo = {
                  experimentKey: decisionObj.experiment.key,
                  variationKey: decisionObj.variation.key,
              };
          }
          this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.DECISION, {
              type: DECISION_NOTIFICATION_TYPES.FEATURE_VARIABLE,
              userId: userId,
              attributes: attributes || {},
              decisionInfo: {
                  featureKey: featureKey,
                  featureEnabled: featureEnabled,
                  source: decisionObj.decisionSource,
                  variableKey: variableKey,
                  variableValue: variableValue,
                  variableType: variable.type,
                  sourceInfo: sourceInfo,
              },
          });
          return variableValue;
      }
      /**
       * Helper method to get the non type-casted value for a variable attached to a
       * feature flag. Returns appropriate variable value depending on whether there
       * was a matching variation, feature was enabled or not or varible was part of the
       * available variation or not. Also logs the appropriate message explaining how it
       * evaluated the value of the variable.
       *
       * @param  {string}          featureKey           Key of the feature whose variable's value is
       *                                                being accessed
       * @param  {boolean}         featureEnabled       Boolean indicating if feature is enabled or not
       * @param  {Variation}       variation            variation returned by decision service
       * @param  {FeatureVariable} variable             varible whose value is being evaluated
       * @param  {string}          userId               ID for the user
       * @return {unknown}                              Value of the variable or null if the
       *                                                config Obj is null
       */
      getFeatureVariableValueFromVariation(featureKey, featureEnabled, variation, variable, userId) {
          var _a, _b, _c, _d;
          const configObj = this.getProjectConfig();
          if (!configObj) {
              return null;
          }
          let variableValue = variable.defaultValue;
          if (variation !== null) {
              const value = getVariableValueForVariation(configObj, variable, variation, this.logger);
              if (value !== null) {
                  if (featureEnabled) {
                      variableValue = value;
                      (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info(USER_RECEIVED_VARIABLE_VALUE, variableValue, variable.key, featureKey);
                  }
                  else {
                      (_b = this.logger) === null || _b === void 0 ? void 0 : _b.info(FEATURE_NOT_ENABLED_RETURN_DEFAULT_VARIABLE_VALUE, featureKey, userId, variableValue);
                  }
              }
              else {
                  (_c = this.logger) === null || _c === void 0 ? void 0 : _c.info(VARIABLE_NOT_USED_RETURN_DEFAULT_VARIABLE_VALUE, variable.key, variation.key);
              }
          }
          else {
              (_d = this.logger) === null || _d === void 0 ? void 0 : _d.info(USER_RECEIVED_DEFAULT_VARIABLE_VALUE, userId, variable.key, featureKey);
          }
          return getTypeCastValue(variableValue, variable.type, this.logger);
      }
      /**
       * Returns value for the given boolean variable attached to the given feature
       * flag.
       * @param  {string}         featureKey   Key of the feature whose variable's value is
       *                                       being accessed
       * @param  {string}         variableKey  Key of the variable whose value is being
       *                                       accessed
       * @param  {string}         userId       ID for the user
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {boolean|null}                Boolean value of the variable, or null if the
       *                                       feature key is invalid, the variable key is invalid,
       *                                       or there is a mismatch with the type of the variable.
       */
      getFeatureVariableBoolean(featureKey, variableKey, userId, attributes) {
          try {
              if (!this.getProjectConfig()) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getFeatureVariableBoolean');
                  return null;
              }
              return this.getFeatureVariableForType(featureKey, variableKey, FEATURE_VARIABLE_TYPES.BOOLEAN, userId, attributes);
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Returns value for the given double variable attached to the given feature
       * flag.
       * @param  {string} featureKey           Key of the feature whose variable's value is
       *                                       being accessed
       * @param  {string} variableKey          Key of the variable whose value is being
       *                                       accessed
       * @param  {string} userId               ID for the user
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {number|null}                 Number value of the variable, or null if the
       *                                       feature key is invalid, the variable key is
       *                                       invalid, or there is a mismatch with the type
       *                                       of the variable
       */
      getFeatureVariableDouble(featureKey, variableKey, userId, attributes) {
          try {
              if (!this.getProjectConfig()) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getFeatureVariableDouble');
                  return null;
              }
              return this.getFeatureVariableForType(featureKey, variableKey, FEATURE_VARIABLE_TYPES.DOUBLE, userId, attributes);
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Returns value for the given integer variable attached to the given feature
       * flag.
       * @param  {string}         featureKey   Key of the feature whose variable's value is
       *                                       being accessed
       * @param  {string}         variableKey  Key of the variable whose value is being
       *                                       accessed
       * @param  {string}         userId       ID for the user
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {number|null}                 Number value of the variable, or null if the
       *                                       feature key is invalid, the variable key is
       *                                       invalid, or there is a mismatch with the type
       *                                       of the variable
       */
      getFeatureVariableInteger(featureKey, variableKey, userId, attributes) {
          try {
              if (!this.getProjectConfig()) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getFeatureVariableInteger');
                  return null;
              }
              return this.getFeatureVariableForType(featureKey, variableKey, FEATURE_VARIABLE_TYPES.INTEGER, userId, attributes);
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Returns value for the given string variable attached to the given feature
       * flag.
       * @param  {string}         featureKey   Key of the feature whose variable's value is
       *                                       being accessed
       * @param  {string}         variableKey  Key of the variable whose value is being
       *                                       accessed
       * @param  {string}         userId       ID for the user
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {string|null}                 String value of the variable, or null if the
       *                                       feature key is invalid, the variable key is
       *                                       invalid, or there is a mismatch with the type
       *                                       of the variable
       */
      getFeatureVariableString(featureKey, variableKey, userId, attributes) {
          try {
              if (!this.getProjectConfig()) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getFeatureVariableString');
                  return null;
              }
              return this.getFeatureVariableForType(featureKey, variableKey, FEATURE_VARIABLE_TYPES.STRING, userId, attributes);
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Returns value for the given json variable attached to the given feature
       * flag.
       * @param  {string}         featureKey   Key of the feature whose variable's value is
       *                                       being accessed
       * @param  {string}         variableKey  Key of the variable whose value is being
       *                                       accessed
       * @param  {string}         userId       ID for the user
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {unknown}                     Object value of the variable, or null if the
       *                                       feature key is invalid, the variable key is
       *                                       invalid, or there is a mismatch with the type
       *                                       of the variable
       */
      getFeatureVariableJSON(featureKey, variableKey, userId, attributes) {
          try {
              if (!this.getProjectConfig()) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getFeatureVariableJSON');
                  return null;
              }
              return this.getFeatureVariableForType(featureKey, variableKey, FEATURE_VARIABLE_TYPES.JSON, userId, attributes);
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Returns values for all the variables attached to the given feature
       * flag.
       * @param  {string}         featureKey   Key of the feature whose variables are being
       *                                       accessed
       * @param  {string}         userId       ID for the user
       * @param  {UserAttributes} attributes   Optional user attributes
       * @return {object|null}                 Object containing all the variables, or null if the
       *                                       feature key is invalid
       */
      getAllFeatureVariables(featureKey, userId, attributes) {
          try {
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'getAllFeatureVariables');
                  return null;
              }
              if (!this.validateInputs({ feature_key: featureKey, user_id: userId }, attributes)) {
                  return null;
              }
              const featureFlag = getFeatureFromKey(configObj, featureKey, this.logger);
              if (!featureFlag) {
                  return null;
              }
              const user = this.createInternalUserContext(userId, attributes);
              const decisionObj = this.decisionService.getVariationForFeature(configObj, featureFlag, user).result;
              const featureEnabled = getFeatureEnabledFromVariation(decisionObj);
              const allVariables = {};
              featureFlag.variables.forEach((variable) => {
                  allVariables[variable.key] = this.getFeatureVariableValueFromVariation(featureKey, featureEnabled, decisionObj.variation, variable, userId);
              });
              let sourceInfo = {};
              if (decisionObj.decisionSource === DECISION_SOURCES.FEATURE_TEST &&
                  decisionObj.experiment !== null &&
                  decisionObj.variation !== null) {
                  sourceInfo = {
                      experimentKey: decisionObj.experiment.key,
                      variationKey: decisionObj.variation.key,
                  };
              }
              this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.DECISION, {
                  type: DECISION_NOTIFICATION_TYPES.ALL_FEATURE_VARIABLES,
                  userId: userId,
                  attributes: attributes || {},
                  decisionInfo: {
                      featureKey: featureKey,
                      featureEnabled: featureEnabled,
                      source: decisionObj.decisionSource,
                      variableValues: allVariables,
                      sourceInfo: sourceInfo,
                  },
              });
              return allVariables;
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Returns OptimizelyConfig object containing experiments and features data
       * @return {OptimizelyConfig|null}
       *
       * OptimizelyConfig Object Schema
       * {
       *   'experimentsMap': {
       *     'my-fist-experiment': {
       *       'id': '111111',
       *       'key': 'my-fist-experiment'
       *       'variationsMap': {
       *         'variation_1': {
       *           'id': '121212',
       *           'key': 'variation_1',
       *           'variablesMap': {
       *             'age': {
       *               'id': '222222',
       *               'key': 'age',
       *               'type': 'integer',
       *               'value': '0',
       *             }
       *           }
       *         }
       *       }
       *     }
       *   },
       *   'featuresMap': {
       *     'awesome-feature': {
       *       'id': '333333',
       *       'key': 'awesome-feature',
       *       'experimentsMap': Object,
       *       'variationsMap': Object,
       *     }
       *   }
       * }
       */
      getOptimizelyConfig() {
          try {
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  return null;
              }
              return this.projectConfigManager.getOptimizelyConfig() || null;
          }
          catch (e) {
              this.errorReporter.report(e);
              return null;
          }
      }
      /**
       * Stop background processes belonging to this instance, including:
       *
       * - Active datafile requests
       * - Pending datafile requests
       * - Pending event queue flushes
       *
       * In-flight datafile requests will be aborted. Any events waiting to be sent
       * as part of a batched event request will be immediately flushed to the event
       * dispatcher.
       *
       * Returns a Promise that fulfills after all in-flight event dispatcher requests
       * (including any final request resulting from flushing the queue as described
       * above) are complete. If there are no in-flight event dispatcher requests and
       * no queued events waiting to be sent, returns an immediately-fulfilled Promise.
       *
       *
       * NOTE: After close is called, this instance is no longer usable - any events
       * generated will no longer be sent to the event dispatcher.
       *
       * @return {Promise}
       */
      close() {
          this.stop();
          return this.onTerminated();
      }
      stop() {
          var _a, _b;
          if (this.isDone()) {
              return;
          }
          if (!this.isRunning()) {
              this.startPromise.reject(new Error(sprintf(SERVICE_STOPPED_BEFORE_RUNNING, 'Client')));
          }
          this.state = ServiceState.Stopping;
          this.projectConfigManager.stop();
          (_a = this.eventProcessor) === null || _a === void 0 ? void 0 : _a.stop();
          (_b = this.odpManager) === null || _b === void 0 ? void 0 : _b.stop();
          this.notificationCenter.clearAllNotificationListeners();
          this.cleanupTasks.forEach((onClose) => onClose());
          Promise.all([
              this.projectConfigManager.onTerminated(),
              this.eventProcessor ? this.eventProcessor.onTerminated() : Promise.resolve(),
              this.odpManager ? this.odpManager.onTerminated() : Promise.resolve(),
          ]).then(() => {
              this.state = ServiceState.Terminated;
              this.stopPromise.resolve();
          }).catch((err) => {
              this.errorReporter.report(err);
              this.state = ServiceState.Failed;
              this.stopPromise.reject(err);
          });
      }
      /**
       * Returns a Promise that fulfills when this instance is ready to use (meaning
       * it has a valid datafile), or rejects when it has failed to become ready within a period of
       * time (configurable by the timeout property of the options argument), or when
       * this instance is closed via the close method before it became ready.
       *
       * If a static project config manager with a valid datafile was provided in the constructor,
       * the returned Promise is immediately fulfilled. If a polling config manager was provided,
       * it will be used to fetch  a datafile, and the returned promise will fulfill if that fetch
       * succeeds, or it will reject if the datafile fetch does not complete before the timeout.
       * The default timeout is 30 seconds.
       *
       * The returned Promise is fulfilled with an unknown result which is not needed to
       * be inspected to know that the instance is ready. If the promise is fulfilled, it
       * is guaranteed that the instance is ready to use. If the promise is rejected, it
       * means the instance is not ready to use, and the reason for the promise rejection
       * will contain an error denoting the cause of failure.
    
       * @param  {Object=}          options
       * @param  {number|undefined} options.timeout
       * @return {Promise}
       */
      onReady(options) {
          let timeoutValue;
          if (typeof options === 'object' && options !== null) {
              if (options.timeout !== undefined) {
                  timeoutValue = options.timeout;
              }
          }
          if (!isSafeInteger(timeoutValue)) {
              timeoutValue = DEFAULT_ONREADY_TIMEOUT;
          }
          const timeoutPromise = resolvablePromise();
          const cleanupTaskId = this.nextCleanupTaskId++;
          const onReadyTimeout = () => {
              this.cleanupTasks.delete(cleanupTaskId);
              timeoutPromise.reject(new Error(sprintf(ONREADY_TIMEOUT, timeoutValue)));
          };
          const readyTimeout = setTimeout(onReadyTimeout, timeoutValue);
          this.cleanupTasks.set(cleanupTaskId, () => {
              clearTimeout(readyTimeout);
              timeoutPromise.reject(new Error(INSTANCE_CLOSED));
          });
          return Promise.race([this.onRunning().then(() => {
                  clearTimeout(readyTimeout);
                  this.cleanupTasks.delete(cleanupTaskId);
              }), timeoutPromise]);
      }
      //============ decide ============//
      /**
       * Creates a context of the user for which decision APIs will be called.
       *
       * A user context will be created successfully even when the SDK is not fully configured yet, so no
       * this.isValidInstance() check is performed here.
       *
       * @param  {string}          userId      (Optional) The user ID to be used for bucketing.
       * @param  {UserAttributes}  attributes  (Optional) user attributes.
       * @return {OptimizelyUserContext|null}  An OptimizelyUserContext associated with this OptimizelyClient or
       *                                       throws if provided inputs are invalid
       */
      createUserContext(userId, attributes) {
          var _a;
          const userIdentifier = userId !== null && userId !== void 0 ? userId : (_a = this.vuidManager) === null || _a === void 0 ? void 0 : _a.getVuid();
          if (userIdentifier === undefined || !this.validateInputs({ user_id: userIdentifier })) {
              throw new Error(INVALID_IDENTIFIER);
          }
          if (!this.validateInputs({}, attributes)) {
              throw new Error(INVALID_ATTRIBUTES);
          }
          const userContext = new OptimizelyUserContext({
              optimizely: this,
              userId: userIdentifier,
              attributes,
          });
          this.onRunning().then(() => {
              if (this.odpManager && this.isOdpIntegrated()) {
                  this.odpManager.identifyUser(userIdentifier);
              }
          }).catch(() => { });
          return userContext;
      }
      /**
       * Creates an internal context of the user for which decision APIs will be called.
       *
       * A user context will be created successfully even when the SDK is not fully configured yet, so no
       * this.isValidInstance() check is performed here.
       *
       * @param  {string}          userId      The user ID to be used for bucketing.
       * @param  {UserAttributes}  attributes  Optional user attributes.
       * @return {OptimizelyUserContext|null}  An OptimizelyUserContext associated with this OptimizelyClient or
       *                                       null if provided inputs are invalid
       */
      createInternalUserContext(userId, attributes) {
          return new OptimizelyUserContext({
              optimizely: this,
              userId,
              attributes,
          });
      }
      decide(user, key, options = []) {
          const configObj = this.getProjectConfig();
          if (!configObj) {
              this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'decide');
              return newErrorDecision(key, user, [DECISION_MESSAGES.SDK_NOT_READY]);
          }
          return this.decideForKeys(user, [key], options, true)[key];
      }
      decideAsync(user, key, options = []) {
          return __awaiter(this, void 0, void 0, function* () {
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'decide');
                  return newErrorDecision(key, user, [DECISION_MESSAGES.SDK_NOT_READY]);
              }
              const result = yield this.decideForKeysAsync(user, [key], options, true);
              return result[key];
          });
      }
      /**
       * Get all decide options.
       * @param  {OptimizelyDecideOption[]}          options   decide options
       * @return {[key: string]: boolean}             Map of all provided decide options including default decide options
       */
      getAllDecideOptions(options) {
          var _a;
          const allDecideOptions = Object.assign({}, this.defaultDecideOptions);
          if (!Array.isArray(options)) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug(INVALID_DECIDE_OPTIONS);
          }
          else {
              options.forEach(option => {
                  var _a;
                  // Filter out all provided decide options that are not in OptimizelyDecideOption[]
                  if (exports.OptimizelyDecideOption[option]) {
                      allDecideOptions[option] = true;
                  }
                  else {
                      (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(UNRECOGNIZED_DECIDE_OPTION, option);
                  }
              });
          }
          return allDecideOptions;
      }
      /**
       * Makes a decision for a given feature key.
       *
       * @param {OptimizelyUserContext} user - The user context associated with this Optimizely client.
       * @param {string} key - The feature key for which a decision will be made.
       * @param {DecisionObj} decisionObj - The decision object containing decision details.
       * @param {DecisionReasons[]} reasons - An array of reasons for the decision.
       * @param {Record<string, boolean>} options - A map of options for decision-making.
       * @param {projectConfig.ProjectConfig} configObj - The project configuration object.
       * @returns {OptimizelyDecision} - The decision object for the feature flag.
       */
      generateDecision(user, key, decisionObj, reasons, options, configObj) {
          var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
          const userId = user.getUserId();
          const attributes = user.getAttributes();
          const feature = configObj.featureKeyMap[key];
          const decisionSource = decisionObj.decisionSource;
          const experimentKey = (_b = (_a = decisionObj.experiment) === null || _a === void 0 ? void 0 : _a.key) !== null && _b !== void 0 ? _b : null;
          const experimentId = (_d = (_c = decisionObj.experiment) === null || _c === void 0 ? void 0 : _c.id) !== null && _d !== void 0 ? _d : null;
          const variationKey = (_f = (_e = decisionObj.variation) === null || _e === void 0 ? void 0 : _e.key) !== null && _f !== void 0 ? _f : null;
          const variationId = (_h = (_g = decisionObj.variation) === null || _g === void 0 ? void 0 : _g.id) !== null && _h !== void 0 ? _h : null;
          const flagEnabled = getFeatureEnabledFromVariation(decisionObj);
          const variablesMap = {};
          let decisionEventDispatched = false;
          if (flagEnabled) {
              (_j = this.logger) === null || _j === void 0 ? void 0 : _j.info(FEATURE_ENABLED_FOR_USER, key, userId);
          }
          else {
              (_k = this.logger) === null || _k === void 0 ? void 0 : _k.info(FEATURE_NOT_ENABLED_FOR_USER, key, userId);
          }
          if (!options[exports.OptimizelyDecideOption.EXCLUDE_VARIABLES]) {
              feature.variables.forEach(variable => {
                  variablesMap[variable.key] = this.getFeatureVariableValueFromVariation(key, flagEnabled, decisionObj.variation, variable, userId);
              });
          }
          if (!options[exports.OptimizelyDecideOption.DISABLE_DECISION_EVENT] &&
              (decisionSource === DECISION_SOURCES.FEATURE_TEST ||
                  (decisionSource === DECISION_SOURCES.ROLLOUT && getSendFlagDecisionsValue(configObj)))) {
              this.sendImpressionEvent(decisionObj, key, userId, flagEnabled, attributes);
              decisionEventDispatched = true;
          }
          const shouldIncludeReasons = options[exports.OptimizelyDecideOption.INCLUDE_REASONS];
          let reportedReasons = [];
          if (shouldIncludeReasons) {
              reportedReasons = reasons.map(reason => sprintf(reason[0], ...reason.slice(1)));
          }
          const featureInfo = {
              flagKey: key,
              enabled: flagEnabled,
              variationKey: variationKey,
              ruleKey: experimentKey,
              variables: variablesMap,
              reasons: reportedReasons,
              decisionEventDispatched: decisionEventDispatched,
              experimentId: experimentId,
              variationId: variationId,
          };
          this.notificationCenter.sendNotifications(NOTIFICATION_TYPES.DECISION, {
              type: DECISION_NOTIFICATION_TYPES.FLAG,
              userId: userId,
              attributes: attributes,
              decisionInfo: featureInfo,
          });
          return {
              variationKey: variationKey,
              enabled: flagEnabled,
              variables: variablesMap,
              ruleKey: experimentKey,
              flagKey: key,
              userContext: user,
              reasons: reportedReasons,
          };
      }
      /**
       * Returns an object of decision results for multiple flag keys and a user context.
       * If the SDK finds an error for a key, the response will include a decision for the key showing reasons for the error.
       * The SDK will always return an object of decisions. When it cannot process requests, it will return an empty object after logging the errors.
       * @param     {OptimizelyUserContext}      user        A user context associated with this OptimizelyClient
       * @param     {string[]}                   keys        An array of flag keys for which decisions will be made.
       * @param     {OptimizelyDecideOption[]}  options     An array of options for decision-making.
       * @return    {[key: string]: OptimizelyDecision}      An object of decision results mapped by flag keys.
       */
      decideForKeys(user, keys, options = [], ignoreEnabledFlagOption) {
          return this.getDecisionForKeys('sync', user, keys, options, ignoreEnabledFlagOption).get();
      }
      decideForKeysAsync(user, keys, options = [], ignoreEnabledFlagOption) {
          return this.getDecisionForKeys('async', user, keys, options, ignoreEnabledFlagOption).get();
      }
      getDecisionForKeys(op, user, keys, options = [], ignoreEnabledFlagOption) {
          var _a;
          const decisionMap = {};
          const flagDecisions = {};
          const decisionReasonsMap = {};
          const configObj = this.getProjectConfig();
          if (!configObj) {
              this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'decideForKeys');
              return Value.of(op, decisionMap);
          }
          if (keys.length === 0) {
              return Value.of(op, decisionMap);
          }
          const allDecideOptions = this.getAllDecideOptions(options);
          if (ignoreEnabledFlagOption) {
              delete allDecideOptions[exports.OptimizelyDecideOption.ENABLED_FLAGS_ONLY];
          }
          const validFlags = [];
          for (const key of keys) {
              const feature = configObj.featureKeyMap[key];
              if (!feature) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(FEATURE_NOT_IN_DATAFILE, key);
                  decisionMap[key] = newErrorDecision(key, user, [sprintf(DECISION_MESSAGES.FLAG_KEY_INVALID, key)]);
                  continue;
              }
              validFlags.push(feature);
          }
          return this.decisionService.resolveVariationsForFeatureList(op, configObj, validFlags, user, allDecideOptions)
              .then((decisionList) => {
              for (let i = 0; i < validFlags.length; i++) {
                  const key = validFlags[i].key;
                  const decision = decisionList[i];
                  if (decision.error) {
                      decisionMap[key] = newErrorDecision(key, user, decision.reasons.map(r => sprintf(r[0], ...r.slice(1))));
                  }
                  else {
                      flagDecisions[key] = decision.result;
                      decisionReasonsMap[key] = decision.reasons;
                  }
              }
              for (const validFlag of validFlags) {
                  const validKey = validFlag.key;
                  // if there is already a value for this flag, that must have come from 
                  // the newErrorDecision above, so we skip it
                  if (decisionMap[validKey]) {
                      continue;
                  }
                  const decision = this.generateDecision(user, validKey, flagDecisions[validKey], decisionReasonsMap[validKey], allDecideOptions, configObj);
                  if (!allDecideOptions[exports.OptimizelyDecideOption.ENABLED_FLAGS_ONLY] || decision.enabled) {
                      decisionMap[validKey] = decision;
                  }
              }
              return Value.of(op, decisionMap);
          });
      }
      /**
       * Returns an object of decision results for all active flag keys.
       * @param     {OptimizelyUserContext}      user        A user context associated with this OptimizelyClient
       * @param     {OptimizelyDecideOption[]}  options     An array of options for decision-making.
       * @return    {[key: string]: OptimizelyDecision}      An object of all decision results mapped by flag keys.
       */
      decideAll(user, options = []) {
          const decisionMap = {};
          const configObj = this.getProjectConfig();
          if (!configObj) {
              this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'decideAll');
              return decisionMap;
          }
          const allFlagKeys = Object.keys(configObj.featureKeyMap);
          return this.decideForKeys(user, allFlagKeys, options);
      }
      decideAllAsync(user, options = []) {
          return __awaiter(this, void 0, void 0, function* () {
              const decisionMap = {};
              const configObj = this.getProjectConfig();
              if (!configObj) {
                  this.errorReporter.report(NO_PROJECT_CONFIG_FAILURE, 'decideAll');
                  return decisionMap;
              }
              const allFlagKeys = Object.keys(configObj.featureKeyMap);
              return this.decideForKeysAsync(user, allFlagKeys, options);
          });
      }
      /**
       * Updates ODP Config with most recent ODP key, host, pixelUrl, and segments from the project config
       */
      updateOdpSettings() {
          const projectConfig = this.getProjectConfig();
          if (!projectConfig) {
              return;
          }
          if (this.odpManager) {
              this.odpManager.updateConfig(projectConfig.odpIntegrationConfig);
          }
      }
      /**
       * Sends an action as an ODP Event with optional custom parameters including type, identifiers, and data
       * Note: Since this depends on this.odpManager, it must await Optimizely client's onReady() promise resolution.
       * @param {string}              action         Subcategory of the event type (i.e. "client_initialized", "identified", or a custom action)
       * @param {string}              type           (Optional) Type of event (Defaults to "fullstack")
       * @param {Map<string, string>} identifiers    (Optional) Key-value map of user identifiers
       * @param {Map<string, string>} data           (Optional) Event data in a key-value map.
       */
      sendOdpEvent(action, type, identifiers, data) {
          var _a, _b;
          if (!this.odpManager) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(ODP_EVENT_FAILED_ODP_MANAGER_MISSING);
              return;
          }
          try {
              const odpEvent = new OdpEvent(type || '', action, identifiers, data);
              this.odpManager.sendEvent(odpEvent);
          }
          catch (e) {
              (_b = this.logger) === null || _b === void 0 ? void 0 : _b.error(ODP_EVENT_FAILED, e);
          }
      }
      /**
       * Checks if ODP (Optimizely Data Platform) is integrated into the project.
       * @returns { boolean } `true` if ODP settings were found in the datafile otherwise `false`
       */
      isOdpIntegrated() {
          var _a, _b, _c;
          return (_c = (_b = (_a = this.getProjectConfig()) === null || _a === void 0 ? void 0 : _a.odpIntegrationConfig) === null || _b === void 0 ? void 0 : _b.integrated) !== null && _c !== void 0 ? _c : false;
      }
      /**
       * Fetches list of qualified segments from ODP for a particular userId.
       * @param {string}                          userId
       * @param {Array<OptimizelySegmentOption>}  options
       * @returns {Promise<string[] | null>}
       */
      fetchQualifiedSegments(userId, options) {
          return __awaiter(this, void 0, void 0, function* () {
              if (!this.odpManager) {
                  return null;
              }
              return yield this.odpManager.fetchQualifiedSegments(userId, options);
          });
      }
      /**
       * @returns {string|undefined}    Currently provisioned VUID from local ODP Manager or undefined if
       *                                ODP Manager has not been instantiated yet for any reason.
       */
      getVuid() {
          var _a;
          if (!this.vuidManager) {
              (_a = this.logger) === null || _a === void 0 ? void 0 : _a.error(UNABLE_TO_GET_VUID_VUID_MANAGER_NOT_AVAILABLE);
              return undefined;
          }
          return this.vuidManager.getVuid();
      }
  }

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const CMAB_PREDICTION_ENDPOINT = 'https://prediction.cmab.optimizely.com/predict/%s';
  class DefaultCmabClient {
      constructor(config) {
          this.requestHandler = config.requestHandler;
          this.retryConfig = config.retryConfig;
      }
      fetchDecision(ruleId, userId, attributes, cmabUuid) {
          var _a, _b;
          return __awaiter(this, void 0, void 0, function* () {
              const url = sprintf(CMAB_PREDICTION_ENDPOINT, ruleId);
              const cmabAttributes = Object.keys(attributes).map((key) => ({
                  id: key,
                  value: attributes[key],
                  type: 'custom_attribute',
              }));
              const body = {
                  instances: [
                      {
                          visitorId: userId,
                          experimentId: ruleId,
                          attributes: cmabAttributes,
                          cmabUUID: cmabUuid,
                      }
                  ]
              };
              const variation = yield (this.retryConfig ?
                  runWithRetry(() => this.doFetch(url, JSON.stringify(body)), (_b = (_a = this.retryConfig).backoffProvider) === null || _b === void 0 ? void 0 : _b.call(_a), this.retryConfig.maxRetries).result : this.doFetch(url, JSON.stringify(body)));
              return variation;
          });
      }
      doFetch(url, data) {
          return __awaiter(this, void 0, void 0, function* () {
              const response = yield this.requestHandler.makeRequest(url, { 'Content-Type': 'application/json' }, 'POST', data).responsePromise;
              if (!isSuccessStatusCode(response.statusCode)) {
                  return Promise.reject(new OptimizelyError(CMAB_FETCH_FAILED$1, response.statusCode));
              }
              const body = JSON.parse(response.body);
              if (!this.validateResponse(body)) {
                  return Promise.reject(new OptimizelyError(INVALID_CMAB_FETCH_RESPONSE));
              }
              return String(body.predictions[0].variation_id);
          });
      }
      validateResponse(body) {
          return body.predictions && body.predictions.length > 0 && body.predictions[0].variation_id;
      }
  }

  /**
   * Copyright 2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class DefaultCmabService {
      constructor(options) {
          this.cmabCache = options.cmabCache;
          this.cmabClient = options.cmabClient;
          this.logger = options.logger;
      }
      getDecision(projectConfig, userContext, ruleId, options) {
          return __awaiter(this, void 0, void 0, function* () {
              const filteredAttributes = this.filterAttributes(projectConfig, userContext, ruleId);
              if (options[exports.OptimizelyDecideOption.IGNORE_CMAB_CACHE]) {
                  return this.fetchDecision(ruleId, userContext.getUserId(), filteredAttributes);
              }
              if (options[exports.OptimizelyDecideOption.RESET_CMAB_CACHE]) {
                  this.cmabCache.reset();
              }
              const cacheKey = this.getCacheKey(userContext.getUserId(), ruleId);
              if (options[exports.OptimizelyDecideOption.INVALIDATE_USER_CMAB_CACHE]) {
                  this.cmabCache.remove(cacheKey);
              }
              const cachedValue = yield this.cmabCache.lookup(cacheKey);
              const attributesJson = JSON.stringify(filteredAttributes, Object.keys(filteredAttributes).sort());
              const attributesHash = String(murmurhash.v3(attributesJson));
              if (cachedValue) {
                  if (cachedValue.attributesHash === attributesHash) {
                      return { variationId: cachedValue.variationId, cmabUuid: cachedValue.cmabUuid };
                  }
                  else {
                      this.cmabCache.remove(cacheKey);
                  }
              }
              const variation = yield this.fetchDecision(ruleId, userContext.getUserId(), filteredAttributes);
              this.cmabCache.save(cacheKey, {
                  attributesHash,
                  variationId: variation.variationId,
                  cmabUuid: variation.cmabUuid,
              });
              return variation;
          });
      }
      fetchDecision(ruleId, userId, attributes) {
          return __awaiter(this, void 0, void 0, function* () {
              const cmabUuid = v4();
              const variationId = yield this.cmabClient.fetchDecision(ruleId, userId, attributes, cmabUuid);
              return { variationId, cmabUuid };
          });
      }
      filterAttributes(projectConfig, userContext, ruleId) {
          const filteredAttributes = {};
          const userAttributes = userContext.getAttributes();
          const experiment = projectConfig.experimentIdMap[ruleId];
          if (!experiment || !experiment.cmab) {
              return filteredAttributes;
          }
          const cmabAttributeIds = experiment.cmab.attributeIds;
          cmabAttributeIds.forEach((aid) => {
              const attribute = projectConfig.attributeIdMap[aid];
              if (userAttributes.hasOwnProperty(attribute.key)) {
                  filteredAttributes[attribute.key] = userAttributes[attribute.key];
              }
          });
          return filteredAttributes;
      }
      getCacheKey(userId, ruleId) {
          const len = userId.length;
          return `${len}-${userId}-${ruleId}`;
      }
  }

  const getOptimizelyInstance = (config) => {
      const { clientEngine, clientVersion, jsonSchemaValidator, userProfileService, userProfileServiceAsync, defaultDecideOptions, disposable, requestHandler, } = config;
      const projectConfigManager = extractConfigManager(config.projectConfigManager);
      const eventProcessor = extractEventProcessor(config.eventProcessor);
      const odpManager = extractOdpManager(config.odpManager);
      const vuidManager = extractVuidManager(config.vuidManager);
      const errorNotifier = extractErrorNotifier(config.errorNotifier);
      const logger = extractLogger(config.logger);
      const cmabClient = new DefaultCmabClient({
          requestHandler,
      });
      const cmabService = new DefaultCmabService({
          cmabClient,
          cmabCache: new InMemoryLruCache(DEFAULT_CMAB_CACHE_SIZE, DEFAULT_CMAB_CACHE_TIMEOUT),
      });
      const optimizelyOptions = {
          cmabService,
          clientEngine: clientEngine || JAVASCRIPT_CLIENT_ENGINE,
          clientVersion: clientVersion || CLIENT_VERSION,
          jsonSchemaValidator,
          userProfileService,
          userProfileServiceAsync,
          defaultDecideOptions,
          disposable,
          logger,
          errorNotifier,
          projectConfigManager,
          eventProcessor,
          odpManager,
          vuidManager,
      };
      return new Optimizely(optimizelyOptions);
  };

  /**
   * Copyright 2022, 2024 Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /**
   * Handles sending requests and receiving responses over HTTP via XMLHttpRequest
   */
  class BrowserRequestHandler {
      constructor(opt = {}) {
          var _a;
          this.logger = opt.logger;
          this.timeout = (_a = opt.timeout) !== null && _a !== void 0 ? _a : REQUEST_TIMEOUT_MS;
      }
      /**
       * Builds an XMLHttpRequest
       * @param requestUrl Fully-qualified URL to which to send the request
       * @param headers List of headers to include in the request
       * @param method HTTP method to use
       * @param data?? stringified version of data to POST, PUT, etc
       * @returns AbortableRequest contains both the response Promise and capability to abort()
       */
      makeRequest(requestUrl, headers, method, data) {
          const request = new XMLHttpRequest();
          const responsePromise = new Promise((resolve, reject) => {
              request.open(method, requestUrl, true);
              this.setHeadersInXhr(headers, request);
              request.onreadystatechange = () => {
                  if (request.readyState === XMLHttpRequest.DONE) {
                      const statusCode = request.status;
                      if (statusCode === 0) {
                          reject(new OptimizelyError(REQUEST_ERROR));
                          return;
                      }
                      const headers = this.parseHeadersFromXhr(request);
                      const response = {
                          statusCode: request.status,
                          body: request.responseText,
                          headers,
                      };
                      resolve(response);
                  }
              };
              request.timeout = this.timeout;
              request.ontimeout = () => {
                  var _a;
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(REQUEST_TIMEOUT);
              };
              request.send(data);
          });
          return {
              responsePromise,
              abort() {
                  request.abort();
              },
          };
      }
      /**
       * Sets the header collection for an XHR
       * @param headers Headers to set
       * @param request Request into which headers are to be set
       * @private
       */
      setHeadersInXhr(headers, request) {
          Object.keys(headers).forEach(headerName => {
              const header = headers[headerName];
              if (typeof header === 'string') {
                  request.setRequestHeader(headerName, header);
              }
          });
      }
      /**
       * Parses headers from an XHR
       * @param request Request containing headers to be retrieved
       * @private
       * @returns List of headers without duplicates
       */
      parseHeadersFromXhr(request) {
          const allHeadersString = request.getAllResponseHeaders();
          if (allHeadersString === null) {
              return {};
          }
          const headerLines = allHeadersString.split('\r\n');
          const headers = {};
          headerLines.forEach(headerLine => {
              var _a;
              try {
                  const separatorIndex = headerLine.indexOf(': ');
                  if (separatorIndex > -1) {
                      const headerName = headerLine.slice(0, separatorIndex);
                      const headerValue = headerLine.slice(separatorIndex + 2);
                      if (headerName && headerValue) {
                          headers[headerName] = headerValue;
                      }
                  }
              }
              catch (_b) {
                  (_a = this.logger) === null || _a === void 0 ? void 0 : _a.warn(UNABLE_TO_PARSE_AND_SKIPPED_HEADER, headerLine);
              }
          });
          return headers;
      }
  }

  class DefaultEventDispatcher {
      constructor(requestHandler) {
          this.requestHandler = requestHandler;
      }
      dispatchEvent(eventObj) {
          return __awaiter(this, void 0, void 0, function* () {
              // Non-POST requests not supported
              if (eventObj.httpVerb !== 'POST') {
                  return Promise.reject(new OptimizelyError(ONLY_POST_REQUESTS_ARE_SUPPORTED));
              }
              const dataString = JSON.stringify(eventObj.params);
              const headers = {
                  'content-type': 'application/json',
              };
              const abortableRequest = this.requestHandler.makeRequest(eventObj.url, headers, 'POST', dataString);
              return abortableRequest.responsePromise;
          });
      }
  }

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const eventDispatcher = new DefaultEventDispatcher(new BrowserRequestHandler());

  /**
   * Copyright 2024, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const createPollingProjectConfigManager = (config) => {
      const defaultConfig = {
          autoUpdate: false,
          requestHandler: new BrowserRequestHandler(),
      };
      return getOpaquePollingConfigManager(Object.assign(Object.assign({}, defaultConfig), config));
  };

  /**
   * Copyright 2022-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  class LocalStorageCache {
      constructor() {
          this.operation = 'sync';
      }
      set(key, value) {
          localStorage.setItem(key, JSON.stringify(value));
      }
      get(key) {
          const value = localStorage.getItem(key);
          return value ? JSON.parse(value) : undefined;
      }
      remove(key) {
          localStorage.removeItem(key);
      }
      clear() {
          localStorage.clear();
      }
      getKeys() {
          const keys = [];
          for (let i = 0; i < localStorage.length; i++) {
              const key = localStorage.key(i);
              if (key) {
                  keys.push(key);
              }
          }
          return keys;
      }
      getBatched(keys) {
          return keys.map((k) => this.get(k));
      }
  }

  const DEFAULT_EVENT_BATCH_SIZE = 10;
  const DEFAULT_EVENT_FLUSH_INTERVAL = 1000;
  const createForwardingEventProcessor = (eventDispatcher$1 = eventDispatcher) => {
      return wrapEventProcessor(getForwardingEventProcessor(eventDispatcher$1));
  };
  const identity = (v) => v;
  const createBatchEventProcessor = (options = {}) => {
      const localStorageCache = new LocalStorageCache();
      const eventStore = new SyncPrefixStore(localStorageCache, EVENT_STORE_PREFIX, identity, identity);
      return getOpaqueBatchEventProcessor({
          eventDispatcher: options.eventDispatcher || eventDispatcher,
          closingEventDispatcher: options.closingEventDispatcher ||
              (options.eventDispatcher ? undefined : eventDispatcher$1),
          flushInterval: options.flushInterval,
          batchSize: options.batchSize,
          defaultFlushInterval: DEFAULT_EVENT_FLUSH_INTERVAL,
          defaultBatchSize: DEFAULT_EVENT_BATCH_SIZE,
          retryOptions: {
              maxRetries: 5,
          },
          failedEventRetryInterval: FAILED_EVENT_RETRY_INTERVAL,
          eventStore,
      });
  };

  /**
   * Copyright 2024-2025, Optimizely
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   * https://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const BROWSER_DEFAULT_API_TIMEOUT = 10000;
  const BROWSER_DEFAULT_BATCH_SIZE = 10;
  const BROWSER_DEFAULT_FLUSH_INTERVAL = 1000;
  const createOdpManager = (options = {}) => {
      const segmentRequestHandler = new BrowserRequestHandler({
          timeout: options.segmentsApiTimeout || BROWSER_DEFAULT_API_TIMEOUT,
      });
      const eventRequestHandler = new BrowserRequestHandler({
          timeout: options.eventApiTimeout || BROWSER_DEFAULT_API_TIMEOUT,
      });
      return getOpaqueOdpManager(Object.assign(Object.assign({}, options), { eventBatchSize: options.eventBatchSize || BROWSER_DEFAULT_BATCH_SIZE, eventFlushInterval: options.eventFlushInterval || BROWSER_DEFAULT_FLUSH_INTERVAL, segmentRequestHandler,
          eventRequestHandler, eventRequestGenerator: eventApiRequestGenerator }));
  };

  class VuidCacheManager {
      constructor(cache, logger) {
          this.vuidCacheKey = 'optimizely-vuid';
          this.waitPromise = Promise.resolve();
          this.cache = cache;
          this.logger = logger;
      }
      setCache(cache) {
          this.cache = cache;
          this.vuid = undefined;
      }
      setLogger(logger) {
          this.logger = logger;
      }
      serialize(fn) {
          return __awaiter(this, void 0, void 0, function* () {
              const resultPromise = this.waitPromise.then(fn, fn);
              this.waitPromise = resultPromise.catch(() => { });
              return resultPromise;
          });
      }
      remove() {
          return __awaiter(this, void 0, void 0, function* () {
              const removeFn = () => __awaiter(this, void 0, void 0, function* () {
                  if (!this.cache) {
                      return;
                  }
                  this.vuid = undefined;
                  yield this.cache.remove(this.vuidCacheKey);
              });
              return this.serialize(removeFn);
          });
      }
      load() {
          return __awaiter(this, void 0, void 0, function* () {
              if (this.vuid) {
                  return this.vuid;
              }
              const loadFn = () => __awaiter(this, void 0, void 0, function* () {
                  if (!this.cache) {
                      return;
                  }
                  const cachedValue = yield this.cache.get(this.vuidCacheKey);
                  if (cachedValue && isVuid(cachedValue)) {
                      this.vuid = cachedValue;
                      return this.vuid;
                  }
                  const newVuid = makeVuid();
                  yield this.cache.set(this.vuidCacheKey, newVuid);
                  this.vuid = newVuid;
                  return newVuid;
              });
              return this.serialize(loadFn);
          });
      }
  }
  class DefaultVuidManager {
      constructor(config) {
          this.vuidEnabled = false;
          this.vuidCacheManager = config.vuidCacheManager;
          this.vuidEnabled = config.enableVuid || false;
          this.vuidCache = config.vuidCache;
      }
      getVuid() {
          return this.vuid;
      }
      isVuidEnabled() {
          return this.vuidEnabled;
      }
      /**
       * initializes the VuidManager
       * @returns Promise that resolves when the VuidManager is initialized
       */
      initialize() {
          return __awaiter(this, void 0, void 0, function* () {
              this.vuidCacheManager.setCache(this.vuidCache);
              if (!this.vuidEnabled) {
                  yield this.vuidCacheManager.remove();
                  return;
              }
              this.vuid = yield this.vuidCacheManager.load();
          });
      }
  }

  /**
  * Copyright 2024-2025, Optimizely
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
  const vuidCacheManager = new VuidCacheManager();
  const createVuidManager = (options = {}) => {
      return wrapVuidManager(new DefaultVuidManager({
          vuidCacheManager,
          vuidCache: options.vuidCache || new LocalStorageCache(),
          enableVuid: options.enableVuid
      }));
  };

  /**
   * Creates an instance of the Optimizely class
   * @param  {Config} config
   * @return {Client|null} the Optimizely client object
   *                           null on error
   */
  const createInstance = function (config) {
      const client = getOptimizelyInstance(Object.assign(Object.assign({}, config), { requestHandler: new BrowserRequestHandler() }));
      if (client) {
          const unloadEvent = 'onpagehide' in window ? 'pagehide' : 'unload';
          window.addEventListener(unloadEvent, () => {
              client.close();
          });
      }
      return client;
  };
  const getSendBeaconEventDispatcher = () => {
      return eventDispatcher$1;
  };
  const clientEngine = JAVASCRIPT_CLIENT_ENGINE;

  exports.DEBUG = DEBUG;
  exports.DECISION_NOTIFICATION_TYPES = DECISION_NOTIFICATION_TYPES;
  exports.DECISION_SOURCES = DECISION_SOURCES;
  exports.ERROR = ERROR;
  exports.INFO = INFO;
  exports.NOTIFICATION_TYPES = NOTIFICATION_TYPES;
  exports.WARN = WARN;
  exports.clientEngine = clientEngine;
  exports.createBatchEventProcessor = createBatchEventProcessor;
  exports.createErrorNotifier = createErrorNotifier;
  exports.createForwardingEventProcessor = createForwardingEventProcessor;
  exports.createInstance = createInstance;
  exports.createLogger = createLogger;
  exports.createOdpManager = createOdpManager;
  exports.createPollingProjectConfigManager = createPollingProjectConfigManager;
  exports.createStaticProjectConfigManager = createStaticProjectConfigManager;
  exports.createVuidManager = createVuidManager;
  exports.eventDispatcher = eventDispatcher;
  exports.getSendBeaconEventDispatcher = getSendBeaconEventDispatcher;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
